/* +CreateDefaultPDBTpl.c */
/**********************************************************************************************************
Copyright (c) 2002-2021 Abdul-Rahman Allouche. All rights reserved

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the Gabedit), to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all copies or substantial portions
  of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
************************************************************************************************************/

#include "../../Config.h"
#include <stdlib.h>
#include <stdio.h>
#include <math.h>

#include "../Common/Global.h"
#include "../Utils/Utils.h"
/************************************************************/
void createTitleResidueTpl(FILE* fout)
{
	fprintf(fout,"Begin Title\n");
	fprintf(fout,"	Residue        : PDB type atom  Amber type atom  charge of atom\n");
	fprintf(fout,"End\n");
}
/************************************************************/
void createListResidueTpl(FILE* fout)
{
	fprintf(fout,"Begin Residue List\n");
	fprintf(fout,"HOH\n");
	fprintf(fout,"T3P\n");
	fprintf(fout,"T3H\n");
	fprintf(fout,"T4P\n");
	fprintf(fout,"T4E\n");
	fprintf(fout,"T5P\n");
	fprintf(fout,"IB+\n");
	fprintf(fout,"Ca+\n");
	fprintf(fout,"Cl-\n");
	fprintf(fout,"Na+\n");
	fprintf(fout,"Mg+\n");
	fprintf(fout,"K+\n");
	fprintf(fout,"Rb+\n");
	fprintf(fout,"Cs+\n");
	fprintf(fout,"Li+\n");
	fprintf(fout,"Zn+\n");
	fprintf(fout,"Sr+\n");
	fprintf(fout,"Ba+\n");
	fprintf(fout,"URE\n");
	fprintf(fout,"ACE\n");
	fprintf(fout,"NME\n");
	fprintf(fout,"NHE\n");
	fprintf(fout,"NH2\n");
	fprintf(fout,"ALA\n");
	fprintf(fout,"GLY\n");
	fprintf(fout,"SER\n");
	fprintf(fout,"THR\n");
	fprintf(fout,"LEU\n");
	fprintf(fout,"ILE\n");
	fprintf(fout,"VAL\n");
	fprintf(fout,"ASN\n");
	fprintf(fout,"GLN\n");
	fprintf(fout,"ARG\n");
	fprintf(fout,"HID\n");
	fprintf(fout,"HIE\n");
	fprintf(fout,"HIP\n");
	fprintf(fout,"HIS\n");
	fprintf(fout,"TRP\n");
	fprintf(fout,"PHE\n");
	fprintf(fout,"TYR\n");
	fprintf(fout,"GLU\n");
	fprintf(fout,"ASP\n");
	fprintf(fout,"LYP\n");
	fprintf(fout,"ORN\n");
	fprintf(fout,"DAB\n");
	fprintf(fout,"LYS\n");
	fprintf(fout,"LYN\n");
	fprintf(fout,"PRO\n");
	fprintf(fout,"HYP\n");
	fprintf(fout,"CYS\n");
	fprintf(fout,"CYN\n");
	fprintf(fout,"CYM\n");
	fprintf(fout,"CYX\n");
	fprintf(fout,"CYS2\n");
	fprintf(fout,"MET\n");
	fprintf(fout,"ASH\n");
	fprintf(fout,"GLH\n");
	fprintf(fout,"CALA\n");
	fprintf(fout,"CGLY\n");
	fprintf(fout,"CSER\n");
	fprintf(fout,"CTHR\n");
	fprintf(fout,"CLEU\n");
	fprintf(fout,"CILE\n");
	fprintf(fout,"CVAL\n");
	fprintf(fout,"CASN\n");
	fprintf(fout,"CGLN\n");
	fprintf(fout,"CARG\n");
	fprintf(fout,"CHID\n");
	fprintf(fout,"CHIE\n");
	fprintf(fout,"CHIP\n");
	fprintf(fout,"CHIS\n");
	fprintf(fout,"CTRP\n");
	fprintf(fout,"CPHE\n");
	fprintf(fout,"CTYR\n");
	fprintf(fout,"CGLU\n");
	fprintf(fout,"CASP\n");
	fprintf(fout,"CLYP\n");
	fprintf(fout,"CLYS\n");
	fprintf(fout,"CPRO\n");
	fprintf(fout,"CCYS\n");
	fprintf(fout,"CCYN\n");
	fprintf(fout,"CCYX\n");
	fprintf(fout,"CCYM\n");
	fprintf(fout,"CMET\n");
	fprintf(fout,"CASH\n");
	fprintf(fout,"CGLH\n");
	fprintf(fout,"CLYN\n");
	fprintf(fout,"OALA\n");
	fprintf(fout,"OARG\n");
	fprintf(fout,"OASN\n");
	fprintf(fout,"OASP\n");
	fprintf(fout,"OCYS\n");
	fprintf(fout,"OCYX\n");
	fprintf(fout,"OGLN\n");
	fprintf(fout,"OGLU\n");
	fprintf(fout,"OGLY\n");
	fprintf(fout,"OHID\n");
	fprintf(fout,"OHIE\n");
	fprintf(fout,"OHIP\n");
	fprintf(fout,"OHIS\n");
	fprintf(fout,"OILE\n");
	fprintf(fout,"OLEU\n");
	fprintf(fout,"OLYS\n");
	fprintf(fout,"OMET\n");
	fprintf(fout,"OPHE\n");
	fprintf(fout,"OPRO\n");
	fprintf(fout,"OSER\n");
	fprintf(fout,"OTHR\n");
	fprintf(fout,"OTYR\n");
	fprintf(fout,"OTRP\n");
	fprintf(fout,"OVAL\n");
	fprintf(fout,"OASH\n");
	fprintf(fout,"OGLH\n");
	fprintf(fout,"OLYN\n");
	fprintf(fout,"OCYM\n");
	fprintf(fout,"NALA\n");
	fprintf(fout,"NGLY\n");
	fprintf(fout,"NSER\n");
	fprintf(fout,"NTHR\n");
	fprintf(fout,"NLEU\n");
	fprintf(fout,"NILE\n");
	fprintf(fout,"NVAL\n");
	fprintf(fout,"NASN\n");
	fprintf(fout,"NGLN\n");
	fprintf(fout,"NARG\n");
	fprintf(fout,"NHID\n");
	fprintf(fout,"NHIE\n");
	fprintf(fout,"NHIP\n");
	fprintf(fout,"NHIS\n");
	fprintf(fout,"NTRP\n");
	fprintf(fout,"NPHE\n");
	fprintf(fout,"NTYR\n");
	fprintf(fout,"NGLU\n");
	fprintf(fout,"NASP\n");
	fprintf(fout,"NLYP\n");
	fprintf(fout,"NLYS\n");
	fprintf(fout,"NPRO\n");
	fprintf(fout,"NCYS\n");
	fprintf(fout,"NCYN\n");
	fprintf(fout,"NCYM\n");
	fprintf(fout,"NCYX\n");
	fprintf(fout,"NMET\n");
	fprintf(fout,"NASH\n");
	fprintf(fout,"NGLH\n");
	fprintf(fout,"NLYN\n");
	fprintf(fout,"HALA\n");
	fprintf(fout,"HARG\n");
	fprintf(fout,"HASN\n");
	fprintf(fout,"HASP\n");
	fprintf(fout,"HCYS\n");
	fprintf(fout,"HCYX\n");
	fprintf(fout,"HGLN\n");
	fprintf(fout,"HGLU\n");
	fprintf(fout,"HGLY\n");
	fprintf(fout,"HHID\n");
	fprintf(fout,"HHIE\n");
	fprintf(fout,"HHIP\n");
	fprintf(fout,"HHIS\n");
	fprintf(fout,"HILE\n");
	fprintf(fout,"HLEU\n");
	fprintf(fout,"HLYS\n");
	fprintf(fout,"HMET\n");
	fprintf(fout,"HPHE\n");
	fprintf(fout,"HPRO\n");
	fprintf(fout,"HSER\n");
	fprintf(fout,"HTHR\n");
	fprintf(fout,"HTYR\n");
	fprintf(fout,"HTRP\n");
	fprintf(fout,"HVAL\n");
	fprintf(fout,"HASH\n");
	fprintf(fout,"HGLH\n");
	fprintf(fout,"HLYN\n");
	fprintf(fout,"HCYM\n");
	fprintf(fout,"ROH\n");
	fprintf(fout,"DA5\n");
	fprintf(fout,"DA\n");
	fprintf(fout,"DA3\n");
	fprintf(fout,"DAN\n");
	fprintf(fout,"RA5\n");
	fprintf(fout,"RA\n");
	fprintf(fout,"RA3\n");
	fprintf(fout,"RAN\n");
	fprintf(fout,"DT5\n");
	fprintf(fout,"DT\n");
	fprintf(fout,"DT3\n");
	fprintf(fout,"DTN\n");
	fprintf(fout,"RU5\n");
	fprintf(fout,"RU\n");
	fprintf(fout,"RU3\n");
	fprintf(fout,"RUN\n");
	fprintf(fout,"DG5\n");
	fprintf(fout,"DG\n");
	fprintf(fout,"DG3\n");
	fprintf(fout,"DGN\n");
	fprintf(fout,"RG5\n");
	fprintf(fout,"RG\n");
	fprintf(fout,"RG3\n");
	fprintf(fout,"RGN\n");
	fprintf(fout,"DC5\n");
	fprintf(fout,"DC\n");
	fprintf(fout,"DC3\n");
	fprintf(fout,"DCN\n");
	fprintf(fout,"RC5\n");
	fprintf(fout,"RC\n");
	fprintf(fout,"RC3\n");
	fprintf(fout,"RCN\n");

	fprintf(fout,"1MA\n");
	fprintf(fout,"1MG\n");
	fprintf(fout,"2MG\n");
	fprintf(fout,"5MC\n");
	fprintf(fout,"7MG\n");
	fprintf(fout,"H2U\n");
	fprintf(fout,"I\n");
	fprintf(fout,"M2G\n");
	fprintf(fout,"OMC\n");
	fprintf(fout,"OMG\n");
	fprintf(fout,"PSU\n");
	fprintf(fout,"Y\n");

	fprintf(fout,"GBZN\n");
	fprintf(fout,"GAPT\n");

	fprintf(fout,"ALLRESIDUE\n");
	fprintf(fout,"End\n");
}
/************************************************************/
void createAminoResidueTpl(FILE* fout)
{

	fprintf(fout,"Begin HOH Residue\n");
	fprintf(fout,"OW     OW     -0.834\n");
	fprintf(fout,"HW1    HW     0.417 \n");
	fprintf(fout,"HW2    HW     0.417 \n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin T3P Residue\n");
	fprintf(fout,"OW     OW     -0.834\n");
	fprintf(fout,"HW1    HW     0.417 \n");
	fprintf(fout,"HW2    HW     0.417 \n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin T3H Residue\n");
	fprintf(fout,"OW     OW     -0.834\n");
	fprintf(fout,"HW1    HW     0.417 \n");
	fprintf(fout,"HW2    HW     0.417 \n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin T4P Residue\n");
	fprintf(fout,"OW     OW     0.000 \n");
	fprintf(fout,"HW2    HW     0.520 \n");
	fprintf(fout,"HW3    HW     0.520 \n");
	fprintf(fout,"MW4    MW     -1.040\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin T4E Residue\n");
	fprintf(fout,"OW     OW     0.000 \n");
	fprintf(fout,"HW1    HW     0.52422\n");
	fprintf(fout,"HW2    HW     0.52422\n");
	fprintf(fout,"MW     MW     -1.04844\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin T5P Residue\n");
	fprintf(fout,"OW     OW     0.000 \n");
	fprintf(fout,"HW1    HW     0.241 \n");
	fprintf(fout,"HW2    HW     0.241 \n");
	fprintf(fout,"LP1    MW     -0.241\n");
	fprintf(fout,"LP2    MW     -0.241\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin IB+ Residue\n");
	fprintf(fout,"IB     IB     1.00000\n");
	fprintf(fout,"IB     IB     1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Ca+ Residue\n");
	fprintf(fout,"Ca     Ca     2.00000\n");
	fprintf(fout,"Ca     Ca     2.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Cl- Residue\n");
	fprintf(fout,"Cl     Cl     -1.00000\n");
	fprintf(fout,"Cl     Cl     -1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Na+ Residue\n");
	fprintf(fout,"Na     Na     1.00000\n");
	fprintf(fout,"Na     Na     1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Mg+ Residue\n");
	fprintf(fout,"Mg     Mg     2.00000\n");
	fprintf(fout,"Mg     Mg     2.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin K+ Residue\n");
	fprintf(fout,"K      K      1.00000\n");
	fprintf(fout,"K      K      1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Rb+ Residue\n");
	fprintf(fout,"Rb     Rb     1.00000\n");
	fprintf(fout,"Rb     Rb     1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Cs+ Residue\n");
	fprintf(fout,"CS     Cs     1.00000\n");
	fprintf(fout,"CS     Cs     1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Li+ Residue\n");
	fprintf(fout,"Li     Li     1.00000\n");
	fprintf(fout,"Li     Li     1.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Zn+ Residue\n");
	fprintf(fout,"Zn     Zn     2.00000\n");
	fprintf(fout,"Zn     Zn     2.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Sr+ Residue\n");
	fprintf(fout,"Sr     Sr     2.00000\n");
	fprintf(fout,"Sr     Sr     2.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Ba+ Residue\n");
	fprintf(fout,"Ba     Ba     2.00000\n");
	fprintf(fout,"Ba     Ba     2.00000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin URE Residue\n");
	fprintf(fout,"C      C      0.880229\n");
	fprintf(fout,"O      O      -0.613359\n");
	fprintf(fout,"N1     N      -0.923545\n");
	fprintf(fout,"H11    H      0.395055\n");
	fprintf(fout,"H12    H      0.395055\n");
	fprintf(fout,"N2     N      -0.923545\n");
	fprintf(fout,"H21    H      0.395055\n");
	fprintf(fout,"H22    H      0.395055\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ACE Residue\n");
	fprintf(fout,"CH3    CT     -0.36620\n");
	fprintf(fout,"HH31   HC     0.11230\n");
	fprintf(fout,"HH32   HC     0.11230\n");
	fprintf(fout,"HH33   HC     0.11230\n");
	fprintf(fout,"C      C      0.59720\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NME Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CH3    CT     -0.14900\n");
	fprintf(fout,"HH31   H1     0.09760\n");
	fprintf(fout,"HH32   H1     0.09760\n");
	fprintf(fout,"HH33   H1     0.09760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NHE Residue\n");
	fprintf(fout,"N      N      -0.46300\n");
	fprintf(fout,"H1     H      0.23150\n");
	fprintf(fout,"H2     H      0.23150\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NH2 Residue\n");
	fprintf(fout,"N      N      -0.46300\n");
	fprintf(fout,"H1     H      0.23150\n");
	fprintf(fout,"H2     H      0.23150\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ALA Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.03370\n");
	fprintf(fout,"HA     H1     0.08230\n");
	fprintf(fout,"CB     CT     -0.18250\n");
	fprintf(fout,"HB1    HC     0.06030\n");
	fprintf(fout,"HB2    HC     0.06030\n");
	fprintf(fout,"HB3    HC     0.06030\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin GLY Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.02520\n");
	fprintf(fout,"HA1    H1     0.06980\n");
	fprintf(fout,"HA2    H1     0.06980\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin SER Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.02490\n");
	fprintf(fout,"HA     H1     0.08430\n");
	fprintf(fout,"CB     CT     0.21170\n");
	fprintf(fout,"HB1    H1     0.03520\n");
	fprintf(fout,"HB2    H1     0.03520\n");
	fprintf(fout,"OG     OH     -0.65460\n");
	fprintf(fout,"HG     HO     0.42750\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin THR Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.03890\n");
	fprintf(fout,"HA     H1     0.10070\n");
	fprintf(fout,"CB     CT     0.36540\n");
	fprintf(fout,"HB     H1     0.00430\n");
	fprintf(fout,"CG2    CT     -0.24380\n");
	fprintf(fout,"HG21   HC     0.06420\n");
	fprintf(fout,"HG22   HC     0.06420\n");
	fprintf(fout,"HG23   HC     0.06420\n");
	fprintf(fout,"OG1    OH     -0.67610\n");
	fprintf(fout,"HG1    HO     0.41020\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin LEU Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.05180\n");
	fprintf(fout,"HA     H1     0.09220\n");
	fprintf(fout,"CB     CT     -0.11020\n");
	fprintf(fout,"HB1    HC     0.04570\n");
	fprintf(fout,"HB2    HC     0.04570\n");
	fprintf(fout,"CG     CT     0.35310\n");
	fprintf(fout,"HG     HC     -0.03610\n");
	fprintf(fout,"CD1    CT     -0.41210\n");
	fprintf(fout,"HD11   HC     0.10000\n");
	fprintf(fout,"HD12   HC     0.10000\n");
	fprintf(fout,"HD13   HC     0.10000\n");
	fprintf(fout,"CD2    CT     -0.41210\n");
	fprintf(fout,"HD21   HC     0.10000\n");
	fprintf(fout,"HD22   HC     0.10000\n");
	fprintf(fout,"HD23   HC     0.10000\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ILE Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.05970\n");
	fprintf(fout,"HA     H1     0.08690\n");
	fprintf(fout,"CB     CT     0.13030\n");
	fprintf(fout,"HB     HC     0.01870\n");
	fprintf(fout,"CG2    CT     -0.32040\n");
	fprintf(fout,"HG21   HC     0.08820\n");
	fprintf(fout,"HG22   HC     0.08820\n");
	fprintf(fout,"HG23   HC     0.08820\n");
	fprintf(fout,"CG1    CT     -0.04300\n");
	fprintf(fout,"HG11   HC     0.02360\n");
	fprintf(fout,"HG12   HC     0.02360\n");
	fprintf(fout,"CD     CT     -0.06600\n");
	fprintf(fout,"HD1    HC     0.01860\n");
	fprintf(fout,"HD2    HC     0.01860\n");
	fprintf(fout,"HD3    HC     0.01860\n");
	fprintf(fout,"CD1    CT     -0.06600\n");
	fprintf(fout,"HD1    HC     0.01860\n");
	fprintf(fout,"HD2    HC     0.01860\n");
	fprintf(fout,"HD3    HC     0.01860\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin VAL Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.08750\n");
	fprintf(fout,"HA     H1     0.09690\n");
	fprintf(fout,"CB     CT     0.29850\n");
	fprintf(fout,"HB     HC     -0.02970\n");
	fprintf(fout,"CG1    CT     -0.31920\n");
	fprintf(fout,"HG11   HC     0.07910\n");
	fprintf(fout,"HG12   HC     0.07910\n");
	fprintf(fout,"HG13   HC     0.07910\n");
	fprintf(fout,"CG2    CT     -0.31920\n");
	fprintf(fout,"HG21   HC     0.07910\n");
	fprintf(fout,"HG22   HC     0.07910\n");
	fprintf(fout,"HG23   HC     0.07910\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ASN Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.01430\n");
	fprintf(fout,"HA     H1     0.10480\n");
	fprintf(fout,"CB     CT     -0.20410\n");
	fprintf(fout,"HB1    HC     0.07970\n");
	fprintf(fout,"HB2    HC     0.07970\n");
	fprintf(fout,"CG     C      0.71300\n");
	fprintf(fout,"OD1    O      -0.59310\n");
	fprintf(fout,"ND2    N      -0.91910\n");
	fprintf(fout,"HD21   H      0.41960\n");
	fprintf(fout,"HD22   H      0.41960\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin GLN Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.00310\n");
	fprintf(fout,"HA     H1     0.08500\n");
	fprintf(fout,"CB     CT     -0.00360\n");
	fprintf(fout,"HB1    HC     0.01710\n");
	fprintf(fout,"HB2    HC     0.01710\n");
	fprintf(fout,"CG     CT     -0.06450\n");
	fprintf(fout,"HG1    HC     0.03520\n");
	fprintf(fout,"HG2    HC     0.03520\n");
	fprintf(fout,"CD     C      0.69510\n");
	fprintf(fout,"OE1    O      -0.60860\n");
	fprintf(fout,"NE2    N      -0.94070\n");
	fprintf(fout,"HE21   H      0.42510\n");
	fprintf(fout,"HE22   H      0.42510\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ARG Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.26370\n");
	fprintf(fout,"HA     H1     0.15600\n");
	fprintf(fout,"CB     CT     -0.00070\n");
	fprintf(fout,"HB1    HC     0.03270\n");
	fprintf(fout,"HB2    HC     0.03270\n");
	fprintf(fout,"CG     CT     0.03900\n");
	fprintf(fout,"HG1    HC     0.02850\n");
	fprintf(fout,"HG2    HC     0.02850\n");
	fprintf(fout,"CD     CT     0.04860\n");
	fprintf(fout,"HD1    H1     0.06870\n");
	fprintf(fout,"HD2    H1     0.06870\n");
	fprintf(fout,"NE     N2     -0.52950\n");
	fprintf(fout,"HE     H      0.34560\n");
	fprintf(fout,"CZ     CA     0.80760\n");
	fprintf(fout,"NH1    N2     -0.86270\n");
	fprintf(fout,"HH11   H      0.44780\n");
	fprintf(fout,"HH12   H      0.44780\n");
	fprintf(fout,"NH2    N2     -0.86270\n");
	fprintf(fout,"HH21   H      0.44780\n");
	fprintf(fout,"HH22   H      0.44780\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin HID Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.01880\n");
	fprintf(fout,"HA     H1     0.08810\n");
	fprintf(fout,"CB     CT     -0.04620\n");
	fprintf(fout,"HB1    HC     0.04020\n");
	fprintf(fout,"HB2    HC     0.04020\n");
	fprintf(fout,"CG     CC     -0.02660\n");
	fprintf(fout,"ND1    NA     -0.38110\n");
	fprintf(fout,"HD1    H      0.36490\n");
	fprintf(fout,"CE1    CR     0.20570\n");
	fprintf(fout,"HE1    H5     0.13920\n");
	fprintf(fout,"NE2    NB     -0.57270\n");
	fprintf(fout,"CD2    CV     0.12920\n");
	fprintf(fout,"HD2    H4     0.11470\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin HIE Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.05810\n");
	fprintf(fout,"HA     H1     0.13600\n");
	fprintf(fout,"CB     CT     -0.00740\n");
	fprintf(fout,"HB1    HC     0.03670\n");
	fprintf(fout,"HB2    HC     0.03670\n");
	fprintf(fout,"CG     CC     0.18680\n");
	fprintf(fout,"ND1    NB     -0.54320\n");
	fprintf(fout,"CE1    CR     0.16350\n");
	fprintf(fout,"HE1    H5     0.14350\n");
	fprintf(fout,"NE2    NA     -0.27950\n");
	fprintf(fout,"HE2    H      0.33390\n");
	fprintf(fout,"CD2    CW     -0.22070\n");
	fprintf(fout,"HD2    H4     0.18620\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin HIP Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.13540\n");
	fprintf(fout,"HA     H1     0.12120\n");
	fprintf(fout,"CB     CT     -0.04140\n");
	fprintf(fout,"HB1    HC     0.08100\n");
	fprintf(fout,"HB2    HC     0.08100\n");
	fprintf(fout,"CG     CC     -0.00120\n");
	fprintf(fout,"ND1    NA     -0.15130\n");
	fprintf(fout,"HD1    H      0.38660\n");
	fprintf(fout,"CE1    CR     -0.01700\n");
	fprintf(fout,"HE1    H5     0.26810\n");
	fprintf(fout,"NE2    NA     -0.17180\n");
	fprintf(fout,"HE2    H      0.39110\n");
	fprintf(fout,"CD2    CW     -0.11410\n");
	fprintf(fout,"HD2    H4     0.23170\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin HIS Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.13540\n");
	fprintf(fout,"HA     H1     0.12120\n");
	fprintf(fout,"CB     CT     -0.04140\n");
	fprintf(fout,"HB1    HC     0.08100\n");
	fprintf(fout,"HB2    HC     0.08100\n");
	fprintf(fout,"CG     CC     -0.00120\n");
	fprintf(fout,"ND1    NA     -0.15130\n");
	fprintf(fout,"HD1    H      0.38660\n");
	fprintf(fout,"CE1    CR     -0.01700\n");
	fprintf(fout,"HE1    H5     0.26810\n");
	fprintf(fout,"NE2    NA     -0.17180\n");
	fprintf(fout,"HE2    H      0.39110\n");
	fprintf(fout,"CD2    CW     -0.11410\n");
	fprintf(fout,"HD2    H4     0.23170\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin TRP Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.02750\n");
	fprintf(fout,"HA     H1     0.11230\n");
	fprintf(fout,"CB     CT     -0.00500\n");
	fprintf(fout,"HB1    HC     0.03390\n");
	fprintf(fout,"HB2    HC     0.03390\n");
	fprintf(fout,"CG     C*     -0.14150\n");
	fprintf(fout,"CD1    CW     -0.16380\n");
	fprintf(fout,"HD1    H4     0.20620\n");
	fprintf(fout,"NE1    NA     -0.34180\n");
	fprintf(fout,"HE1    H      0.34120\n");
	fprintf(fout,"CE2    CN     0.13800\n");
	fprintf(fout,"CZ2    CA     -0.26010\n");
	fprintf(fout,"HZ2    HA     0.15720\n");
	fprintf(fout,"CH2    CA     -0.11340\n");
	fprintf(fout,"HH2    HA     0.14170\n");
	fprintf(fout,"CZ3    CA     -0.19720\n");
	fprintf(fout,"HZ3    HA     0.14470\n");
	fprintf(fout,"CE3    CA     -0.23870\n");
	fprintf(fout,"HE3    HA     0.17000\n");
	fprintf(fout,"CD2    CB     0.12430\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin PHE Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.00240\n");
	fprintf(fout,"HA     H1     0.09780\n");
	fprintf(fout,"CB     CT     -0.03430\n");
	fprintf(fout,"HB1    HC     0.02950\n");
	fprintf(fout,"HB2    HC     0.02950\n");
	fprintf(fout,"CG     CA     0.01180\n");
	fprintf(fout,"CD1    CA     -0.12560\n");
	fprintf(fout,"HD1    HA     0.13300\n");
	fprintf(fout,"CE1    CA     -0.17040\n");
	fprintf(fout,"HE1    HA     0.14300\n");
	fprintf(fout,"CZ     CA     -0.10720\n");
	fprintf(fout,"HZ     HA     0.12970\n");
	fprintf(fout,"CE2    CA     -0.17040\n");
	fprintf(fout,"HE2    HA     0.14300\n");
	fprintf(fout,"CD2    CA     -0.12560\n");
	fprintf(fout,"HD2    HA     0.13300\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin TYR Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.00140\n");
	fprintf(fout,"HA     H1     0.08760\n");
	fprintf(fout,"CB     CT     -0.01520\n");
	fprintf(fout,"HB1    HC     0.02950\n");
	fprintf(fout,"HB2    HC     0.02950\n");
	fprintf(fout,"CG     CA     -0.00110\n");
	fprintf(fout,"CD1    CA     -0.19060\n");
	fprintf(fout,"HD1    HA     0.16990\n");
	fprintf(fout,"CE1    CA     -0.23410\n");
	fprintf(fout,"HE1    HA     0.16560\n");
	fprintf(fout,"CZ     C      0.32260\n");
	fprintf(fout,"OH     OH     -0.55790\n");
	fprintf(fout,"HH     HO     0.39920\n");
	fprintf(fout,"CE2    CA     -0.23410\n");
	fprintf(fout,"HE2    HA     0.16560\n");
	fprintf(fout,"CD2    CA     -0.19060\n");
	fprintf(fout,"HD2    HA     0.16990\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin GLU Residue\n");
	fprintf(fout,"N      N      -0.51630\n");
	fprintf(fout,"H      H      0.29360\n");
	fprintf(fout,"CA     CT     0.03970\n");
	fprintf(fout,"HA     H1     0.11050\n");
	fprintf(fout,"CB     CT     0.05600\n");
	fprintf(fout,"HB1    HC     -0.01730\n");
	fprintf(fout,"HB2    HC     -0.01730\n");
	fprintf(fout,"CG     CT     0.01360\n");
	fprintf(fout,"HG1    HC     -0.04250\n");
	fprintf(fout,"HG2    HC     -0.04250\n");
	fprintf(fout,"CD     C      0.80540\n");
	fprintf(fout,"OE1    O2     -0.81880\n");
	fprintf(fout,"OE2    O2     -0.81880\n");
	fprintf(fout,"C      C      0.53660\n");
	fprintf(fout,"O      O      -0.58190\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ASP Residue\n");
	fprintf(fout,"N      N      -0.51630\n");
	fprintf(fout,"H      H      0.29360\n");
	fprintf(fout,"CA     CT     0.03810\n");
	fprintf(fout,"HA     H1     0.08800\n");
	fprintf(fout,"CB     CT     -0.03030\n");
	fprintf(fout,"HB1    HC     -0.01220\n");
	fprintf(fout,"HB2    HC     -0.01220\n");
	fprintf(fout,"CG     C      0.79940\n");
	fprintf(fout,"OD1    O2     -0.80140\n");
	fprintf(fout,"OD2    O2     -0.80140\n");
	fprintf(fout,"C      C      0.53660\n");
	fprintf(fout,"O      O      -0.58190\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin LYP Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.24000\n");
	fprintf(fout,"HA     H1     0.14260\n");
	fprintf(fout,"CB     CT     -0.00940\n");
	fprintf(fout,"HB1    HC     0.03620\n");
	fprintf(fout,"HB2    HC     0.03620\n");
	fprintf(fout,"CG     CT     0.01870\n");
	fprintf(fout,"HG1    HC     0.01030\n");
	fprintf(fout,"HG2    HC     0.01030\n");
	fprintf(fout,"CD     CT     -0.04790\n");
	fprintf(fout,"HD1    HC     0.06210\n");
	fprintf(fout,"HD2    HC     0.06210\n");
	fprintf(fout,"CE     CT     -0.01430\n");
	fprintf(fout,"HE1    HP     0.11350\n");
	fprintf(fout,"HE2    HP     0.11350\n");
	fprintf(fout,"NZ     N3     -0.38540\n");
	fprintf(fout,"HZ1    H      0.34000\n");
	fprintf(fout,"HZ2    H      0.34000\n");
	fprintf(fout,"HZ3    H      0.34000\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ORN Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.24000\n");
	fprintf(fout,"HA     H1     0.14260\n");
	fprintf(fout,"CB     CT     0.00990\n");
	fprintf(fout,"HB1    HC     0.03620\n");
	fprintf(fout,"HB2    HC     0.03620\n");
	fprintf(fout,"CG     CT     -0.02790\n");
	fprintf(fout,"HG1    HC     0.06210\n");
	fprintf(fout,"HG2    HC     0.06210\n");
	fprintf(fout,"CD     CT     -0.01430\n");
	fprintf(fout,"HD1    HP     0.11350\n");
	fprintf(fout,"HD2    HP     0.11350\n");
	fprintf(fout,"NE     N3     -0.38540\n");
	fprintf(fout,"HE1    H      0.34000\n");
	fprintf(fout,"HE2    H      0.34000\n");
	fprintf(fout,"HE3    H      0.34000\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DAB Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.24000\n");
	fprintf(fout,"HA     H1     0.14260\n");
	fprintf(fout,"CB     CT     0.02920\n");
	fprintf(fout,"HB1    HC     0.07470\n");
	fprintf(fout,"HB2    HC     0.07470\n");
	fprintf(fout,"CG     CT     -0.01430\n");
	fprintf(fout,"HG1    HP     0.11350\n");
	fprintf(fout,"HG2    HP     0.11350\n");
	fprintf(fout,"ND     N3     -0.38540\n");
	fprintf(fout,"HD1    H      0.34000\n");
	fprintf(fout,"HD2    H      0.34000\n");
	fprintf(fout,"HD3    H      0.34000\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin LYS Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.24000\n");
	fprintf(fout,"HA     H1     0.14260\n");
	fprintf(fout,"CB     CT     -0.00940\n");
	fprintf(fout,"HB1    HC     0.03620\n");
	fprintf(fout,"HB2    HC     0.03620\n");
	fprintf(fout,"CG     CT     0.01870\n");
	fprintf(fout,"HG1    HC     0.01030\n");
	fprintf(fout,"HG2    HC     0.01030\n");
	fprintf(fout,"CD     CT     -0.04790\n");
	fprintf(fout,"HD1    HC     0.06210\n");
	fprintf(fout,"HD2    HC     0.06210\n");
	fprintf(fout,"CE     CT     -0.01430\n");
	fprintf(fout,"HE1    HP     0.11350\n");
	fprintf(fout,"HE2    HP     0.11350\n");
	fprintf(fout,"NZ     N3     -0.38540\n");
	fprintf(fout,"HZ1    H      0.34000\n");
	fprintf(fout,"HZ2    H      0.34000\n");
	fprintf(fout,"HZ3    H      0.34000\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin LYN Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.07206\n");
	fprintf(fout,"HA     H1     0.09940\n");
	fprintf(fout,"CB     CT     -0.04845\n");
	fprintf(fout,"HB1    HC     0.03400\n");
	fprintf(fout,"HB2    HC     0.03400\n");
	fprintf(fout,"CG     CT     0.06612\n");
	fprintf(fout,"HG1    HC     0.01041\n");
	fprintf(fout,"HG2    HC     0.01041\n");
	fprintf(fout,"CD     CT     -0.03768\n");
	fprintf(fout,"HD1    HC     0.01155\n");
	fprintf(fout,"HD2    HC     0.01155\n");
	fprintf(fout,"CE     CT     0.32604\n");
	fprintf(fout,"HE1    HP     -0.03358\n");
	fprintf(fout,"HE2    HP     -0.03358\n");
	fprintf(fout,"NZ     N3     -1.03581\n");
	fprintf(fout,"HZ1    H      0.38604\n");
	fprintf(fout,"HZ2    H      0.38604\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin PRO Residue\n");
	fprintf(fout,"N      N      -0.25480\n");
	fprintf(fout,"CD     CT     0.01920\n");
	fprintf(fout,"HD1    H1     0.03910\n");
	fprintf(fout,"HD2    H1     0.03910\n");
	fprintf(fout,"CG     CT     0.01890\n");
	fprintf(fout,"HG1    HC     0.02130\n");
	fprintf(fout,"HG2    HC     0.02130\n");
	fprintf(fout,"CB     CT     -0.00700\n");
	fprintf(fout,"HB1    HC     0.02530\n");
	fprintf(fout,"HB2    HC     0.02530\n");
	fprintf(fout,"CA     CT     -0.02660\n");
	fprintf(fout,"HA     H1     0.06410\n");
	fprintf(fout,"C      C      0.58960\n");
	fprintf(fout,"O      O      -0.57480\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin HYP Residue\n");
	fprintf(fout,"N      N      -0.25480\n");
	fprintf(fout,"CD2    CT     0.05950\n");
	fprintf(fout,"HD21   H1     0.07000\n");
	fprintf(fout,"HD22   H1     0.07000\n");
	fprintf(fout,"CG     CT     0.04000\n");
	fprintf(fout,"HG     H1     0.04160\n");
	fprintf(fout,"OD1    OH     -0.61340\n");
	fprintf(fout,"HD1    HO     0.38510\n");
	fprintf(fout,"CB     CT     0.02030\n");
	fprintf(fout,"HB1    HC     0.04260\n");
	fprintf(fout,"HB2    HC     0.04260\n");
	fprintf(fout,"CA     CT     0.00470\n");
	fprintf(fout,"HA     H1     0.07700\n");
	fprintf(fout,"C      C      0.58960\n");
	fprintf(fout,"O      O      -0.57480\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CYS Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.02130\n");
	fprintf(fout,"HA     H1     0.11240\n");
	fprintf(fout,"CB     CT     -0.12310\n");
	fprintf(fout,"HB1    H1     0.11120\n");
	fprintf(fout,"HB2    H1     0.11120\n");
	fprintf(fout,"SG     SH     -0.31190\n");
	fprintf(fout,"HG     HS     0.19330\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CYN Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.02130\n");
	fprintf(fout,"HA     H1     0.11240\n");
	fprintf(fout,"CB     CT     -0.12310\n");
	fprintf(fout,"HB1    H1     0.11120\n");
	fprintf(fout,"HB2    H1     0.11120\n");
	fprintf(fout,"SG     SH     -0.31190\n");
	fprintf(fout,"HG     HS     0.19330\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CYM Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.03510\n");
	fprintf(fout,"HA     H1     0.05080\n");
	fprintf(fout,"CB     CT     -0.24130\n");
	fprintf(fout,"HB1    H1     0.11220\n");
	fprintf(fout,"HB2    H1     0.11220\n");
	fprintf(fout,"SG     SH     -0.88440\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CYX Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.04290\n");
	fprintf(fout,"HA     H1     0.07660\n");
	fprintf(fout,"CB     CT     -0.07900\n");
	fprintf(fout,"HB1    H1     0.09100\n");
	fprintf(fout,"HB2    H1     0.09100\n");
	fprintf(fout,"SG     S      -0.10810\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CYS2 Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.04290\n");
	fprintf(fout,"HA     H1     0.07660\n");
	fprintf(fout,"CB     CT     -0.07900\n");
	fprintf(fout,"HB1    H1     0.09100\n");
	fprintf(fout,"HB2    H1     0.09100\n");
	fprintf(fout,"SG     S      -0.10810\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin MET Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.02370\n");
	fprintf(fout,"HA     H1     0.08800\n");
	fprintf(fout,"CB     CT     0.03420\n");
	fprintf(fout,"HB1    HC     0.02410\n");
	fprintf(fout,"HB2    HC     0.02410\n");
	fprintf(fout,"CG     CT     0.00180\n");
	fprintf(fout,"HG1    H1     0.04400\n");
	fprintf(fout,"HG2    H1     0.04400\n");
	fprintf(fout,"SD     S      -0.27370\n");
	fprintf(fout,"CE     CT     -0.05360\n");
	fprintf(fout,"HE1    H1     0.06840\n");
	fprintf(fout,"HE2    H1     0.06840\n");
	fprintf(fout,"HE3    H1     0.06840\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ASH Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.03410\n");
	fprintf(fout,"HA     H1     0.08640\n");
	fprintf(fout,"CB     CT     -0.03160\n");
	fprintf(fout,"HB1    HC     0.04880\n");
	fprintf(fout,"HB2    HC     0.04880\n");
	fprintf(fout,"CG     C      0.64620\n");
	fprintf(fout,"OD1    O      -0.55540\n");
	fprintf(fout,"OD2    OH     -0.63760\n");
	fprintf(fout,"HD2    HO     0.47470\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin GLH Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     0.01450\n");
	fprintf(fout,"HA     H1     0.07790\n");
	fprintf(fout,"CB     CT     -0.00710\n");
	fprintf(fout,"HB1    HC     0.02560\n");
	fprintf(fout,"HB2    HC     0.02560\n");
	fprintf(fout,"CG     CT     -0.01740\n");
	fprintf(fout,"HG1    HC     0.04300\n");
	fprintf(fout,"HG2    HC     0.04300\n");
	fprintf(fout,"CD     C      0.68010\n");
	fprintf(fout,"OE1    O      -0.58380\n");
	fprintf(fout,"OE2    OH     -0.65110\n");
	fprintf(fout,"HE2    HO     0.46410\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CALA Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.17470\n");
	fprintf(fout,"HA     H1     0.10670\n");
	fprintf(fout,"CB     CT     -0.20930\n");
	fprintf(fout,"HB1    HC     0.07640\n");
	fprintf(fout,"HB2    HC     0.07640\n");
	fprintf(fout,"HB3    HC     0.07640\n");
	fprintf(fout,"C      C      0.77310\n");
	fprintf(fout,"OC1    O2     -0.80550\n");
	fprintf(fout,"OC2    O2     -0.80550\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CGLY Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.24930\n");
	fprintf(fout,"HA1    H1     0.10560\n");
	fprintf(fout,"HA2    H1     0.10560\n");
	fprintf(fout,"C      C      0.72310\n");
	fprintf(fout,"OC1    O2     -0.78550\n");
	fprintf(fout,"OC2    O2     -0.78550\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CSER Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.27220\n");
	fprintf(fout,"HA     H1     0.13040\n");
	fprintf(fout,"CB     CT     0.11230\n");
	fprintf(fout,"HB1    H1     0.08130\n");
	fprintf(fout,"HB2    H1     0.08130\n");
	fprintf(fout,"OG     OH     -0.65140\n");
	fprintf(fout,"HG     HO     0.44740\n");
	fprintf(fout,"C      C      0.81130\n");
	fprintf(fout,"OC1    O2     -0.81320\n");
	fprintf(fout,"OC2    O2     -0.81320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CTHR Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.24200\n");
	fprintf(fout,"HA     H1     0.12070\n");
	fprintf(fout,"CB     CT     0.30250\n");
	fprintf(fout,"HB     H1     0.00780\n");
	fprintf(fout,"CG2    CT     -0.18530\n");
	fprintf(fout,"HG21   HC     0.05860\n");
	fprintf(fout,"HG22   HC     0.05860\n");
	fprintf(fout,"HG23   HC     0.05860\n");
	fprintf(fout,"OG1    OH     -0.64960\n");
	fprintf(fout,"HG1    HO     0.41190\n");
	fprintf(fout,"C      C      0.78100\n");
	fprintf(fout,"OC1    O2     -0.80440\n");
	fprintf(fout,"OC2    O2     -0.80440\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CLEU Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.28470\n");
	fprintf(fout,"HA     H1     0.13460\n");
	fprintf(fout,"CB     CT     -0.24690\n");
	fprintf(fout,"HB1    HC     0.09740\n");
	fprintf(fout,"HB2    HC     0.09740\n");
	fprintf(fout,"CG     CT     0.37060\n");
	fprintf(fout,"HG     HC     -0.03740\n");
	fprintf(fout,"CD1    CT     -0.41630\n");
	fprintf(fout,"HD11   HC     0.10380\n");
	fprintf(fout,"HD12   HC     0.10380\n");
	fprintf(fout,"HD13   HC     0.10380\n");
	fprintf(fout,"CD2    CT     -0.41630\n");
	fprintf(fout,"HD21   HC     0.10380\n");
	fprintf(fout,"HD22   HC     0.10380\n");
	fprintf(fout,"HD23   HC     0.10380\n");
	fprintf(fout,"C      C      0.83260\n");
	fprintf(fout,"OC1    O2     -0.81990\n");
	fprintf(fout,"OC2    O2     -0.81990\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CILE Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.31000\n");
	fprintf(fout,"HA     H1     0.13750\n");
	fprintf(fout,"CB     CT     0.03630\n");
	fprintf(fout,"HB     HC     0.07660\n");
	fprintf(fout,"CG2    CT     -0.34980\n");
	fprintf(fout,"HG21   HC     0.10210\n");
	fprintf(fout,"HG22   HC     0.10210\n");
	fprintf(fout,"HG23   HC     0.10210\n");
	fprintf(fout,"CG1    CT     -0.03230\n");
	fprintf(fout,"HG11   HC     0.03210\n");
	fprintf(fout,"HG12   HC     0.03210\n");
	fprintf(fout,"CD     CT     -0.06990\n");
	fprintf(fout,"HD1    HC     0.01960\n");
	fprintf(fout,"HD2    HC     0.01960\n");
	fprintf(fout,"HD3    HC     0.01960\n");
	fprintf(fout,"C      C      0.83430\n");
	fprintf(fout,"OC1    O2     -0.81900\n");
	fprintf(fout,"OC2    O2     -0.81900\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CVAL Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.34380\n");
	fprintf(fout,"HA     H1     0.14380\n");
	fprintf(fout,"CB     CT     0.19400\n");
	fprintf(fout,"HB     HC     0.03080\n");
	fprintf(fout,"CG1    CT     -0.30640\n");
	fprintf(fout,"HG11   HC     0.08360\n");
	fprintf(fout,"HG12   HC     0.08360\n");
	fprintf(fout,"HG13   HC     0.08360\n");
	fprintf(fout,"CG2    CT     -0.30640\n");
	fprintf(fout,"HG21   HC     0.08360\n");
	fprintf(fout,"HG22   HC     0.08360\n");
	fprintf(fout,"HG23   HC     0.08360\n");
	fprintf(fout,"C      C      0.83500\n");
	fprintf(fout,"OC1    O2     -0.81730\n");
	fprintf(fout,"OC2    O2     -0.81730\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CASN Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.20800\n");
	fprintf(fout,"HA     H1     0.13580\n");
	fprintf(fout,"CB     CT     -0.22990\n");
	fprintf(fout,"HB1    HC     0.10230\n");
	fprintf(fout,"HB2    HC     0.10230\n");
	fprintf(fout,"CG     C      0.71530\n");
	fprintf(fout,"OD1    O      -0.60100\n");
	fprintf(fout,"ND2    N      -0.90840\n");
	fprintf(fout,"HD21   H      0.41500\n");
	fprintf(fout,"HD22   H      0.41500\n");
	fprintf(fout,"C      C      0.80500\n");
	fprintf(fout,"OC1    O2     -0.81470\n");
	fprintf(fout,"OC2    O2     -0.81470\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CGLN Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.22480\n");
	fprintf(fout,"HA     H1     0.12320\n");
	fprintf(fout,"CB     CT     -0.06640\n");
	fprintf(fout,"HB1    HC     0.04520\n");
	fprintf(fout,"HB2    HC     0.04520\n");
	fprintf(fout,"CG     CT     -0.02100\n");
	fprintf(fout,"HG1    HC     0.02030\n");
	fprintf(fout,"HG2    HC     0.02030\n");
	fprintf(fout,"CD     C      0.70930\n");
	fprintf(fout,"OE1    O      -0.60980\n");
	fprintf(fout,"NE2    N      -0.95740\n");
	fprintf(fout,"HE21   H      0.43040\n");
	fprintf(fout,"HE22   H      0.43040\n");
	fprintf(fout,"C      C      0.77750\n");
	fprintf(fout,"OC1    O2     -0.80420\n");
	fprintf(fout,"OC2    O2     -0.80420\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CARG Residue\n");
	fprintf(fout,"N      N      -0.34810\n");
	fprintf(fout,"H      H      0.27640\n");
	fprintf(fout,"CA     CT     -0.30680\n");
	fprintf(fout,"HA     H1     0.14470\n");
	fprintf(fout,"CB     CT     -0.03740\n");
	fprintf(fout,"HB1    HC     0.03710\n");
	fprintf(fout,"HB2    HC     0.03710\n");
	fprintf(fout,"CG     CT     0.07440\n");
	fprintf(fout,"HG1    HC     0.01850\n");
	fprintf(fout,"HG2    HC     0.01850\n");
	fprintf(fout,"CD     CT     0.11140\n");
	fprintf(fout,"HD1    H1     0.04680\n");
	fprintf(fout,"HD2    H1     0.04680\n");
	fprintf(fout,"NE     N2     -0.55640\n");
	fprintf(fout,"HE     H      0.34790\n");
	fprintf(fout,"CZ     CA     0.83680\n");
	fprintf(fout,"NH1    N2     -0.87370\n");
	fprintf(fout,"HH11   H      0.44930\n");
	fprintf(fout,"HH12   H      0.44930\n");
	fprintf(fout,"NH2    N2     -0.87370\n");
	fprintf(fout,"HH21   H      0.44930\n");
	fprintf(fout,"HH22   H      0.44930\n");
	fprintf(fout,"C      C      0.85570\n");
	fprintf(fout,"OC1    O2     -0.82660\n");
	fprintf(fout,"OC2    O2     -0.82660\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CHID Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.17390\n");
	fprintf(fout,"HA     H1     0.11000\n");
	fprintf(fout,"CB     CT     -0.10460\n");
	fprintf(fout,"HB1    HC     0.05650\n");
	fprintf(fout,"HB2    HC     0.05650\n");
	fprintf(fout,"CG     CC     0.02930\n");
	fprintf(fout,"ND1    NA     -0.38920\n");
	fprintf(fout,"HD1    H      0.37550\n");
	fprintf(fout,"CE1    CR     0.19250\n");
	fprintf(fout,"HE1    H5     0.14180\n");
	fprintf(fout,"NE2    NB     -0.56290\n");
	fprintf(fout,"CD2    CV     0.10010\n");
	fprintf(fout,"HD2    H4     0.12410\n");
	fprintf(fout,"C      C      0.76150\n");
	fprintf(fout,"OC1    O2     -0.80160\n");
	fprintf(fout,"OC2    O2     -0.80160\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CHIE Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.26990\n");
	fprintf(fout,"HA     H1     0.16500\n");
	fprintf(fout,"CB     CT     -0.10680\n");
	fprintf(fout,"HB1    HC     0.06200\n");
	fprintf(fout,"HB2    HC     0.06200\n");
	fprintf(fout,"CG     CC     0.27240\n");
	fprintf(fout,"ND1    NB     -0.55170\n");
	fprintf(fout,"CE1    CR     0.15580\n");
	fprintf(fout,"HE1    H5     0.14480\n");
	fprintf(fout,"NE2    NA     -0.26700\n");
	fprintf(fout,"HE2    H      0.33190\n");
	fprintf(fout,"CD2    CW     -0.25880\n");
	fprintf(fout,"HD2    H4     0.19570\n");
	fprintf(fout,"C      C      0.79160\n");
	fprintf(fout,"OC1    O2     -0.80650\n");
	fprintf(fout,"OC2    O2     -0.80650\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CHIP Residue\n");
	fprintf(fout,"N      N      -0.34810\n");
	fprintf(fout,"H      H      0.27640\n");
	fprintf(fout,"CA     CT     -0.14450\n");
	fprintf(fout,"HA     H1     0.11150\n");
	fprintf(fout,"CB     CT     -0.08000\n");
	fprintf(fout,"HB1    HC     0.08680\n");
	fprintf(fout,"HB2    HC     0.08680\n");
	fprintf(fout,"CG     CC     0.02980\n");
	fprintf(fout,"ND1    NA     -0.15010\n");
	fprintf(fout,"HD1    H      0.38830\n");
	fprintf(fout,"CE1    CR     -0.02510\n");
	fprintf(fout,"HE1    H5     0.26940\n");
	fprintf(fout,"NE2    NA     -0.16830\n");
	fprintf(fout,"HE2    H      0.39130\n");
	fprintf(fout,"CD2    CW     -0.12560\n");
	fprintf(fout,"HD2    H4     0.23360\n");
	fprintf(fout,"C      C      0.80320\n");
	fprintf(fout,"OC1    O2     -0.81770\n");
	fprintf(fout,"OC2    O2     -0.81770\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CHIS Residue\n");
	fprintf(fout,"N      N      -0.34810\n");
	fprintf(fout,"H      H      0.27640\n");
	fprintf(fout,"CA     CT     -0.14450\n");
	fprintf(fout,"HA     H1     0.11150\n");
	fprintf(fout,"CB     CT     -0.08000\n");
	fprintf(fout,"HB1    HC     0.08680\n");
	fprintf(fout,"HB2    HC     0.08680\n");
	fprintf(fout,"CG     CC     0.02980\n");
	fprintf(fout,"ND1    NA     -0.15010\n");
	fprintf(fout,"HD1    H      0.38830\n");
	fprintf(fout,"CE1    CR     -0.02510\n");
	fprintf(fout,"HE1    H5     0.26940\n");
	fprintf(fout,"NE2    NA     -0.16830\n");
	fprintf(fout,"HE2    H      0.39130\n");
	fprintf(fout,"CD2    CW     -0.12560\n");
	fprintf(fout,"HD2    H4     0.23360\n");
	fprintf(fout,"C      C      0.80320\n");
	fprintf(fout,"OC1    O2     -0.81770\n");
	fprintf(fout,"OC2    O2     -0.81770\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CTRP Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.20840\n");
	fprintf(fout,"HA     H1     0.12720\n");
	fprintf(fout,"CB     CT     -0.07420\n");
	fprintf(fout,"HB1    HC     0.04970\n");
	fprintf(fout,"HB2    HC     0.04970\n");
	fprintf(fout,"CG     C*     -0.07960\n");
	fprintf(fout,"CD1    CW     -0.18080\n");
	fprintf(fout,"HD1    H4     0.20430\n");
	fprintf(fout,"NE1    NA     -0.33160\n");
	fprintf(fout,"HE1    H      0.34130\n");
	fprintf(fout,"CE2    CN     0.12220\n");
	fprintf(fout,"CZ2    CA     -0.25940\n");
	fprintf(fout,"HZ2    HA     0.15670\n");
	fprintf(fout,"CH2    CA     -0.10200\n");
	fprintf(fout,"HH2    HA     0.14010\n");
	fprintf(fout,"CZ3    CA     -0.22870\n");
	fprintf(fout,"HZ3    HA     0.15070\n");
	fprintf(fout,"CE3    CA     -0.18370\n");
	fprintf(fout,"HE3    HA     0.14910\n");
	fprintf(fout,"CD2    CB     0.10780\n");
	fprintf(fout,"C      C      0.76580\n");
	fprintf(fout,"OC1    O2     -0.80110\n");
	fprintf(fout,"OC2    O2     -0.80110\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CPHE Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.18250\n");
	fprintf(fout,"HA     H1     0.10980\n");
	fprintf(fout,"CB     CT     -0.09590\n");
	fprintf(fout,"HB1    HC     0.04430\n");
	fprintf(fout,"HB2    HC     0.04430\n");
	fprintf(fout,"CG     CA     0.05520\n");
	fprintf(fout,"CD1    CA     -0.13000\n");
	fprintf(fout,"HD1    HA     0.14080\n");
	fprintf(fout,"CE1    CA     -0.18470\n");
	fprintf(fout,"HE1    HA     0.14610\n");
	fprintf(fout,"CZ     CA     -0.09440\n");
	fprintf(fout,"HZ     HA     0.12800\n");
	fprintf(fout,"CE2    CA     -0.18470\n");
	fprintf(fout,"HE2    HA     0.14610\n");
	fprintf(fout,"CD2    CA     -0.13000\n");
	fprintf(fout,"HD2    HA     0.14080\n");
	fprintf(fout,"C      C      0.76600\n");
	fprintf(fout,"OC1    O2     -0.80260\n");
	fprintf(fout,"OC2    O2     -0.80260\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CTYR Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.20150\n");
	fprintf(fout,"HA     H1     0.10920\n");
	fprintf(fout,"CB     CT     -0.07520\n");
	fprintf(fout,"HB1    HC     0.04900\n");
	fprintf(fout,"HB2    HC     0.04900\n");
	fprintf(fout,"CG     CA     0.02430\n");
	fprintf(fout,"CD1    CA     -0.19220\n");
	fprintf(fout,"HD1    HA     0.17800\n");
	fprintf(fout,"CE1    CA     -0.24580\n");
	fprintf(fout,"HE1    HA     0.16730\n");
	fprintf(fout,"CZ     C      0.33950\n");
	fprintf(fout,"OH     OH     -0.56430\n");
	fprintf(fout,"HH     HO     0.40170\n");
	fprintf(fout,"CE2    CA     -0.24580\n");
	fprintf(fout,"HE2    HA     0.16730\n");
	fprintf(fout,"CD2    CA     -0.19220\n");
	fprintf(fout,"HD2    HA     0.17800\n");
	fprintf(fout,"C      C      0.78170\n");
	fprintf(fout,"OC1    O2     -0.80700\n");
	fprintf(fout,"OC2    O2     -0.80700\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CGLU Residue\n");
	fprintf(fout,"N      N      -0.51920\n");
	fprintf(fout,"H      H      0.30550\n");
	fprintf(fout,"CA     CT     -0.20590\n");
	fprintf(fout,"HA     H1     0.13990\n");
	fprintf(fout,"CB     CT     0.00710\n");
	fprintf(fout,"HB1    HC     -0.00780\n");
	fprintf(fout,"HB2    HC     -0.00780\n");
	fprintf(fout,"CG     CT     0.06750\n");
	fprintf(fout,"HG1    HC     -0.05480\n");
	fprintf(fout,"HG2    HC     -0.05480\n");
	fprintf(fout,"CD     C      0.81830\n");
	fprintf(fout,"OE1    O2     -0.82200\n");
	fprintf(fout,"OE2    O2     -0.82200\n");
	fprintf(fout,"C      C      0.74200\n");
	fprintf(fout,"OC1    O2     -0.79300\n");
	fprintf(fout,"OC2    O2     -0.79300\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CASP Residue\n");
	fprintf(fout,"N      N      -0.51920\n");
	fprintf(fout,"H      H      0.30550\n");
	fprintf(fout,"CA     CT     -0.18170\n");
	fprintf(fout,"HA     H1     0.10460\n");
	fprintf(fout,"CB     CT     -0.06770\n");
	fprintf(fout,"HB1    HC     -0.02120\n");
	fprintf(fout,"HB2    HC     -0.02120\n");
	fprintf(fout,"CG     C      0.88510\n");
	fprintf(fout,"OD1    O2     -0.81620\n");
	fprintf(fout,"OD2    O2     -0.81620\n");
	fprintf(fout,"C      C      0.72560\n");
	fprintf(fout,"OC1    O2     -0.78870\n");
	fprintf(fout,"OC2    O2     -0.78870\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CLYS Residue\n");
	fprintf(fout,"N      N      -0.34810\n");
	fprintf(fout,"H      H      0.27640\n");
	fprintf(fout,"CA     CT     -0.29030\n");
	fprintf(fout,"HA     H1     0.14380\n");
	fprintf(fout,"CB     CT     -0.05380\n");
	fprintf(fout,"HB1    HC     0.04820\n");
	fprintf(fout,"HB2    HC     0.04820\n");
	fprintf(fout,"CG     CT     0.02270\n");
	fprintf(fout,"HG1    HC     0.01340\n");
	fprintf(fout,"HG2    HC     0.01340\n");
	fprintf(fout,"CD     CT     -0.03920\n");
	fprintf(fout,"HD1    HC     0.06110\n");
	fprintf(fout,"HD2    HC     0.06110\n");
	fprintf(fout,"CE     CT     -0.01760\n");
	fprintf(fout,"HE1    HP     0.11210\n");
	fprintf(fout,"HE2    HP     0.11210\n");
	fprintf(fout,"NZ     N3     -0.37410\n");
	fprintf(fout,"HZ1    H      0.33740\n");
	fprintf(fout,"HZ2    H      0.33740\n");
	fprintf(fout,"HZ3    H      0.33740\n");
	fprintf(fout,"C      C      0.84880\n");
	fprintf(fout,"OC1    O2     -0.82520\n");
	fprintf(fout,"OC2    O2     -0.82520\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CLYP Residue\n");
	fprintf(fout,"N      N      -0.34810\n");
	fprintf(fout,"H      H      0.27640\n");
	fprintf(fout,"CA     CT     -0.29030\n");
	fprintf(fout,"HA     H1     0.14380\n");
	fprintf(fout,"CB     CT     -0.05380\n");
	fprintf(fout,"HB1    HC     0.04820\n");
	fprintf(fout,"HB2    HC     0.04820\n");
	fprintf(fout,"CG     CT     0.02270\n");
	fprintf(fout,"HG1    HC     0.01340\n");
	fprintf(fout,"HG2    HC     0.01340\n");
	fprintf(fout,"CD     CT     -0.03920\n");
	fprintf(fout,"HD1    HC     0.06110\n");
	fprintf(fout,"HD2    HC     0.06110\n");
	fprintf(fout,"CE     CT     -0.01760\n");
	fprintf(fout,"HE1    HP     0.11210\n");
	fprintf(fout,"HE2    HP     0.11210\n");
	fprintf(fout,"NZ     N3     -0.37410\n");
	fprintf(fout,"HZ1    H      0.33740\n");
	fprintf(fout,"HZ2    H      0.33740\n");
	fprintf(fout,"HZ3    H      0.33740\n");
	fprintf(fout,"C      C      0.84880\n");
	fprintf(fout,"OC1    O2     -0.82520\n");
	fprintf(fout,"OC2    O2     -0.82520\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CPRO Residue\n");
	fprintf(fout,"N      N      -0.28020\n");
	fprintf(fout,"CD     CT     0.04340\n");
	fprintf(fout,"HD1    H1     0.03310\n");
	fprintf(fout,"HD2    H1     0.03310\n");
	fprintf(fout,"CG     CT     0.04660\n");
	fprintf(fout,"HG1    HC     0.01720\n");
	fprintf(fout,"HG2    HC     0.01720\n");
	fprintf(fout,"CB     CT     -0.05430\n");
	fprintf(fout,"HB1    HC     0.03810\n");
	fprintf(fout,"HB2    HC     0.03810\n");
	fprintf(fout,"CA     CT     -0.13360\n");
	fprintf(fout,"HA     H1     0.07760\n");
	fprintf(fout,"C      C      0.66310\n");
	fprintf(fout,"OC1    O2     -0.76970\n");
	fprintf(fout,"OC2    O2     -0.76970\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CCYS Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.16350\n");
	fprintf(fout,"HA     H1     0.13960\n");
	fprintf(fout,"CB     CT     -0.19960\n");
	fprintf(fout,"HB1    H1     0.14370\n");
	fprintf(fout,"HB2    H1     0.14370\n");
	fprintf(fout,"SG     SH     -0.31020\n");
	fprintf(fout,"HG     HS     0.20680\n");
	fprintf(fout,"C      C      0.74970\n");
	fprintf(fout,"OC1    O2     -0.79810\n");
	fprintf(fout,"OC2    O2     -0.79810\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CCYN Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.16350\n");
	fprintf(fout,"HA     H1     0.13960\n");
	fprintf(fout,"CB     CT     -0.19960\n");
	fprintf(fout,"HB1    H1     0.14370\n");
	fprintf(fout,"HB2    H1     0.14370\n");
	fprintf(fout,"SG     SH     -0.31020\n");
	fprintf(fout,"HG     HS     0.20680\n");
	fprintf(fout,"C      C      0.74970\n");
	fprintf(fout,"OC1    O2     -0.79810\n");
	fprintf(fout,"OC2    O2     -0.79810\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CCYX Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.13180\n");
	fprintf(fout,"HA     H1     0.09380\n");
	fprintf(fout,"CB     CT     -0.19430\n");
	fprintf(fout,"HB1    H1     0.12280\n");
	fprintf(fout,"HB2    H1     0.12280\n");
	fprintf(fout,"SG     S      -0.05290\n");
	fprintf(fout,"C      C      0.76180\n");
	fprintf(fout,"OC1    O2     -0.80410\n");
	fprintf(fout,"OC2    O2     -0.80410\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CCYM Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.28470\n");
	fprintf(fout,"HA     H1     0.13460\n");
	fprintf(fout,"CB     CT     -0.24130\n");
	fprintf(fout,"HB1    H1     0.11220\n");
	fprintf(fout,"HB2    H1     0.11220\n");
	fprintf(fout,"SG     SH     -0.88440\n");
	fprintf(fout,"C      C      0.83260\n");
	fprintf(fout,"OC1    O2     -0.83360\n");
	fprintf(fout,"OC2    O2     -0.83360\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CMET Residue\n");
	fprintf(fout,"N      N      -0.38210\n");
	fprintf(fout,"H      H      0.26810\n");
	fprintf(fout,"CA     CT     -0.25970\n");
	fprintf(fout,"HA     H1     0.12770\n");
	fprintf(fout,"CB     CT     -0.02360\n");
	fprintf(fout,"HB1    HC     0.04800\n");
	fprintf(fout,"HB2    HC     0.04800\n");
	fprintf(fout,"CG     CT     0.04920\n");
	fprintf(fout,"HG1    H1     0.03170\n");
	fprintf(fout,"HG2    H1     0.03170\n");
	fprintf(fout,"SD     S      -0.26920\n");
	fprintf(fout,"CE     CT     -0.03760\n");
	fprintf(fout,"HE1    H1     0.06250\n");
	fprintf(fout,"HE2    H1     0.06250\n");
	fprintf(fout,"HE3    H1     0.06250\n");
	fprintf(fout,"C      C      0.80130\n");
	fprintf(fout,"OC1    O2     -0.81050\n");
	fprintf(fout,"OC2    O2     -0.81050\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CASH Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.163500\n");
	fprintf(fout,"HA     H1     0.13310\n");
	fprintf(fout,"CA     CT     -0.16350\n");
	fprintf(fout,"HA     H1     0.13960\n");
	fprintf(fout,"CB     CT     -0.03160\n");
	fprintf(fout,"HB1    HC     0.04880\n");
	fprintf(fout,"HB2    HC     0.04880\n");
	fprintf(fout,"CG     C      0.64620\n");
	fprintf(fout,"OD1    O      -0.55540\n");
	fprintf(fout,"OD2    OH     -0.63760\n");
	fprintf(fout,"HD2    HO     0.47470\n");
	fprintf(fout,"C      C      0.80130\n");
	fprintf(fout,"OC1    O2     -0.81050\n");
	fprintf(fout,"OC2    O2     -0.81050\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CGLH Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.163500\n");
	fprintf(fout,"HA     H1     0.105000\n");
	fprintf(fout,"CB     CT     -0.00710\n");
	fprintf(fout,"HB1    HC     0.02560\n");
	fprintf(fout,"HB2    HC     0.02560\n");
	fprintf(fout,"CG     CT     -0.01740\n");
	fprintf(fout,"HG1    HC     0.04300\n");
	fprintf(fout,"HG2    HC     0.04300\n");
	fprintf(fout,"CD     C      0.68010\n");
	fprintf(fout,"OE1    O      -0.58380\n");
	fprintf(fout,"OE2    OH     -0.65110\n");
	fprintf(fout,"HE2    HO     0.46410\n");
	fprintf(fout,"C      C      0.80130\n");
	fprintf(fout,"OC1    O2     -0.81050\n");
	fprintf(fout,"OC2    O2     -0.81050\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin CLYN Residue\n");
	fprintf(fout,"N      N      -0.41570\n");
	fprintf(fout,"H      H      0.27190\n");
	fprintf(fout,"CA     CT     -0.163500\n");
	fprintf(fout,"HA     H1     0.03994\n");
	fprintf(fout,"CB     CT     -0.04845\n");
	fprintf(fout,"HB1    HC     0.03400\n");
	fprintf(fout,"HB2    HC     0.03400\n");
	fprintf(fout,"CG     CT     0.06612\n");
	fprintf(fout,"HG1    HC     0.01041\n");
	fprintf(fout,"HG2    HC     0.01041\n");
	fprintf(fout,"CD     CT     -0.03768\n");
	fprintf(fout,"HD1    HC     0.01155\n");
	fprintf(fout,"HD2    HC     0.01155\n");
	fprintf(fout,"CE     CT     0.32604\n");
	fprintf(fout,"HE1    HP     -0.03358\n");
	fprintf(fout,"HE2    HP     -0.03358\n");
	fprintf(fout,"NZ     N3     -1.03581\n");
	fprintf(fout,"HZ1    H      0.38604\n");
	fprintf(fout,"HZ2    H      0.38604\n");
	fprintf(fout,"C      C      0.80130\n");
	fprintf(fout,"OC1    O2     -0.81050\n");
	fprintf(fout,"OC2    O2     -0.81050\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin OALA Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	0.033700\n");
	fprintf(fout,"HA 	H1	0.082300\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	-0.182500\n");
	fprintf(fout,"HB1 	HC	0.060300\n");
	fprintf(fout,"HB2 	HC	0.060300\n");
	fprintf(fout,"HB3 	HC	0.060300\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OARG Residue\n");
	fprintf(fout,"N 	N	-0.347900\n");
	fprintf(fout,"H 	H	0.274700\n");
	fprintf(fout,"CA 	CT	-0.263700\n");
	fprintf(fout,"HA 	H1	0.156000\n");
	fprintf(fout,"C 	C	0.704557\n");
	fprintf(fout,"O 	O	-0.501460\n");
	fprintf(fout,"CB 	CT	-0.000700\n");
	fprintf(fout,"HB1 	HC	0.032700\n");
	fprintf(fout,"HB2 	HC	0.032700\n");
	fprintf(fout,"CG 	CT	0.039000\n");
	fprintf(fout,"HG1 	HC	0.028500\n");
	fprintf(fout,"HG2 	HC	0.028500\n");
	fprintf(fout,"CD 	CT	0.048600\n");
	fprintf(fout,"HD1 	H1	0.068700\n");
	fprintf(fout,"HD2 	H1	0.068700\n");
	fprintf(fout,"NE 	N2	-0.529500\n");
	fprintf(fout,"HE 	H	0.345600\n");
	fprintf(fout,"CZ 	CA	0.807600\n");
	fprintf(fout,"NH1 	N2	-0.862700\n");
	fprintf(fout,"HH11 	H	0.447800\n");
	fprintf(fout,"HH12 	H	0.447800\n");
	fprintf(fout,"NH2 	N2	-0.862700\n");
	fprintf(fout,"HH21 	H	0.447800\n");
	fprintf(fout,"HH22 	H	0.447800\n");
	fprintf(fout,"OH 	OH	-0.576454\n");
	fprintf(fout,"HO 	HO	0.518057\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OASN Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	0.014300\n");
	fprintf(fout,"HA 	H1	0.104800\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	-0.204100\n");
	fprintf(fout,"HB1 	HC	0.079700\n");
	fprintf(fout,"HB2 	HC	0.079700\n");
	fprintf(fout,"CG 	C	0.713000\n");
	fprintf(fout,"OD1 	O	-0.593100\n");
	fprintf(fout,"ND2 	N	-0.919100\n");
	fprintf(fout,"HD21 	H	0.419600\n");
	fprintf(fout,"HD22 	H	0.419600\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OASP Residue\n");
	fprintf(fout,"N 	N	-0.516300\n");
	fprintf(fout,"H 	H	0.293600\n");
	fprintf(fout,"CA 	CT	0.038100\n");
	fprintf(fout,"HA 	H1	0.088000\n");
	fprintf(fout,"C 	C	0.653215\n");
	fprintf(fout,"O 	O	-0.548403\n");
	fprintf(fout,"CB 	CT	-0.030300\n");
	fprintf(fout,"HB1 	HC	-0.012200\n");
	fprintf(fout,"HB2 	HC	-0.012200\n");
	fprintf(fout,"CG 	C	0.799400\n");
	fprintf(fout,"OD1 	O2	-0.801400\n");
	fprintf(fout,"OD2 	O2	-0.801400\n");
	fprintf(fout,"OH 	OH	-0.630417\n");
	fprintf(fout,"HO 	HO	0.480305\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OCYS Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	0.021300\n");
	fprintf(fout,"HA 	H1	0.112400\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	-0.123100\n");
	fprintf(fout,"HB1 	H1	0.111200\n");
	fprintf(fout,"HB2 	H1	0.111200\n");
	fprintf(fout,"SG 	SH	-0.311900\n");
	fprintf(fout,"HG 	HS	0.193300\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OCYX Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	0.042900\n");
	fprintf(fout,"HA 	H1	0.076600\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	-0.079000\n");
	fprintf(fout,"HB1 	H1	0.091000\n");
	fprintf(fout,"HB2 	H1	0.091000\n");
	fprintf(fout,"SG 	S	-0.108100\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OGLN Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	-0.003100\n");
	fprintf(fout,"HA 	H1	0.085000\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	-0.003600\n");
	fprintf(fout,"HB1 	HC	0.017100\n");
	fprintf(fout,"HB2 	HC	0.017100\n");
	fprintf(fout,"CG 	CT	-0.064500\n");
	fprintf(fout,"HG1 	HC	0.035200\n");
	fprintf(fout,"HG2 	HC	0.035200\n");
	fprintf(fout,"CD 	C	0.695100\n");
	fprintf(fout,"OE1 	O	-0.608600\n");
	fprintf(fout,"NE2 	N	-0.940700\n");
	fprintf(fout,"HE21 	H	0.425100\n");
	fprintf(fout,"HE22 	H	0.425100\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OGLU Residue\n");
	fprintf(fout,"N 	N	-0.516300\n");
	fprintf(fout,"H 	H	0.293600\n");
	fprintf(fout,"CA 	CT	0.039700\n");
	fprintf(fout,"HA 	H1	0.110500\n");
	fprintf(fout,"C 	C	0.653215\n");
	fprintf(fout,"O 	O	-0.548403\n");
	fprintf(fout,"CB 	CT	0.056000\n");
	fprintf(fout,"HB1 	HC	-0.017300\n");
	fprintf(fout,"HB2 	HC	-0.017300\n");
	fprintf(fout,"CG 	CT	0.013600\n");
	fprintf(fout,"HG1 	HC	-0.042500\n");
	fprintf(fout,"HG2 	HC	-0.042500\n");
	fprintf(fout,"CD 	C	0.805400\n");
	fprintf(fout,"OE1 	O2	-0.818800\n");
	fprintf(fout,"OE2 	O2	-0.818800\n");
	fprintf(fout,"OH 	OH	-0.630417\n");
	fprintf(fout,"HO 	HO	0.480305\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OGLY Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	-0.025200\n");
	fprintf(fout,"HA1 	H1	0.069800\n");
	fprintf(fout,"HA2 	H1	0.069800\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OHID Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	0.018800\n");
	fprintf(fout,"HA 	H1	0.088100\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	-0.046200\n");
	fprintf(fout,"HB1 	HC	0.040200\n");
	fprintf(fout,"HB2 	HC	0.040200\n");
	fprintf(fout,"CG 	CC	-0.026600\n");
	fprintf(fout,"ND1 	NA	-0.381100\n");
	fprintf(fout,"HD1 	H	0.364900\n");
	fprintf(fout,"CD2 	CV	0.129200\n");
	fprintf(fout,"HD2 	H4	0.114700\n");
	fprintf(fout,"CE1 	CR	0.205700\n");
	fprintf(fout,"HE1 	H5	0.139200\n");
	fprintf(fout,"NE2 	NB	-0.572700\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OHIE Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	-0.058100\n");
	fprintf(fout,"HA 	H1	0.136000\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	-0.007400\n");
	fprintf(fout,"HB1 	HC	0.036700\n");
	fprintf(fout,"HB2 	HC	0.036700\n");
	fprintf(fout,"CG 	CC	0.186800\n");
	fprintf(fout,"ND1 	NB	-0.543200\n");
	fprintf(fout,"CD2 	CW	-0.220700\n");
	fprintf(fout,"HD2 	H4	0.186200\n");
	fprintf(fout,"CE1 	CR	0.163500\n");
	fprintf(fout,"HE1 	H5	0.143500\n");
	fprintf(fout,"NE2 	NA	-0.279500\n");
	fprintf(fout,"HE2 	H	0.333900\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OHIP Residue\n");
	fprintf(fout,"N 	N	-0.347900\n");
	fprintf(fout,"H 	H	0.274700\n");
	fprintf(fout,"CA 	CT	-0.135400\n");
	fprintf(fout,"HA 	H1	0.121200\n");
	fprintf(fout,"C 	C	0.704557\n");
	fprintf(fout,"O 	O	-0.501460\n");
	fprintf(fout,"CB 	CT	-0.041400\n");
	fprintf(fout,"HB1 	HC	0.081000\n");
	fprintf(fout,"HB2 	HC	0.081000\n");
	fprintf(fout,"CG 	CC	-0.001200\n");
	fprintf(fout,"ND1 	NA	-0.151300\n");
	fprintf(fout,"HD1 	H	0.386600\n");
	fprintf(fout,"CD2 	CW	-0.114100\n");
	fprintf(fout,"HD2 	H4	0.231700\n");
	fprintf(fout,"CE1 	CR	-0.017000\n");
	fprintf(fout,"HE1 	H5	0.268100\n");
	fprintf(fout,"NE2 	NA	-0.171800\n");
	fprintf(fout,"HE2 	H	0.391100\n");
	fprintf(fout,"OH 	OH	-0.576454\n");
	fprintf(fout,"HO 	HO	0.518057\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OHIS Residue\n");
	fprintf(fout,"N 	N	-0.347900\n");
	fprintf(fout,"H 	H	0.274700\n");
	fprintf(fout,"CA 	CT	-0.135400\n");
	fprintf(fout,"HA 	H1	0.121200\n");
	fprintf(fout,"C 	C	0.704557\n");
	fprintf(fout,"O 	O	-0.501460\n");
	fprintf(fout,"CB 	CT	-0.041400\n");
	fprintf(fout,"HB1 	HC	0.081000\n");
	fprintf(fout,"HB2 	HC	0.081000\n");
	fprintf(fout,"CG 	CC	-0.001200\n");
	fprintf(fout,"ND1 	NA	-0.151300\n");
	fprintf(fout,"HD1 	H	0.386600\n");
	fprintf(fout,"CD2 	CW	-0.114100\n");
	fprintf(fout,"HD2 	H4	0.231700\n");
	fprintf(fout,"CE1 	CR	-0.017000\n");
	fprintf(fout,"HE1 	H5	0.268100\n");
	fprintf(fout,"NE2 	NA	-0.171800\n");
	fprintf(fout,"HE2 	H	0.391100\n");
	fprintf(fout,"OH 	OH	-0.576454\n");
	fprintf(fout,"HO 	HO	0.518057\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OILE Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	-0.059700\n");
	fprintf(fout,"HA 	H1	0.086900\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	0.130300\n");
	fprintf(fout,"HB 	HC	0.018700\n");
	fprintf(fout,"CG1 	CT	-0.043000\n");
	fprintf(fout,"HG11 	HC	0.023600\n");
	fprintf(fout,"HG12 	HC	0.023600\n");
	fprintf(fout,"CG2 	CT	-0.320400\n");
	fprintf(fout,"HG21 	HC	0.088200\n");
	fprintf(fout,"HG22 	HC	0.088200\n");
	fprintf(fout,"HG23 	HC	0.088200\n");
	fprintf(fout,"CD 	CT	-0.066000\n");
	fprintf(fout,"HD1 	HC	0.018600\n");
	fprintf(fout,"HD2 	HC	0.018600\n");
	fprintf(fout,"HD3 	HC	0.018600\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OLEU Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	-0.051800\n");
	fprintf(fout,"HA 	H1	0.092200\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	-0.110200\n");
	fprintf(fout,"HB1 	HC	0.045700\n");
	fprintf(fout,"HB2 	HC	0.045700\n");
	fprintf(fout,"CG 	CT	0.353100\n");
	fprintf(fout,"HG 	HC	-0.036100\n");
	fprintf(fout,"CD1 	CT	-0.412100\n");
	fprintf(fout,"HD11 	HC	0.100000\n");
	fprintf(fout,"HD12 	HC	0.100000\n");
	fprintf(fout,"HD13 	HC	0.100000\n");
	fprintf(fout,"CD2 	CT	-0.412100\n");
	fprintf(fout,"HD21 	HC	0.100000\n");
	fprintf(fout,"HD22 	HC	0.100000\n");
	fprintf(fout,"HD23 	HC	0.100000\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OLYS Residue\n");
	fprintf(fout,"N 	N	-0.347900\n");
	fprintf(fout,"H 	H	0.274700\n");
	fprintf(fout,"CA 	CT	-0.240000\n");
	fprintf(fout,"HA 	H1	0.142600\n");
	fprintf(fout,"C 	C	0.704557\n");
	fprintf(fout,"O 	O	-0.501460\n");
	fprintf(fout,"CB 	CT	-0.009400\n");
	fprintf(fout,"HB1 	HC	0.036200\n");
	fprintf(fout,"HB2 	HC	0.036200\n");
	fprintf(fout,"CG 	CT	0.018700\n");
	fprintf(fout,"HG1 	HC	0.010300\n");
	fprintf(fout,"HG2 	HC	0.010300\n");
	fprintf(fout,"CD 	CT	-0.047900\n");
	fprintf(fout,"HD1 	HC	0.062100\n");
	fprintf(fout,"HD2 	HC	0.062100\n");
	fprintf(fout,"CE 	CT	-0.014300\n");
	fprintf(fout,"HE1 	HP	0.113500\n");
	fprintf(fout,"HE2 	HP	0.113500\n");
	fprintf(fout,"NZ 	N3	-0.385400\n");
	fprintf(fout,"HZ1 	H	0.340000\n");
	fprintf(fout,"HZ2 	H	0.340000\n");
	fprintf(fout,"HZ3 	H	0.340000\n");
	fprintf(fout,"OH 	OH	-0.576454\n");
	fprintf(fout,"HO 	HO	0.518057\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OMET Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	-0.023700\n");
	fprintf(fout,"HA 	H1	0.088000\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	0.034200\n");
	fprintf(fout,"HB1 	HC	0.024100\n");
	fprintf(fout,"HB2 	HC	0.024100\n");
	fprintf(fout,"CG 	CT	0.001800\n");
	fprintf(fout,"HG1 	H1	0.044000\n");
	fprintf(fout,"HG2 	H1	0.044000\n");
	fprintf(fout,"SD 	S	-0.273700\n");
	fprintf(fout,"CE 	CT	-0.053600\n");
	fprintf(fout,"HE1 	H1	0.068400\n");
	fprintf(fout,"HE2 	H1	0.068400\n");
	fprintf(fout,"HE3 	H1	0.068400\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OPHE Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	-0.002400\n");
	fprintf(fout,"HA 	H1	0.097800\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	-0.034300\n");
	fprintf(fout,"HB1 	HC	0.029500\n");
	fprintf(fout,"HB2 	HC	0.029500\n");
	fprintf(fout,"CG 	CA	0.011800\n");
	fprintf(fout,"CD1 	CA	-0.125600\n");
	fprintf(fout,"HD1 	HA	0.133000\n");
	fprintf(fout,"CD2 	CA	-0.125600\n");
	fprintf(fout,"HD2 	HA	0.133000\n");
	fprintf(fout,"CE1 	CA	-0.170400\n");
	fprintf(fout,"HE1 	HA	0.143000\n");
	fprintf(fout,"CE2 	CA	-0.170400\n");
	fprintf(fout,"HE2 	HA	0.143000\n");
	fprintf(fout,"CZ 	CA	-0.107200\n");
	fprintf(fout,"HZ 	HA	0.129700\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OPRO Residue\n");
	fprintf(fout,"N 	N	-0.254800\n");
	fprintf(fout,"CA 	CT	-0.026600\n");
	fprintf(fout,"HA 	H1	0.064100\n");
	fprintf(fout,"C 	C	0.669455\n");
	fprintf(fout,"O 	O	-0.533554\n");
	fprintf(fout,"CB 	CT	-0.007000\n");
	fprintf(fout,"HB1 	HC	0.025300\n");
	fprintf(fout,"HB2 	HC	0.025300\n");
	fprintf(fout,"CG 	CT	0.018900\n");
	fprintf(fout,"HG1 	HC	0.021300\n");
	fprintf(fout,"HG2 	HC	0.021300\n");
	fprintf(fout,"CD 	CT	0.019200\n");
	fprintf(fout,"HD1 	H1	0.039100\n");
	fprintf(fout,"HD2 	H1	0.039100\n");
	fprintf(fout,"OH 	OH	-0.613347\n");
	fprintf(fout,"HO 	HO	0.492247\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OSER Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	-0.024900\n");
	fprintf(fout,"HA 	H1	0.084300\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	0.211700\n");
	fprintf(fout,"HB1 	H1	0.035200\n");
	fprintf(fout,"HB2 	H1	0.035200\n");
	fprintf(fout,"OG 	OH	-0.654600\n");
	fprintf(fout,"HG 	HO	0.427500\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OTHR Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	-0.038900\n");
	fprintf(fout,"HA 	H1	0.100700\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	0.365400\n");
	fprintf(fout,"HB 	H1	0.004300\n");
	fprintf(fout,"OG1 	OH	-0.676100\n");
	fprintf(fout,"HG1 	HO	0.410200\n");
	fprintf(fout,"CG2 	CT	-0.243800\n");
	fprintf(fout,"HG21 	HC	0.064200\n");
	fprintf(fout,"HG22 	HC	0.064200\n");
	fprintf(fout,"HG23 	HC	0.064200\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OTYR Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	-0.001400\n");
	fprintf(fout,"HA 	H1	0.087600\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	-0.015200\n");
	fprintf(fout,"HB1 	HC	0.029500\n");
	fprintf(fout,"HB2 	HC	0.029500\n");
	fprintf(fout,"CG 	CA	-0.001100\n");
	fprintf(fout,"CD1 	CA	-0.190600\n");
	fprintf(fout,"HD1 	HA	0.169900\n");
	fprintf(fout,"CD2 	CA	-0.190600\n");
	fprintf(fout,"HD2 	HA	0.169900\n");
	fprintf(fout,"CE1 	CA	-0.234100\n");
	fprintf(fout,"HE1 	HA	0.165600\n");
	fprintf(fout,"CE2 	CA	-0.234100\n");
	fprintf(fout,"HE2 	HA	0.165600\n");
	fprintf(fout,"CZ 	C	0.322600\n");
	fprintf(fout,"OH 	OH	-0.557900\n");
	fprintf(fout,"HH 	HO	0.399200\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OTRP Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	-0.027500\n");
	fprintf(fout,"HA 	H1	0.112300\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	-0.005000\n");
	fprintf(fout,"HB1 	HC	0.033900\n");
	fprintf(fout,"HB2 	HC	0.033900\n");
	fprintf(fout,"CG 	C*	-0.141500\n");
	fprintf(fout,"CD1 	CW	-0.163800\n");
	fprintf(fout,"HD1 	H4	0.206200\n");
	fprintf(fout,"CD2 	CB	0.124300\n");
	fprintf(fout,"NE1 	NA	-0.341800\n");
	fprintf(fout,"HE1 	H	0.341200\n");
	fprintf(fout,"CE2 	CN	0.138000\n");
	fprintf(fout,"CE3 	CA	-0.238700\n");
	fprintf(fout,"HE3 	HA	0.170000\n");
	fprintf(fout,"CZ2 	CA	-0.260100\n");
	fprintf(fout,"HZ2 	HA	0.157200\n");
	fprintf(fout,"CZ3 	CA	-0.197200\n");
	fprintf(fout,"HZ3 	HA	0.144700\n");
	fprintf(fout,"CH2 	CA	-0.113400\n");
	fprintf(fout,"HH2 	HA	0.141700\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OVAL Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	-0.087500\n");
	fprintf(fout,"HA 	H1	0.096900\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	0.298500\n");
	fprintf(fout,"HB 	HC	-0.029700\n");
	fprintf(fout,"CG1 	CT	-0.319200\n");
	fprintf(fout,"HG11 	HC	0.079100\n");
	fprintf(fout,"HG12 	HC	0.079100\n");
	fprintf(fout,"HG13 	HC	0.079100\n");
	fprintf(fout,"CG2 	CT	-0.319200\n");
	fprintf(fout,"HG21 	HC	0.079100\n");
	fprintf(fout,"HG22 	HC	0.079100\n");
	fprintf(fout,"HG23 	HC	0.079100\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OASH Residue\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"HB2 	HC	0.048800\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"CA 	CT	0.034100\n");
	fprintf(fout,"CB 	CT	-0.031600\n");
	fprintf(fout,"OD1 	O	-0.555400\n");
	fprintf(fout,"HB1 	HC	0.048800\n");
	fprintf(fout,"CG 	C	0.646200\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"HA 	H1	0.086400\n");
	fprintf(fout,"OD2 	OH	-0.637600\n");
	fprintf(fout,"HD2 	HO	0.474700\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OGLH Residue\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"HB2 	HC	0.025600\n");
	fprintf(fout,"HB1 	HC	0.025600\n");
	fprintf(fout,"CB 	CT	-0.007100\n");
	fprintf(fout,"CA 	CT	0.014500\n");
	fprintf(fout,"HE2 	HO	0.464100\n");
	fprintf(fout,"OE2 	OH	-0.651100\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"HA 	H1	0.077900\n");
	fprintf(fout,"CD 	C	0.680100\n");
	fprintf(fout,"OE1 	O	-0.583800\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"CG 	CT	-0.017400\n");
	fprintf(fout,"HG1 	HC	0.043000\n");
	fprintf(fout,"HG2 	HC	0.043000\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OLYN Residue\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"HB2 	HC	0.034000\n");
	fprintf(fout,"HD2 	HC	0.011550\n");
	fprintf(fout,"HB1 	HC	0.034000\n");
	fprintf(fout,"HD1 	HC	0.011550\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"CB 	CT	-0.048450\n");
	fprintf(fout,"CD 	CT	-0.037680\n");
	fprintf(fout,"CA 	CT	-0.072060\n");
	fprintf(fout,"CG 	CT	0.066120\n");
	fprintf(fout,"HE2 	HP	-0.033580\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"HZ1 	H	0.386040\n");
	fprintf(fout,"CE 	CT	0.326040\n");
	fprintf(fout,"NZ 	N3	-1.035810\n");
	fprintf(fout,"HG1 	HC	0.010410\n");
	fprintf(fout,"HG2 	HC	0.010410\n");
	fprintf(fout,"HA 	H1	0.099400\n");
	fprintf(fout,"HZ2 	H	0.386040\n");
	fprintf(fout,"HE1 	HP	-0.033580\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin OCYM Residue\n");
	fprintf(fout,"N 	N	-0.415700\n");
	fprintf(fout,"H 	H	0.271900\n");
	fprintf(fout,"CA 	CT	-0.035100\n");
	fprintf(fout,"HA 	H1	0.050800\n");
	fprintf(fout,"C 	C	0.673401\n");
	fprintf(fout,"O 	O	-0.529947\n");
	fprintf(fout,"CB 	CT	-0.241300\n");
	fprintf(fout,"HB1 	H1	0.112200\n");
	fprintf(fout,"HB2 	H1	0.112200\n");
	fprintf(fout,"SG 	SH	-0.884400\n");
	fprintf(fout,"OH 	OH	-0.609201\n");
	fprintf(fout,"HO 	HO	0.495147\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NALA Residue\n");
	fprintf(fout,"N      N3     0.14140\n");
	fprintf(fout,"H1     H      0.19970\n");
	fprintf(fout,"H2     H      0.19970\n");
	fprintf(fout,"H3     H      0.19970\n");
	fprintf(fout,"CA     CT     0.09620\n");
	fprintf(fout,"HA     HP     0.08890\n");
	fprintf(fout,"CB     CT     -0.05970\n");
	fprintf(fout,"HB1    HC     0.03000\n");
	fprintf(fout,"HB2    HC     0.03000\n");
	fprintf(fout,"HB3    HC     0.03000\n");
	fprintf(fout,"C      C      0.61630\n");
	fprintf(fout,"O      O      -0.57220\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NGLY Residue\n");
	fprintf(fout,"N      N3     0.29430\n");
	fprintf(fout,"H1     H      0.16420\n");
	fprintf(fout,"H2     H      0.16420\n");
	fprintf(fout,"H3     H      0.16420\n");
	fprintf(fout,"CA     CT     -0.01000\n");
	fprintf(fout,"HA1    HP     0.08950\n");
	fprintf(fout,"HA2    HP     0.08950\n");
	fprintf(fout,"C      C      0.61630\n");
	fprintf(fout,"O      O      -0.57220\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NSER Residue\n");
	fprintf(fout,"N      N3     0.18490\n");
	fprintf(fout,"H1     H      0.18980\n");
	fprintf(fout,"H2     H      0.18980\n");
	fprintf(fout,"H3     H      0.18980\n");
	fprintf(fout,"CA     CT     0.05670\n");
	fprintf(fout,"HA     HP     0.07820\n");
	fprintf(fout,"CB     CT     0.25960\n");
	fprintf(fout,"HB1    H1     0.02730\n");
	fprintf(fout,"HB2    H1     0.02730\n");
	fprintf(fout,"OG     OH     -0.67140\n");
	fprintf(fout,"HG     HO     0.42390\n");
	fprintf(fout,"C      C      0.61630\n");
	fprintf(fout,"O      O      -0.57220\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NTHR Residue\n");
	fprintf(fout,"N      N3     0.18120\n");
	fprintf(fout,"H1     H      0.19340\n");
	fprintf(fout,"H2     H      0.19340\n");
	fprintf(fout,"H3     H      0.19340\n");
	fprintf(fout,"CA     CT     0.00340\n");
	fprintf(fout,"HA     HP     0.10870\n");
	fprintf(fout,"CB     CT     0.45140\n");
	fprintf(fout,"HB     H1     -0.03230\n");
	fprintf(fout,"CG2    CT     -0.25540\n");
	fprintf(fout,"HG21   HC     0.06270\n");
	fprintf(fout,"HG22   HC     0.06270\n");
	fprintf(fout,"HG23   HC     0.06270\n");
	fprintf(fout,"OG1    OH     -0.67640\n");
	fprintf(fout,"HG1    HO     0.40700\n");
	fprintf(fout,"C      C      0.61630\n");
	fprintf(fout,"O      O      -0.57220\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NLEU Residue\n");
	fprintf(fout,"N      N3     0.10100\n");
	fprintf(fout,"H1     H      0.21480\n");
	fprintf(fout,"H2     H      0.21480\n");
	fprintf(fout,"H3     H      0.21480\n");
	fprintf(fout,"CA     CT     0.01040\n");
	fprintf(fout,"HA     HP     0.10530\n");
	fprintf(fout,"CB     CT     -0.02440\n");
	fprintf(fout,"HB1    HC     0.02560\n");
	fprintf(fout,"HB2    HC     0.02560\n");
	fprintf(fout,"CG     CT     0.34210\n");
	fprintf(fout,"HG     HC     -0.03800\n");
	fprintf(fout,"CD1    CT     -0.41060\n");
	fprintf(fout,"HD11   HC     0.09800\n");
	fprintf(fout,"HD12   HC     0.09800\n");
	fprintf(fout,"HD13   HC     0.09800\n");
	fprintf(fout,"CD2    CT     -0.41040\n");
	fprintf(fout,"HD21   HC     0.09800\n");
	fprintf(fout,"HD22   HC     0.09800\n");
	fprintf(fout,"HD23   HC     0.09800\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NILE Residue\n");
	fprintf(fout,"N      N3     0.03110\n");
	fprintf(fout,"H1     H      0.23290\n");
	fprintf(fout,"H2     H      0.23290\n");
	fprintf(fout,"H3     H      0.23290\n");
	fprintf(fout,"CA     CT     0.02570\n");
	fprintf(fout,"HA     HP     0.10310\n");
	fprintf(fout,"CB     CT     0.18850\n");
	fprintf(fout,"HB     HC     0.02130\n");
	fprintf(fout,"CG2    CT     -0.37200\n");
	fprintf(fout,"HG21   HC     0.09470\n");
	fprintf(fout,"HG22   HC     0.09470\n");
	fprintf(fout,"HG23   HC     0.09470\n");
	fprintf(fout,"CG1    CT     -0.03870\n");
	fprintf(fout,"HG11   HC     0.02010\n");
	fprintf(fout,"HG12   HC     0.02010\n");
	fprintf(fout,"CD     CT     -0.09080\n");
	fprintf(fout,"HD1    HC     0.02260\n");
	fprintf(fout,"HD2    HC     0.02260\n");
	fprintf(fout,"HD3    HC     0.02260\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NVAL Residue\n");
	fprintf(fout,"N      N3     0.05770\n");
	fprintf(fout,"H1     H      0.22720\n");
	fprintf(fout,"H2     H      0.22720\n");
	fprintf(fout,"H3     H      0.22720\n");
	fprintf(fout,"CA     CT     -0.00540\n");
	fprintf(fout,"HA     HP     0.10930\n");
	fprintf(fout,"CB     CT     0.31960\n");
	fprintf(fout,"HB     HC     -0.02210\n");
	fprintf(fout,"CG1    CT     -0.31290\n");
	fprintf(fout,"HG11   HC     0.07350\n");
	fprintf(fout,"HG12   HC     0.07350\n");
	fprintf(fout,"HG13   HC     0.07350\n");
	fprintf(fout,"CG2    CT     -0.31290\n");
	fprintf(fout,"HG21   HC     0.07350\n");
	fprintf(fout,"HG22   HC     0.07350\n");
	fprintf(fout,"HG23   HC     0.07350\n");
	fprintf(fout,"C      C      0.61630\n");
	fprintf(fout,"O      O      -0.57220\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NASN Residue\n");
	fprintf(fout,"N      N3     0.18010\n");
	fprintf(fout,"H1     H      0.19210\n");
	fprintf(fout,"H2     H      0.19210\n");
	fprintf(fout,"H3     H      0.19210\n");
	fprintf(fout,"CA     CT     0.03680\n");
	fprintf(fout,"HA     HP     0.12310\n");
	fprintf(fout,"CB     CT     -0.02830\n");
	fprintf(fout,"HB1    HC     0.05150\n");
	fprintf(fout,"HB2    HC     0.05150\n");
	fprintf(fout,"CG     C      0.58330\n");
	fprintf(fout,"OD1    O      -0.57440\n");
	fprintf(fout,"ND2    N      -0.86340\n");
	fprintf(fout,"HD21   H      0.40970\n");
	fprintf(fout,"HD22   H      0.40970\n");
	fprintf(fout,"C      C      0.61630\n");
	fprintf(fout,"O      O      -0.57220\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NGLN Residue\n");
	fprintf(fout,"N      N3     0.14930\n");
	fprintf(fout,"H1     H      0.19960\n");
	fprintf(fout,"H2     H      0.19960\n");
	fprintf(fout,"H3     H      0.19960\n");
	fprintf(fout,"CA     CT     0.05360\n");
	fprintf(fout,"HA     HP     0.10150\n");
	fprintf(fout,"CB     CT     0.06510\n");
	fprintf(fout,"HB1    HC     0.00500\n");
	fprintf(fout,"HB2    HC     0.00500\n");
	fprintf(fout,"CG     CT     -0.09030\n");
	fprintf(fout,"HG1    HC     0.03310\n");
	fprintf(fout,"HG2    HC     0.03310\n");
	fprintf(fout,"CD     C      0.73540\n");
	fprintf(fout,"OE1    O      -0.61330\n");
	fprintf(fout,"NE2    N      -1.00310\n");
	fprintf(fout,"HE21   H      0.44290\n");
	fprintf(fout,"HE22   H      0.44290\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NARG Residue\n");
	fprintf(fout,"N      N3     0.13050\n");
	fprintf(fout,"H1     H      0.20830\n");
	fprintf(fout,"H2     H      0.20830\n");
	fprintf(fout,"H3     H      0.20830\n");
	fprintf(fout,"CA     CT     -0.02230\n");
	fprintf(fout,"HA     HP     0.12420\n");
	fprintf(fout,"CB     CT     0.01180\n");
	fprintf(fout,"HB1    HC     0.02260\n");
	fprintf(fout,"HB2    HC     0.02260\n");
	fprintf(fout,"CG     CT     0.02360\n");
	fprintf(fout,"HG1    HC     0.03090\n");
	fprintf(fout,"HG2    HC     0.03090\n");
	fprintf(fout,"CD     CT     0.09350\n");
	fprintf(fout,"HD1    H1     0.05270\n");
	fprintf(fout,"HD2    H1     0.05270\n");
	fprintf(fout,"NE     N2     -0.56500\n");
	fprintf(fout,"HE     H      0.35920\n");
	fprintf(fout,"CZ     CA     0.82810\n");
	fprintf(fout,"NH1    N2     -0.86930\n");
	fprintf(fout,"HH11   H      0.44940\n");
	fprintf(fout,"HH12   H      0.44940\n");
	fprintf(fout,"NH2    N2     -0.86930\n");
	fprintf(fout,"HH21   H      0.44940\n");
	fprintf(fout,"HH22   H      0.44940\n");
	fprintf(fout,"C      C      0.72140\n");
	fprintf(fout,"O      O      -0.60130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NHID Residue\n");
	fprintf(fout,"N      N3     0.15420\n");
	fprintf(fout,"H1     H      0.19630\n");
	fprintf(fout,"H2     H      0.19630\n");
	fprintf(fout,"H3     H      0.19630\n");
	fprintf(fout,"CA     CT     0.09640\n");
	fprintf(fout,"HA     HP     0.09580\n");
	fprintf(fout,"CB     CT     0.02590\n");
	fprintf(fout,"HB1    HC     0.02090\n");
	fprintf(fout,"HB2    HC     0.02090\n");
	fprintf(fout,"CG     CC     -0.03990\n");
	fprintf(fout,"ND1    NA     -0.38190\n");
	fprintf(fout,"HD1    H      0.36320\n");
	fprintf(fout,"CE1    CR     0.21270\n");
	fprintf(fout,"HE1    H5     0.13850\n");
	fprintf(fout,"NE2    NB     -0.57110\n");
	fprintf(fout,"CD2    CV     0.10460\n");
	fprintf(fout,"HD2    H4     0.12990\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NHIE Residue\n");
	fprintf(fout,"N      N3     0.14720\n");
	fprintf(fout,"H1     H      0.20160\n");
	fprintf(fout,"H2     H      0.20160\n");
	fprintf(fout,"H3     H      0.20160\n");
	fprintf(fout,"CA     CT     0.02360\n");
	fprintf(fout,"HA     HP     0.13800\n");
	fprintf(fout,"CB     CT     0.04890\n");
	fprintf(fout,"HB1    HC     0.02230\n");
	fprintf(fout,"HB2    HC     0.02230\n");
	fprintf(fout,"CG     CC     0.17400\n");
	fprintf(fout,"ND1    NB     -0.55790\n");
	fprintf(fout,"CE1    CR     0.18040\n");
	fprintf(fout,"HE1    H5     0.13970\n");
	fprintf(fout,"NE2    NA     -0.27810\n");
	fprintf(fout,"HE2    H      0.33240\n");
	fprintf(fout,"CD2    CW     -0.23490\n");
	fprintf(fout,"HD2    H4     0.19630\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NHIP Residue\n");
	fprintf(fout,"N      N3     0.25600\n");
	fprintf(fout,"H1     H      0.17040\n");
	fprintf(fout,"H2     H      0.17040\n");
	fprintf(fout,"H3     H      0.17040\n");
	fprintf(fout,"CA     CT     0.05810\n");
	fprintf(fout,"HA     HP     0.10470\n");
	fprintf(fout,"CB     CT     0.04840\n");
	fprintf(fout,"HB1    HC     0.05310\n");
	fprintf(fout,"HB2    HC     0.05310\n");
	fprintf(fout,"CG     CC     -0.02360\n");
	fprintf(fout,"ND1    NA     -0.15100\n");
	fprintf(fout,"HD1    H      0.38210\n");
	fprintf(fout,"CE1    CR     -0.00110\n");
	fprintf(fout,"HE1    H5     0.26450\n");
	fprintf(fout,"NE2    NA     -0.17390\n");
	fprintf(fout,"HE2    H      0.39210\n");
	fprintf(fout,"CD2    CW     -0.14330\n");
	fprintf(fout,"HD2    H4     0.24950\n");
	fprintf(fout,"C      C      0.72140\n");
	fprintf(fout,"O      O      -0.60130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NHIS Residue\n");
	fprintf(fout,"N      N3     0.25600\n");
	fprintf(fout,"H1     H      0.17040\n");
	fprintf(fout,"H2     H      0.17040\n");
	fprintf(fout,"H3     H      0.17040\n");
	fprintf(fout,"CA     CT     0.05810\n");
	fprintf(fout,"HA     HP     0.10470\n");
	fprintf(fout,"CB     CT     0.04840\n");
	fprintf(fout,"HB1    HC     0.05310\n");
	fprintf(fout,"HB2    HC     0.05310\n");
	fprintf(fout,"CG     CC     -0.02360\n");
	fprintf(fout,"ND1    NA     -0.15100\n");
	fprintf(fout,"HD1    H      0.38210\n");
	fprintf(fout,"CE1    CR     -0.00110\n");
	fprintf(fout,"HE1    H5     0.26450\n");
	fprintf(fout,"NE2    NA     -0.17390\n");
	fprintf(fout,"HE2    H      0.39210\n");
	fprintf(fout,"CD2    CW     -0.14330\n");
	fprintf(fout,"HD2    H4     0.24950\n");
	fprintf(fout,"C      C      0.72140\n");
	fprintf(fout,"O      O      -0.60130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NTRP Residue\n");
	fprintf(fout,"N      N3     0.19130\n");
	fprintf(fout,"H1     H      0.18880\n");
	fprintf(fout,"H2     H      0.18880\n");
	fprintf(fout,"H3     H      0.18880\n");
	fprintf(fout,"CA     CT     0.04210\n");
	fprintf(fout,"HA     HP     0.11620\n");
	fprintf(fout,"CB     CT     0.05430\n");
	fprintf(fout,"HB1    HC     0.02220\n");
	fprintf(fout,"HB2    HC     0.02220\n");
	fprintf(fout,"CG     C*     -0.16540\n");
	fprintf(fout,"CD1    CW     -0.17880\n");
	fprintf(fout,"HD1    H4     0.21950\n");
	fprintf(fout,"NE1    NA     -0.34440\n");
	fprintf(fout,"HE1    H      0.34120\n");
	fprintf(fout,"CE2    CN     0.15750\n");
	fprintf(fout,"CZ2    CA     -0.27100\n");
	fprintf(fout,"HZ2    HA     0.15890\n");
	fprintf(fout,"CH2    CA     -0.10800\n");
	fprintf(fout,"HH2    HA     0.14110\n");
	fprintf(fout,"CZ3    CA     -0.20340\n");
	fprintf(fout,"HZ3    HA     0.14580\n");
	fprintf(fout,"CE3    CA     -0.22650\n");
	fprintf(fout,"HE3    HA     0.16460\n");
	fprintf(fout,"CD2    CB     0.11320\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NPHE Residue\n");
	fprintf(fout,"N      N3     0.17370\n");
	fprintf(fout,"H1     H      0.19210\n");
	fprintf(fout,"H2     H      0.19210\n");
	fprintf(fout,"H3     H      0.19210\n");
	fprintf(fout,"CA     CT     0.07330\n");
	fprintf(fout,"HA     HP     0.10410\n");
	fprintf(fout,"CB     CT     0.03300\n");
	fprintf(fout,"HB1    HC     0.01040\n");
	fprintf(fout,"HB2    HC     0.01040\n");
	fprintf(fout,"CG     CA     0.00310\n");
	fprintf(fout,"CD1    CA     -0.13920\n");
	fprintf(fout,"HD1    HA     0.13740\n");
	fprintf(fout,"CE1    CA     -0.16020\n");
	fprintf(fout,"HE1    HA     0.14330\n");
	fprintf(fout,"CZ     CA     -0.12080\n");
	fprintf(fout,"HZ     HA     0.13290\n");
	fprintf(fout,"CE2    CA     -0.16030\n");
	fprintf(fout,"HE2    HA     0.14330\n");
	fprintf(fout,"CD2    CA     -0.13910\n");
	fprintf(fout,"HD2    HA     0.13740\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NTYR Residue\n");
	fprintf(fout,"N      N3     0.19400\n");
	fprintf(fout,"H1     H      0.18730\n");
	fprintf(fout,"H2     H      0.18730\n");
	fprintf(fout,"H3     H      0.18730\n");
	fprintf(fout,"CA     CT     0.05700\n");
	fprintf(fout,"HA     HP     0.09830\n");
	fprintf(fout,"CB     CT     0.06590\n");
	fprintf(fout,"HB1    HC     0.01020\n");
	fprintf(fout,"HB2    HC     0.01020\n");
	fprintf(fout,"CG     CA     -0.02050\n");
	fprintf(fout,"CD1    CA     -0.20020\n");
	fprintf(fout,"HD1    HA     0.17200\n");
	fprintf(fout,"CE1    CA     -0.22390\n");
	fprintf(fout,"HE1    HA     0.16500\n");
	fprintf(fout,"CZ     C      0.31390\n");
	fprintf(fout,"OH     OH     -0.55780\n");
	fprintf(fout,"HH     HO     0.40010\n");
	fprintf(fout,"CE2    CA     -0.22390\n");
	fprintf(fout,"HE2    HA     0.16500\n");
	fprintf(fout,"CD2    CA     -0.20020\n");
	fprintf(fout,"HD2    HA     0.17200\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NGLU Residue\n");
	fprintf(fout,"N      N3     0.00170\n");
	fprintf(fout,"H1     H      0.23910\n");
	fprintf(fout,"H2     H      0.23910\n");
	fprintf(fout,"H3     H      0.23910\n");
	fprintf(fout,"CA     CT     0.05880\n");
	fprintf(fout,"HA     HP     0.12020\n");
	fprintf(fout,"CB     CT     0.09090\n");
	fprintf(fout,"HB1    HC     -0.02320\n");
	fprintf(fout,"HB2    HC     -0.02320\n");
	fprintf(fout,"CG     CT     -0.02360\n");
	fprintf(fout,"HG1    HC     -0.03150\n");
	fprintf(fout,"HG2    HC     -0.03150\n");
	fprintf(fout,"CD     C      0.80870\n");
	fprintf(fout,"OE1    O2     -0.81890\n");
	fprintf(fout,"OE2    O2     -0.81890\n");
	fprintf(fout,"C      C      0.56210\n");
	fprintf(fout,"O      O      -0.58890\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NASP Residue\n");
	fprintf(fout,"N      N3     0.07820\n");
	fprintf(fout,"H1     H      0.22000\n");
	fprintf(fout,"H2     H      0.22000\n");
	fprintf(fout,"H3     H      0.22000\n");
	fprintf(fout,"CA     CT     0.02920\n");
	fprintf(fout,"HA     HP     0.11410\n");
	fprintf(fout,"CB     CT     -0.02350\n");
	fprintf(fout,"HB1    HC     -0.01690\n");
	fprintf(fout,"HB2    HC     -0.01690\n");
	fprintf(fout,"CG     C      0.81940\n");
	fprintf(fout,"OD1    O2     -0.80840\n");
	fprintf(fout,"OD2    O2     -0.80840\n");
	fprintf(fout,"C      C      0.56210\n");
	fprintf(fout,"O      O      -0.58890\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NLYS Residue\n");
	fprintf(fout,"N      N3     0.09660\n");
	fprintf(fout,"H1     H      0.21650\n");
	fprintf(fout,"H2     H      0.21650\n");
	fprintf(fout,"H3     H      0.21650\n");
	fprintf(fout,"CA     CT     -0.00150\n");
	fprintf(fout,"HA     HP     0.11800\n");
	fprintf(fout,"CB     CT     0.02120\n");
	fprintf(fout,"HB1    HC     0.02830\n");
	fprintf(fout,"HB2    HC     0.02830\n");
	fprintf(fout,"CG     CT     -0.00480\n");
	fprintf(fout,"HG1    HC     0.01210\n");
	fprintf(fout,"HG2    HC     0.01210\n");
	fprintf(fout,"CD     CT     -0.06080\n");
	fprintf(fout,"HD1    HC     0.06330\n");
	fprintf(fout,"HD2    HC     0.06330\n");
	fprintf(fout,"CE     CT     -0.01810\n");
	fprintf(fout,"HE1    HP     0.11710\n");
	fprintf(fout,"HE2    HP     0.11710\n");
	fprintf(fout,"NZ     N3     -0.37640\n");
	fprintf(fout,"HZ1    H      0.33820\n");
	fprintf(fout,"HZ2    H      0.33820\n");
	fprintf(fout,"HZ3    H      0.33820\n");
	fprintf(fout,"C      C      0.72140\n");
	fprintf(fout,"O      O      -0.60130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NLYP Residue\n");
	fprintf(fout,"N      N3     0.09660\n");
	fprintf(fout,"H1     H      0.21650\n");
	fprintf(fout,"H2     H      0.21650\n");
	fprintf(fout,"H3     H      0.21650\n");
	fprintf(fout,"CA     CT     -0.00150\n");
	fprintf(fout,"HA     HP     0.11800\n");
	fprintf(fout,"CB     CT     0.02120\n");
	fprintf(fout,"HB1    HC     0.02830\n");
	fprintf(fout,"HB2    HC     0.02830\n");
	fprintf(fout,"CG     CT     -0.00480\n");
	fprintf(fout,"HG1    HC     0.01210\n");
	fprintf(fout,"HG2    HC     0.01210\n");
	fprintf(fout,"CD     CT     -0.06080\n");
	fprintf(fout,"HD1    HC     0.06330\n");
	fprintf(fout,"HD2    HC     0.06330\n");
	fprintf(fout,"CE     CT     -0.01810\n");
	fprintf(fout,"HE1    HP     0.11710\n");
	fprintf(fout,"HE2    HP     0.11710\n");
	fprintf(fout,"NZ     N3     -0.37640\n");
	fprintf(fout,"HZ1    H      0.33820\n");
	fprintf(fout,"HZ2    H      0.33820\n");
	fprintf(fout,"HZ3    H      0.33820\n");
	fprintf(fout,"C      C      0.72140\n");
	fprintf(fout,"O      O      -0.60130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NPRO Residue\n");
	fprintf(fout,"N      N3     -0.20200\n");
	fprintf(fout,"H1     H      0.31200\n");
	fprintf(fout,"H2     H      0.31200\n");
	fprintf(fout,"CD     CT     -0.01200\n");
	fprintf(fout,"HD1    HP     0.10000\n");
	fprintf(fout,"HD2    HP     0.10000\n");
	fprintf(fout,"CG     CT     -0.12100\n");
	fprintf(fout,"HG1    HC     0.10000\n");
	fprintf(fout,"HG2    HC     0.10000\n");
	fprintf(fout,"CB     CT     -0.11500\n");
	fprintf(fout,"HB1    HC     0.10000\n");
	fprintf(fout,"HB2    HC     0.10000\n");
	fprintf(fout,"CA     CT     0.10000\n");
	fprintf(fout,"HA     HP     0.10000\n");
	fprintf(fout,"C      C      0.52600\n");
	fprintf(fout,"O      O      -0.50000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NCYS Residue\n");
	fprintf(fout,"N      N3     0.13250\n");
	fprintf(fout,"H1     H      0.20230\n");
	fprintf(fout,"H2     H      0.20230\n");
	fprintf(fout,"H3     H      0.20230\n");
	fprintf(fout,"CA     CT     0.09270\n");
	fprintf(fout,"HA     HP     0.14110\n");
	fprintf(fout,"CB     CT     -0.11950\n");
	fprintf(fout,"HB1    H1     0.11880\n");
	fprintf(fout,"HB2    H1     0.11880\n");
	fprintf(fout,"SG     SH     -0.32980\n");
	fprintf(fout,"HG     HS     0.19750\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NCYN Residue\n");
	fprintf(fout,"N      N3     0.13250\n");
	fprintf(fout,"H1     H      0.20230\n");
	fprintf(fout,"H2     H      0.20230\n");
	fprintf(fout,"H3     H      0.20230\n");
	fprintf(fout,"CA     CT     0.09270\n");
	fprintf(fout,"HA     HP     0.14110\n");
	fprintf(fout,"CB     CT     -0.11950\n");
	fprintf(fout,"HB1    H1     0.11880\n");
	fprintf(fout,"HB2    H1     0.11880\n");
	fprintf(fout,"SG     SH     -0.32980\n");
	fprintf(fout,"HG     HS     0.19750\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NCYM Residue\n");
	fprintf(fout,"N      N3     0.098749\n");
	fprintf(fout,"H1     H      0.150769\n");
	fprintf(fout,"H2     H      0.150769\n");
	fprintf(fout,"H3     H      0.150769\n");
	fprintf(fout,"CA     CT     0.069086\n");
	fprintf(fout,"HA     HP     0.105158\n");
	fprintf(fout,"CB     CT     -0.11950\n");
	fprintf(fout,"HB1    H1     0.11880\n");
	fprintf(fout,"HB2    H1     0.11880\n");
	fprintf(fout,"SG     SH     -0.88440\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");

	fprintf(fout,"Begin NCYX Residue\n");
	fprintf(fout,"N      N3     0.20690\n");
	fprintf(fout,"H1     H      0.18150\n");
	fprintf(fout,"H2     H      0.18150\n");
	fprintf(fout,"H3     H      0.18150\n");
	fprintf(fout,"CA     CT     0.10550\n");
	fprintf(fout,"HA     HP     0.09220\n");
	fprintf(fout,"CB     CT     -0.02770\n");
	fprintf(fout,"HB1    H1     0.06800\n");
	fprintf(fout,"HB2    H1     0.06800\n");
	fprintf(fout,"SG     S      -0.09840\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NMET Residue\n");
	fprintf(fout,"N      N3     0.15920\n");
	fprintf(fout,"H1     H      0.19840\n");
	fprintf(fout,"H2     H      0.19840\n");
	fprintf(fout,"H3     H      0.19840\n");
	fprintf(fout,"CA     CT     0.02210\n");
	fprintf(fout,"HA     HP     0.11160\n");
	fprintf(fout,"CB     CT     0.08650\n");
	fprintf(fout,"HB1    HC     0.01250\n");
	fprintf(fout,"HB2    HC     0.01250\n");
	fprintf(fout,"CG     CT     0.03340\n");
	fprintf(fout,"HG1    H1     0.02920\n");
	fprintf(fout,"HG2    H1     0.02920\n");
	fprintf(fout,"SD     S      -0.27740\n");
	fprintf(fout,"CE     CT     -0.03410\n");
	fprintf(fout,"HE1    H1     0.05970\n");
	fprintf(fout,"HE2    H1     0.05970\n");
	fprintf(fout,"HE3    H1     0.05970\n");
	fprintf(fout,"C      C      0.61230\n");
	fprintf(fout,"O      O      -0.57130\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NASH Residue\n");
	fprintf(fout,"N      N3     0.09069\n");
	fprintf(fout,"H1     H      0.25517\n");
	fprintf(fout,"H2     H      0.25517\n");
	fprintf(fout,"H3     H      0.25517\n");
	fprintf(fout,"CA     CT     0.03410\n");
	fprintf(fout,"HA     H1     0.08640\n");
	fprintf(fout,"CB     CT     -0.03160\n");
	fprintf(fout,"HB1    HC     0.04880\n");
	fprintf(fout,"HB2    HC     0.04880\n");
	fprintf(fout,"CG     C      0.64620\n");
	fprintf(fout,"OD1    O      -0.55540\n");
	fprintf(fout,"OD2    OH     -0.63760\n");
	fprintf(fout,"HD2    HO     0.47470\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NGLH Residue\n");
	fprintf(fout,"N      N3     0.32022\n");
	fprintf(fout,"H1     H      0.17866\n");
	fprintf(fout,"H2     H      0.17866\n");
	fprintf(fout,"H3     H      0.17866\n");
	fprintf(fout,"CA     CT     0.01450\n");
	fprintf(fout,"HA     H1     0.07790\n");
	fprintf(fout,"CB     CT     -0.00710\n");
	fprintf(fout,"HB1    HC     0.02560\n");
	fprintf(fout,"HB2    HC     0.02560\n");
	fprintf(fout,"CG     CT     -0.01740\n");
	fprintf(fout,"HG1    HC     0.04300\n");
	fprintf(fout,"HG2    HC     0.04300\n");
	fprintf(fout,"CD     C      0.68010\n");
	fprintf(fout,"OE1    O      -0.58380\n");
	fprintf(fout,"OE2    OH     -0.65110\n");
	fprintf(fout,"HE2    HO     0.46410\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin NLYN Residue\n");
	fprintf(fout,"N      N3     0.32022\n");
	fprintf(fout,"H1     H      0.17866\n");
	fprintf(fout,"H2     H      0.17866\n");
	fprintf(fout,"H3     H      0.17866\n");
	fprintf(fout,"CA     CT     -0.07206\n");
	fprintf(fout,"HA     H1     0.09940\n");
	fprintf(fout,"CB     CT     -0.04845\n");
	fprintf(fout,"HB1    HC     0.03400\n");
	fprintf(fout,"HB2    HC     0.03400\n");
	fprintf(fout,"CG     CT     0.06612\n");
	fprintf(fout,"HG1    HC     0.01041\n");
	fprintf(fout,"HG2    HC     0.01041\n");
	fprintf(fout,"CD     CT     -0.03768\n");
	fprintf(fout,"HD1    HC     0.01155\n");
	fprintf(fout,"HD2    HC     0.01155\n");
	fprintf(fout,"CE     CT     0.32604\n");
	fprintf(fout,"HE1    HP     -0.03358\n");
	fprintf(fout,"HE2    HP     -0.03358\n");
	fprintf(fout,"NZ     N3     -1.03581\n");
	fprintf(fout,"HZ1    H      0.38604\n");
	fprintf(fout,"HZ2    H      0.38604\n");
	fprintf(fout,"C      C      0.59730\n");
	fprintf(fout,"O      O      -0.56790\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin HALA Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	0.033700\n");
	fprintf(fout,"HA 	H1	0.082300\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	-0.182500\n");
	fprintf(fout,"HB1 	HC	0.060300\n");
	fprintf(fout,"HB2 	HC	0.060300\n");
	fprintf(fout,"HB3 	HC	0.060300\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HARG Residue\n");
	fprintf(fout,"N 	N	-0.916539\n");
	fprintf(fout,"H1 	H	0.421669\n");
	fprintf(fout,"H2 	H	0.421669\n");
	fprintf(fout,"CA 	CT	-0.263700\n");
	fprintf(fout,"HA 	H1	0.156000\n");
	fprintf(fout,"C 	C	0.734100\n");
	fprintf(fout,"O 	O	-0.589400\n");
	fprintf(fout,"CB 	CT	-0.000700\n");
	fprintf(fout,"HB1 	HC	0.032700\n");
	fprintf(fout,"HB2 	HC	0.032700\n");
	fprintf(fout,"CG 	CT	0.039000\n");
	fprintf(fout,"HG1 	HC	0.028500\n");
	fprintf(fout,"HG2 	HC	0.028500\n");
	fprintf(fout,"CD 	CT	0.048600\n");
	fprintf(fout,"HD1 	H1	0.068700\n");
	fprintf(fout,"HD2 	H1	0.068700\n");
	fprintf(fout,"NE 	N2	-0.529500\n");
	fprintf(fout,"HE 	H	0.345600\n");
	fprintf(fout,"CZ 	CA	0.807600\n");
	fprintf(fout,"NH1 	N2	-0.862700\n");
	fprintf(fout,"HH11 	H	0.447800\n");
	fprintf(fout,"HH12 	H	0.447800\n");
	fprintf(fout,"NH2 	N2	-0.862700\n");
	fprintf(fout,"HH21 	H	0.447800\n");
	fprintf(fout,"HH22 	H	0.447800\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HASN Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	0.014300\n");
	fprintf(fout,"HA 	H1	0.104800\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	-0.204100\n");
	fprintf(fout,"HB1 	HC	0.079700\n");
	fprintf(fout,"HB2 	HC	0.079700\n");
	fprintf(fout,"CG 	C	0.713000\n");
	fprintf(fout,"OD1 	O	-0.593100\n");
	fprintf(fout,"ND2 	N	-0.919100\n");
	fprintf(fout,"HD21 	H	0.419600\n");
	fprintf(fout,"HD22 	H	0.419600\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HASP Residue\n");
	fprintf(fout,"N 	N	-0.997877\n");
	fprintf(fout,"H1 	H	0.387588\n");
	fprintf(fout,"H2 	H	0.387588\n");
	fprintf(fout,"CA 	CT	0.038100\n");
	fprintf(fout,"HA 	H1	0.088000\n");
	fprintf(fout,"C 	C	0.536600\n");
	fprintf(fout,"O 	O	-0.581900\n");
	fprintf(fout,"CB 	CT	-0.030300\n");
	fprintf(fout,"HB1 	HC	-0.012200\n");
	fprintf(fout,"HB2 	HC	-0.012200\n");
	fprintf(fout,"CG 	C	0.799400\n");
	fprintf(fout,"OD1 	O2	-0.801400\n");
	fprintf(fout,"OD2 	O2	-0.801400\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HCYS Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	0.021300\n");
	fprintf(fout,"HA 	H1	0.112400\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	-0.123100\n");
	fprintf(fout,"HB1 	H1	0.111200\n");
	fprintf(fout,"HB2 	H1	0.111200\n");
	fprintf(fout,"SG 	SH	-0.311900\n");
	fprintf(fout,"HG 	HS	0.193300\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HCYX Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	0.042900\n");
	fprintf(fout,"HA 	H1	0.076600\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	-0.079000\n");
	fprintf(fout,"HB1 	H1	0.091000\n");
	fprintf(fout,"HB2 	H1	0.091000\n");
	fprintf(fout,"SG 	S	-0.108100\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HGLN Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	-0.003100\n");
	fprintf(fout,"HA 	H1	0.085000\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	-0.003600\n");
	fprintf(fout,"HB1 	HC	0.017100\n");
	fprintf(fout,"HB2 	HC	0.017100\n");
	fprintf(fout,"CG 	CT	-0.064500\n");
	fprintf(fout,"HG1 	HC	0.035200\n");
	fprintf(fout,"HG2 	HC	0.035200\n");
	fprintf(fout,"CD 	C	0.695100\n");
	fprintf(fout,"OE1 	O	-0.608600\n");
	fprintf(fout,"NE2 	N	-0.940700\n");
	fprintf(fout,"HE21 	H	0.425100\n");
	fprintf(fout,"HE22 	H	0.425100\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HGLU Residue\n");
	fprintf(fout,"N 	N	-0.997877\n");
	fprintf(fout,"H1 	H	0.387588\n");
	fprintf(fout,"H2 	H	0.387588\n");
	fprintf(fout,"CA 	CT	0.039700\n");
	fprintf(fout,"HA 	H1	0.110500\n");
	fprintf(fout,"C 	C	0.536600\n");
	fprintf(fout,"O 	O	-0.581900\n");
	fprintf(fout,"CB 	CT	0.056000\n");
	fprintf(fout,"HB1 	HC	-0.017300\n");
	fprintf(fout,"HB2 	HC	-0.017300\n");
	fprintf(fout,"CG 	CT	0.013600\n");
	fprintf(fout,"HG1 	HC	-0.042500\n");
	fprintf(fout,"HG2 	HC	-0.042500\n");
	fprintf(fout,"CD 	C	0.805400\n");
	fprintf(fout,"OE1 	O2	-0.818800\n");
	fprintf(fout,"OE2 	O2	-0.818800\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HGLY Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	-0.025200\n");
	fprintf(fout,"HA1 	H1	0.069800\n");
	fprintf(fout,"HA2 	H1	0.069800\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HHID Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	0.018800\n");
	fprintf(fout,"HA 	H1	0.088100\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	-0.046200\n");
	fprintf(fout,"HB1 	HC	0.040200\n");
	fprintf(fout,"HB2 	HC	0.040200\n");
	fprintf(fout,"CG 	CC	-0.026600\n");
	fprintf(fout,"ND1 	NA	-0.381100\n");
	fprintf(fout,"HD1 	H	0.364900\n");
	fprintf(fout,"CD2 	CV	0.129200\n");
	fprintf(fout,"HD2 	H4	0.114700\n");
	fprintf(fout,"CE1 	CR	0.205700\n");
	fprintf(fout,"HE1 	H5	0.139200\n");
	fprintf(fout,"NE2 	NB	-0.572700\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HHIE Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	-0.058100\n");
	fprintf(fout,"HA 	H1	0.136000\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	-0.007400\n");
	fprintf(fout,"HB1 	HC	0.036700\n");
	fprintf(fout,"HB2 	HC	0.036700\n");
	fprintf(fout,"CG 	CC	0.186800\n");
	fprintf(fout,"ND1 	NB	-0.543200\n");
	fprintf(fout,"CD2 	CW	-0.220700\n");
	fprintf(fout,"HD2 	H4	0.186200\n");
	fprintf(fout,"CE1 	CR	0.163500\n");
	fprintf(fout,"HE1 	H5	0.143500\n");
	fprintf(fout,"NE2 	NA	-0.279500\n");
	fprintf(fout,"HE2 	H	0.333900\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HHIP Residue\n");
	fprintf(fout,"N 	N	-0.916539\n");
	fprintf(fout,"H1 	H	0.421669\n");
	fprintf(fout,"H2 	H	0.421669\n");
	fprintf(fout,"CA 	CT	-0.135400\n");
	fprintf(fout,"HA 	H1	0.121200\n");
	fprintf(fout,"C 	C	0.734100\n");
	fprintf(fout,"O 	O	-0.589400\n");
	fprintf(fout,"CB 	CT	-0.041400\n");
	fprintf(fout,"HB1 	HC	0.081000\n");
	fprintf(fout,"HB2 	HC	0.081000\n");
	fprintf(fout,"CG 	CC	-0.001200\n");
	fprintf(fout,"ND1 	NA	-0.151300\n");
	fprintf(fout,"HD1 	H	0.386600\n");
	fprintf(fout,"CD2 	CW	-0.114100\n");
	fprintf(fout,"HD2 	H4	0.231700\n");
	fprintf(fout,"CE1 	CR	-0.017000\n");
	fprintf(fout,"HE1 	H5	0.268100\n");
	fprintf(fout,"NE2 	NA	-0.171800\n");
	fprintf(fout,"HE2 	H	0.391100\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HHIS Residue\n");
	fprintf(fout,"N 	N	-0.916539\n");
	fprintf(fout,"H1 	H	0.421669\n");
	fprintf(fout,"H2 	H	0.421669\n");
	fprintf(fout,"CA 	CT	-0.135400\n");
	fprintf(fout,"HA 	H1	0.121200\n");
	fprintf(fout,"C 	C	0.734100\n");
	fprintf(fout,"O 	O	-0.589400\n");
	fprintf(fout,"CB 	CT	-0.041400\n");
	fprintf(fout,"HB1 	HC	0.081000\n");
	fprintf(fout,"HB2 	HC	0.081000\n");
	fprintf(fout,"CG 	CC	-0.001200\n");
	fprintf(fout,"ND1 	NA	-0.151300\n");
	fprintf(fout,"HD1 	H	0.386600\n");
	fprintf(fout,"CD2 	CW	-0.114100\n");
	fprintf(fout,"HD2 	H4	0.231700\n");
	fprintf(fout,"CE1 	CR	-0.017000\n");
	fprintf(fout,"HE1 	H5	0.268100\n");
	fprintf(fout,"NE2 	NA	-0.171800\n");
	fprintf(fout,"HE2 	H	0.391100\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HILE Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	-0.059700\n");
	fprintf(fout,"HA 	H1	0.086900\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	0.130300\n");
	fprintf(fout,"HB 	HC	0.018700\n");
	fprintf(fout,"CG1 	CT	-0.043000\n");
	fprintf(fout,"HG11 	HC	0.023600\n");
	fprintf(fout,"HG12 	HC	0.023600\n");
	fprintf(fout,"CG2 	CT	-0.320400\n");
	fprintf(fout,"HG21 	HC	0.088200\n");
	fprintf(fout,"HG22 	HC	0.088200\n");
	fprintf(fout,"HG23 	HC	0.088200\n");
	fprintf(fout,"CD 	CT	-0.066000\n");
	fprintf(fout,"HD1 	HC	0.018600\n");
	fprintf(fout,"HD2 	HC	0.018600\n");
	fprintf(fout,"HD3 	HC	0.018600\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HLEU Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	-0.051800\n");
	fprintf(fout,"HA 	H1	0.092200\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	-0.110200\n");
	fprintf(fout,"HB1 	HC	0.045700\n");
	fprintf(fout,"HB2 	HC	0.045700\n");
	fprintf(fout,"CG 	CT	0.353100\n");
	fprintf(fout,"HG 	HC	-0.036100\n");
	fprintf(fout,"CD1 	CT	-0.412100\n");
	fprintf(fout,"HD11 	HC	0.100000\n");
	fprintf(fout,"HD12 	HC	0.100000\n");
	fprintf(fout,"HD13 	HC	0.100000\n");
	fprintf(fout,"CD2 	CT	-0.412100\n");
	fprintf(fout,"HD21 	HC	0.100000\n");
	fprintf(fout,"HD22 	HC	0.100000\n");
	fprintf(fout,"HD23 	HC	0.100000\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HLYS Residue\n");
	fprintf(fout,"N 	N	-0.916539\n");
	fprintf(fout,"H1 	H	0.421669\n");
	fprintf(fout,"H2 	H	0.421669\n");
	fprintf(fout,"CA 	CT	-0.240000\n");
	fprintf(fout,"HA 	H1	0.142600\n");
	fprintf(fout,"C 	C	0.734100\n");
	fprintf(fout,"O 	O	-0.589400\n");
	fprintf(fout,"CB 	CT	-0.009400\n");
	fprintf(fout,"HB1 	HC	0.036200\n");
	fprintf(fout,"HB2 	HC	0.036200\n");
	fprintf(fout,"CG 	CT	0.018700\n");
	fprintf(fout,"HG1 	HC	0.010300\n");
	fprintf(fout,"HG2 	HC	0.010300\n");
	fprintf(fout,"CD 	CT	-0.047900\n");
	fprintf(fout,"HD1 	HC	0.062100\n");
	fprintf(fout,"HD2 	HC	0.062100\n");
	fprintf(fout,"CE 	CT	-0.014300\n");
	fprintf(fout,"HE1 	HP	0.113500\n");
	fprintf(fout,"HE2 	HP	0.113500\n");
	fprintf(fout,"NZ 	N3	-0.385400\n");
	fprintf(fout,"HZ1 	H	0.340000\n");
	fprintf(fout,"HZ2 	H	0.340000\n");
	fprintf(fout,"HZ3 	H	0.340000\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HMET Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	-0.023700\n");
	fprintf(fout,"HA 	H1	0.088000\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	0.034200\n");
	fprintf(fout,"HB1 	HC	0.024100\n");
	fprintf(fout,"HB2 	HC	0.024100\n");
	fprintf(fout,"CG 	CT	0.001800\n");
	fprintf(fout,"HG1 	H1	0.044000\n");
	fprintf(fout,"HG2 	H1	0.044000\n");
	fprintf(fout,"SD 	S	-0.273700\n");
	fprintf(fout,"CE 	CT	-0.053600\n");
	fprintf(fout,"HE1 	H1	0.068400\n");
	fprintf(fout,"HE2 	H1	0.068400\n");
	fprintf(fout,"HE3 	H1	0.068400\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HPHE Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	-0.002400\n");
	fprintf(fout,"HA 	H1	0.097800\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	-0.034300\n");
	fprintf(fout,"HB1 	HC	0.029500\n");
	fprintf(fout,"HB2 	HC	0.029500\n");
	fprintf(fout,"CG 	CA	0.011800\n");
	fprintf(fout,"CD1 	CA	-0.125600\n");
	fprintf(fout,"HD1 	HA	0.133000\n");
	fprintf(fout,"CD2 	CA	-0.125600\n");
	fprintf(fout,"HD2 	HA	0.133000\n");
	fprintf(fout,"CE1 	CA	-0.170400\n");
	fprintf(fout,"HE1 	HA	0.143000\n");
	fprintf(fout,"CE2 	CA	-0.170400\n");
	fprintf(fout,"HE2 	HA	0.143000\n");
	fprintf(fout,"CZ 	CA	-0.107200\n");
	fprintf(fout,"HZ 	HA	0.129700\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HPRO Residue\n");
	fprintf(fout,"N 	N	-0.654800\n");
	fprintf(fout,"H 	H	0.400000\n");
	fprintf(fout,"CA 	CT	-0.026600\n");
	fprintf(fout,"HA 	H1	0.064100\n");
	fprintf(fout,"C 	C	0.589600\n");
	fprintf(fout,"O 	O	-0.574800\n");
	fprintf(fout,"CB 	CT	-0.007000\n");
	fprintf(fout,"HB1 	HC	0.025300\n");
	fprintf(fout,"HB2 	HC	0.025300\n");
	fprintf(fout,"CG 	CT	0.018900\n");
	fprintf(fout,"HG1 	HC	0.021300\n");
	fprintf(fout,"HG2 	HC	0.021300\n");
	fprintf(fout,"CD 	CT	0.019200\n");
	fprintf(fout,"HD1 	H1	0.039100\n");
	fprintf(fout,"HD2 	H1	0.039100\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HSER Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	-0.024900\n");
	fprintf(fout,"HA 	H1	0.084300\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	0.211700\n");
	fprintf(fout,"HB1 	H1	0.035200\n");
	fprintf(fout,"HB2 	H1	0.035200\n");
	fprintf(fout,"OG 	OH	-0.654600\n");
	fprintf(fout,"HG 	HO	0.427500\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HTHR Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	-0.038900\n");
	fprintf(fout,"HA 	H1	0.100700\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	0.365400\n");
	fprintf(fout,"HB 	H1	0.004300\n");
	fprintf(fout,"OG1 	OH	-0.676100\n");
	fprintf(fout,"HG1 	HO	0.410200\n");
	fprintf(fout,"CG2 	CT	-0.243800\n");
	fprintf(fout,"HG21 	HC	0.064200\n");
	fprintf(fout,"HG22 	HC	0.064200\n");
	fprintf(fout,"HG23 	HC	0.064200\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HTYR Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	-0.001400\n");
	fprintf(fout,"HA 	H1	0.087600\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	-0.015200\n");
	fprintf(fout,"HB1 	HC	0.029500\n");
	fprintf(fout,"HB2 	HC	0.029500\n");
	fprintf(fout,"CG 	CA	-0.001100\n");
	fprintf(fout,"CD1 	CA	-0.190600\n");
	fprintf(fout,"HD1 	HA	0.169900\n");
	fprintf(fout,"CD2 	CA	-0.190600\n");
	fprintf(fout,"HD2 	HA	0.169900\n");
	fprintf(fout,"CE1 	CA	-0.234100\n");
	fprintf(fout,"HE1 	HA	0.165600\n");
	fprintf(fout,"CE2 	CA	-0.234100\n");
	fprintf(fout,"HE2 	HA	0.165600\n");
	fprintf(fout,"CZ 	C	0.322600\n");
	fprintf(fout,"OH 	OH	-0.557900\n");
	fprintf(fout,"HH 	HO	0.399200\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HTRP Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	-0.027500\n");
	fprintf(fout,"HA 	H1	0.112300\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	-0.005000\n");
	fprintf(fout,"HB1 	HC	0.033900\n");
	fprintf(fout,"HB2 	HC	0.033900\n");
	fprintf(fout,"CG 	C*	-0.141500\n");
	fprintf(fout,"CD1 	CW	-0.163800\n");
	fprintf(fout,"HD1 	H4	0.206200\n");
	fprintf(fout,"CD2 	CB	0.124300\n");
	fprintf(fout,"NE1 	NA	-0.341800\n");
	fprintf(fout,"HE1 	H	0.341200\n");
	fprintf(fout,"CE2 	CN	0.138000\n");
	fprintf(fout,"CE3 	CA	-0.238700\n");
	fprintf(fout,"HE3 	HA	0.170000\n");
	fprintf(fout,"CZ2 	CA	-0.260100\n");
	fprintf(fout,"HZ2 	HA	0.157200\n");
	fprintf(fout,"CZ3 	CA	-0.197200\n");
	fprintf(fout,"HZ3 	HA	0.144700\n");
	fprintf(fout,"CH2 	CA	-0.113400\n");
	fprintf(fout,"HH2 	HA	0.141700\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HVAL Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	-0.087500\n");
	fprintf(fout,"HA 	H1	0.096900\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	0.298500\n");
	fprintf(fout,"HB 	HC	-0.029700\n");
	fprintf(fout,"CG1 	CT	-0.319200\n");
	fprintf(fout,"HG11 	HC	0.079100\n");
	fprintf(fout,"HG12 	HC	0.079100\n");
	fprintf(fout,"HG13 	HC	0.079100\n");
	fprintf(fout,"CG2 	CT	-0.319200\n");
	fprintf(fout,"HG21 	HC	0.079100\n");
	fprintf(fout,"HG22 	HC	0.079100\n");
	fprintf(fout,"HG23 	HC	0.079100\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HASH Residue\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"HB2 	HC	0.048800\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"CA 	CT	0.034100\n");
	fprintf(fout,"CB 	CT	-0.031600\n");
	fprintf(fout,"OD1 	O	-0.555400\n");
	fprintf(fout,"HB1 	HC	0.048800\n");
	fprintf(fout,"CG 	C	0.646200\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"HA 	H1	0.086400\n");
	fprintf(fout,"OD2 	OH	-0.637600\n");
	fprintf(fout,"HD2 	HO	0.474700\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HGLH Residue\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"CB 	CT	-0.007100\n");
	fprintf(fout,"HB2 	HC	0.025600\n");
	fprintf(fout,"HB1 	HC	0.025600\n");
	fprintf(fout,"CA 	CT	0.014500\n");
	fprintf(fout,"HA 	H1	0.077900\n");
	fprintf(fout,"OE1 	O	-0.583800\n");
	fprintf(fout,"OE2 	OH	-0.651100\n");
	fprintf(fout,"HE2 	HO	0.464100\n");
	fprintf(fout,"CD 	C	0.680100\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CG 	CT	-0.017400\n");
	fprintf(fout,"HG1 	HC	0.043000\n");
	fprintf(fout,"HG2 	HC	0.043000\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HLYN Residue\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"CB 	CT	-0.048450\n");
	fprintf(fout,"HB1 	HC	0.034000\n");
	fprintf(fout,"HB2 	HC	0.034000\n");
	fprintf(fout,"CD 	CT	-0.037680\n");
	fprintf(fout,"HD1 	HC	0.011550\n");
	fprintf(fout,"HD2 	HC	0.011550\n");
	fprintf(fout,"CA 	CT	-0.072060\n");
	fprintf(fout,"HA 	H1	0.099400\n");
	fprintf(fout,"CG 	CT	0.066120\n");
	fprintf(fout,"HG1 	HC	0.010410\n");
	fprintf(fout,"HG2 	HC	0.010410\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CE 	CT	0.326040\n");
	fprintf(fout,"HE1 	HP	-0.033580\n");
	fprintf(fout,"HE2 	HP	-0.033580\n");
	fprintf(fout,"NZ 	N3	-1.035810\n");
	fprintf(fout,"HZ1 	H	0.386040\n");
	fprintf(fout,"HZ2 	H	0.386040\n");
	fprintf(fout,"End\n");
	fprintf(fout,"Begin HCYM Residue\n");
	fprintf(fout,"N 	N	-0.954950\n");
	fprintf(fout,"H1 	H	0.405575\n");
	fprintf(fout,"H2 	H	0.405575\n");
	fprintf(fout,"CA 	CT	-0.035100\n");
	fprintf(fout,"HA 	H1	0.050800\n");
	fprintf(fout,"C 	C	0.597300\n");
	fprintf(fout,"O 	O	-0.567900\n");
	fprintf(fout,"CB 	CT	-0.241300\n");
	fprintf(fout,"HB1 	H1	0.112200\n");
	fprintf(fout,"HB2 	H1	0.112200\n");
	fprintf(fout,"SG 	SH	-0.884400\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin ROH Residue\n");
	fprintf(fout,"N      N      -0.687400\n");
	fprintf(fout,"H      H      0.362500\n");
	fprintf(fout,"CA     CT     0.613500\n");
	fprintf(fout,"HA     H1     -0.013000\n");
	fprintf(fout,"CB     CT     -0.426200\n");
	fprintf(fout,"HB1    HC     0.162200\n");
	fprintf(fout,"HB2    HC     0.097600\n");
	fprintf(fout,"CG     CT     -0.121200\n");
	fprintf(fout,"HG1    HC     0.126700\n");
	fprintf(fout,"HG2    HC     0.078100\n");
	fprintf(fout,"CD     CT     0.185000\n");
	fprintf(fout,"HD1    H1     0.055100\n");
	fprintf(fout,"HD2    H1     0.059300\n");
	fprintf(fout,"NE     N2     -0.707500\n");
	fprintf(fout,"HE     H      0.383700\n");
	fprintf(fout,"CZ     CA     1.082900\n");
	fprintf(fout,"NH1    N2     -0.981100\n");
	fprintf(fout,"HH11   H      0.452300\n");
	fprintf(fout,"HH12   H      0.483000\n");
	fprintf(fout,"NH2    N2     -1.121400\n");
	fprintf(fout,"HH21   H      0.511600\n");
	fprintf(fout,"HH22   H      0.514900\n");
	fprintf(fout,"C      C      0.683200\n");
	fprintf(fout,"O      O      -0.590800\n");
	fprintf(fout,"OH     OH     -0.747600\n");
	fprintf(fout,"HO     HO     0.544600\n");
	fprintf(fout,"End\n");



	fprintf(fout,"End\n");
}
/************************************************************/
void createNucleicResidueTpl(FILE* fout)
{

	fprintf(fout,"Begin DA5 Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.04310\n");
	fprintf(fout,"H1'    H2     0.18380\n");
	fprintf(fout,"N9     N*     -0.02680\n");
	fprintf(fout,"C8     CK     0.16070\n");
	fprintf(fout,"H8     H5     0.18770\n");
	fprintf(fout,"N7     NB     -0.61750\n");
	fprintf(fout,"C5     CB     0.07250\n");
	fprintf(fout,"C6     CA     0.68970\n");
	fprintf(fout,"N6     N2     -0.91230\n");
	fprintf(fout,"H61    H      0.41670\n");
	fprintf(fout,"H62    H      0.41670\n");
	fprintf(fout,"N1     NC     -0.76240\n");
	fprintf(fout,"C2     CQ     0.57160\n");
	fprintf(fout,"H2     H5     0.05980\n");
	fprintf(fout,"N3     NC     -0.74170\n");
	fprintf(fout,"C4     CB     0.38000\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DA Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.24000\n");
	fprintf(fout,"HA     H1     0.14260\n");
	fprintf(fout,"CB     CT     0.02920\n");
	fprintf(fout,"HB1    HC     0.07470\n");
	fprintf(fout,"HB2    HC     0.07470\n");
	fprintf(fout,"CG     CT     -0.01430\n");
	fprintf(fout,"HG1    HP     0.11350\n");
	fprintf(fout,"HG2    HP     0.11350\n");
	fprintf(fout,"ND     N3     -0.38540\n");
	fprintf(fout,"HD1    H      0.34000\n");
	fprintf(fout,"HD2    H      0.34000\n");
	fprintf(fout,"HD3    H      0.34000\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DA3 Residue\n");
	fprintf(fout,"P      P      1.16590\n");
	fprintf(fout,"O1P    O2     -0.77610\n");
	fprintf(fout,"O2P    O2     -0.77610\n");
	fprintf(fout,"O5'    OS     -0.49540\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.04310\n");
	fprintf(fout,"H1'    H2     0.18380\n");
	fprintf(fout,"N9     N*     -0.02680\n");
	fprintf(fout,"C8     CK     0.16070\n");
	fprintf(fout,"H8     H5     0.18770\n");
	fprintf(fout,"N7     NB     -0.61750\n");
	fprintf(fout,"C5     CB     0.07250\n");
	fprintf(fout,"C6     CA     0.68970\n");
	fprintf(fout,"N6     N2     -0.91230\n");
	fprintf(fout,"H61    H      0.41670\n");
	fprintf(fout,"H62    H      0.41670\n");
	fprintf(fout,"N1     NC     -0.76240\n");
	fprintf(fout,"C2     CQ     0.57160\n");
	fprintf(fout,"H2     H5     0.05980\n");
	fprintf(fout,"N3     NC     -0.74170\n");
	fprintf(fout,"C4     CB     0.38000\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DAN Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.04310\n");
	fprintf(fout,"H1'    H2     0.18380\n");
	fprintf(fout,"N9     N*     -0.02680\n");
	fprintf(fout,"C8     CK     0.16070\n");
	fprintf(fout,"H8     H5     0.18770\n");
	fprintf(fout,"N7     NB     -0.61750\n");
	fprintf(fout,"C5     CB     0.07250\n");
	fprintf(fout,"C6     CA     0.68970\n");
	fprintf(fout,"N6     N2     -0.91230\n");
	fprintf(fout,"H61    H      0.41670\n");
	fprintf(fout,"H62    H      0.41670\n");
	fprintf(fout,"N1     NC     -0.76240\n");
	fprintf(fout,"C2     CQ     0.57160\n");
	fprintf(fout,"H2     H5     0.05980\n");
	fprintf(fout,"N3     NC     -0.74170\n");
	fprintf(fout,"C4     CB     0.38000\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RA5 Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.03940\n");
	fprintf(fout,"H1'    H2     0.20070\n");
	fprintf(fout,"N9     N*     -0.02510\n");
	fprintf(fout,"C8     CK     0.20060\n");
	fprintf(fout,"H8     H5     0.15530\n");
	fprintf(fout,"N7     NB     -0.60730\n");
	fprintf(fout,"C5     CB     0.05150\n");
	fprintf(fout,"C6     CA     0.70090\n");
	fprintf(fout,"N6     N2     -0.90190\n");
	fprintf(fout,"H61    H      0.41150\n");
	fprintf(fout,"H62    H      0.41150\n");
	fprintf(fout,"N1     NC     -0.76150\n");
	fprintf(fout,"C2     CQ     0.58750\n");
	fprintf(fout,"H2     H5     0.04730\n");
	fprintf(fout,"N3     NC     -0.69970\n");
	fprintf(fout,"C4     CB     0.30530\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RA Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.03940\n");
	fprintf(fout,"H1'    H2     0.20070\n");
	fprintf(fout,"N9     N*     -0.02510\n");
	fprintf(fout,"C8     CK     0.20060\n");
	fprintf(fout,"H8     H5     0.15530\n");
	fprintf(fout,"N7     NB     -0.60730\n");
	fprintf(fout,"C5     CB     0.05150\n");
	fprintf(fout,"C6     CA     0.70090\n");
	fprintf(fout,"N6     N2     -0.90190\n");
	fprintf(fout,"H61    H      0.41150\n");
	fprintf(fout,"H62    H      0.41150\n");
	fprintf(fout,"N1     NC     -0.76150\n");
	fprintf(fout,"C2     CQ     0.58750\n");
	fprintf(fout,"H2     H5     0.04730\n");
	fprintf(fout,"N3     NC     -0.69970\n");
	fprintf(fout,"C4     CB     0.30530\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RA3 Residue\n");
	fprintf(fout,"P      P      1.16620\n");
	fprintf(fout,"O1P    O2     -0.77600\n");
	fprintf(fout,"O2P    O2     -0.77600\n");
	fprintf(fout,"O5'    OS     -0.49890\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.03940\n");
	fprintf(fout,"H1'    H2     0.20070\n");
	fprintf(fout,"N9     N*     -0.02510\n");
	fprintf(fout,"C8     CK     0.20060\n");
	fprintf(fout,"H8     H5     0.15530\n");
	fprintf(fout,"N7     NB     -0.60730\n");
	fprintf(fout,"C5     CB     0.05150\n");
	fprintf(fout,"C6     CA     0.70090\n");
	fprintf(fout,"N6     N2     -0.90190\n");
	fprintf(fout,"H61    H      0.41150\n");
	fprintf(fout,"H62    H      0.41150\n");
	fprintf(fout,"N1     NC     -0.76150\n");
	fprintf(fout,"C2     CQ     0.58750\n");
	fprintf(fout,"H2     H5     0.04730\n");
	fprintf(fout,"N3     NC     -0.69970\n");
	fprintf(fout,"C4     CB     0.30530\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RAN Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.03940\n");
	fprintf(fout,"H1'    H2     0.20070\n");
	fprintf(fout,"N9     N*     -0.02510\n");
	fprintf(fout,"C8     CK     0.20060\n");
	fprintf(fout,"H8     H5     0.15530\n");
	fprintf(fout,"N7     NB     -0.60730\n");
	fprintf(fout,"C5     CB     0.05150\n");
	fprintf(fout,"C6     CA     0.70090\n");
	fprintf(fout,"N6     N2     -0.90190\n");
	fprintf(fout,"H61    H      0.41150\n");
	fprintf(fout,"H62    H      0.41150\n");
	fprintf(fout,"N1     NC     -0.76150\n");
	fprintf(fout,"C2     CQ     0.58750\n");
	fprintf(fout,"H2     H5     0.04730\n");
	fprintf(fout,"N3     NC     -0.69970\n");
	fprintf(fout,"C4     CB     0.30530\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DT5 Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.06800\n");
	fprintf(fout,"H1'    H2     0.18040\n");
	fprintf(fout,"N1     N*     -0.02390\n");
	fprintf(fout,"C6     CM     -0.22090\n");
	fprintf(fout,"H6     H4     0.26070\n");
	fprintf(fout,"C5     CM     0.00250\n");
	fprintf(fout,"C7     CT     -0.22690\n");
	fprintf(fout,"H71    HC     0.07700\n");
	fprintf(fout,"H72    HC     0.07700\n");
	fprintf(fout,"H73    HC     0.07700\n");
	fprintf(fout,"C4     C      0.51940\n");
	fprintf(fout,"O4     O      -0.55630\n");
	fprintf(fout,"N3     NA     -0.43400\n");
	fprintf(fout,"H3     H      0.34200\n");
	fprintf(fout,"C2     C      0.56770\n");
	fprintf(fout,"O      O      -0.58810\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DT Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.06800\n");
	fprintf(fout,"H1'    H2     0.18040\n");
	fprintf(fout,"N1     N*     -0.02390\n");
	fprintf(fout,"C6     CM     -0.22090\n");
	fprintf(fout,"H6     H4     0.26070\n");
	fprintf(fout,"C5     CM     0.00250\n");
	fprintf(fout,"C7     CT     -0.22690\n");
	fprintf(fout,"H71    HC     0.07700\n");
	fprintf(fout,"H72    HC     0.07700\n");
	fprintf(fout,"H73    HC     0.07700\n");
	fprintf(fout,"C4     C      0.51940\n");
	fprintf(fout,"O4     O      -0.55630\n");
	fprintf(fout,"N3     NA     -0.43400\n");
	fprintf(fout,"H3     H      0.34200\n");
	fprintf(fout,"C2     C      0.56770\n");
	fprintf(fout,"O      O      -0.58810\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DT3 Residue\n");
	fprintf(fout,"P      P      1.16590\n");
	fprintf(fout,"O1P    O2     -0.77610\n");
	fprintf(fout,"O2P    O2     -0.77610\n");
	fprintf(fout,"O5'    OS     -0.49540\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.06800\n");
	fprintf(fout,"H1'    H2     0.18040\n");
	fprintf(fout,"N1     N*     -0.02390\n");
	fprintf(fout,"C6     CM     -0.22090\n");
	fprintf(fout,"H6     H4     0.26070\n");
	fprintf(fout,"C5     CM     0.00250\n");
	fprintf(fout,"C7     CT     -0.22690\n");
	fprintf(fout,"H71    HC     0.07700\n");
	fprintf(fout,"H72    HC     0.07700\n");
	fprintf(fout,"H73    HC     0.07700\n");
	fprintf(fout,"C4     C      0.51940\n");
	fprintf(fout,"O4     O      -0.55630\n");
	fprintf(fout,"N3     NA     -0.43400\n");
	fprintf(fout,"H3     H      0.34200\n");
	fprintf(fout,"C2     C      0.56770\n");
	fprintf(fout,"O      O      -0.58810\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DTN Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.06800\n");
	fprintf(fout,"H1'    H2     0.18040\n");
	fprintf(fout,"N1     N*     -0.02390\n");
	fprintf(fout,"C6     CM     -0.22090\n");
	fprintf(fout,"H6     H4     0.26070\n");
	fprintf(fout,"C5     CM     0.00250\n");
	fprintf(fout,"C7     CT     -0.22690\n");
	fprintf(fout,"H71    HC     0.07700\n");
	fprintf(fout,"H72    HC     0.07700\n");
	fprintf(fout,"H73    HC     0.07700\n");
	fprintf(fout,"C4     C      0.51940\n");
	fprintf(fout,"O4     O      -0.55630\n");
	fprintf(fout,"N3     NA     -0.43400\n");
	fprintf(fout,"H3     H      0.34200\n");
	fprintf(fout,"C2     C      0.56770\n");
	fprintf(fout,"O      O      -0.58810\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RU5 Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.06740\n");
	fprintf(fout,"H1'    H2     0.18240\n");
	fprintf(fout,"N1     N*     0.04180\n");
	fprintf(fout,"C6     CM     -0.11260\n");
	fprintf(fout,"H6     H4     0.21880\n");
	fprintf(fout,"C5     CM     -0.36350\n");
	fprintf(fout,"H5     HA     0.18110\n");
	fprintf(fout,"C4     C      0.59520\n");
	fprintf(fout,"O4     O      -0.57610\n");
	fprintf(fout,"N3     NA     -0.35490\n");
	fprintf(fout,"H3     H      0.31540\n");
	fprintf(fout,"C2     C      0.46870\n");
	fprintf(fout,"O      O      -0.54770\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RU Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.06740\n");
	fprintf(fout,"H1'    H2     0.18240\n");
	fprintf(fout,"N1     N*     0.04180\n");
	fprintf(fout,"C6     CM     -0.11260\n");
	fprintf(fout,"H6     H4     0.21880\n");
	fprintf(fout,"C5     CM     -0.36350\n");
	fprintf(fout,"H5     HA     0.18110\n");
	fprintf(fout,"C4     C      0.59520\n");
	fprintf(fout,"O4     O      -0.57610\n");
	fprintf(fout,"N3     NA     -0.35490\n");
	fprintf(fout,"H3     H      0.31540\n");
	fprintf(fout,"C2     C      0.46870\n");
	fprintf(fout,"O      O      -0.54770\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RU3 Residue\n");
	fprintf(fout,"P      P      1.16620\n");
	fprintf(fout,"O1P    O2     -0.77600\n");
	fprintf(fout,"O2P    O2     -0.77600\n");
	fprintf(fout,"O5'    OS     -0.49890\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.06740\n");
	fprintf(fout,"H1'    H2     0.18240\n");
	fprintf(fout,"N1     N*     0.04180\n");
	fprintf(fout,"C6     CM     -0.11260\n");
	fprintf(fout,"H6     H4     0.21880\n");
	fprintf(fout,"C5     CM     -0.36350\n");
	fprintf(fout,"H5     HA     0.18110\n");
	fprintf(fout,"C4     C      0.59520\n");
	fprintf(fout,"O4     O      -0.57610\n");
	fprintf(fout,"N3     NA     -0.35490\n");
	fprintf(fout,"H3     H      0.31540\n");
	fprintf(fout,"C2     C      0.46870\n");
	fprintf(fout,"O      O      -0.54770\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RUN Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.06740\n");
	fprintf(fout,"H1'    H2     0.18240\n");
	fprintf(fout,"N1     N*     0.04180\n");
	fprintf(fout,"C6     CM     -0.11260\n");
	fprintf(fout,"H6     H4     0.21880\n");
	fprintf(fout,"C5     CM     -0.36350\n");
	fprintf(fout,"H5     HA     0.18110\n");
	fprintf(fout,"C4     C      0.59520\n");
	fprintf(fout,"O4     O      -0.57610\n");
	fprintf(fout,"N3     NA     -0.35490\n");
	fprintf(fout,"H3     H      0.31540\n");
	fprintf(fout,"C2     C      0.46870\n");
	fprintf(fout,"O      O      -0.54770\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DG5 Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.03580\n");
	fprintf(fout,"H1'    H2     0.17460\n");
	fprintf(fout,"N9     N*     0.05770\n");
	fprintf(fout,"C8     CK     0.07360\n");
	fprintf(fout,"H8     H5     0.19970\n");
	fprintf(fout,"N7     NB     -0.57250\n");
	fprintf(fout,"C5     CB     0.19910\n");
	fprintf(fout,"C6     C      0.49180\n");
	fprintf(fout,"O6     O      -0.56990\n");
	fprintf(fout,"N1     NA     -0.50530\n");
	fprintf(fout,"H1     H      0.35200\n");
	fprintf(fout,"C2     CA     0.74320\n");
	fprintf(fout,"N2     N2     -0.92300\n");
	fprintf(fout,"H21    H      0.42350\n");
	fprintf(fout,"H22    H      0.42350\n");
	fprintf(fout,"N3     NC     -0.66360\n");
	fprintf(fout,"C4     CB     0.18140\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DG Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.03580\n");
	fprintf(fout,"H1'    H2     0.17460\n");
	fprintf(fout,"N9     N*     0.05770\n");
	fprintf(fout,"C8     CK     0.07360\n");
	fprintf(fout,"H8     H5     0.19970\n");
	fprintf(fout,"N7     NB     -0.57250\n");
	fprintf(fout,"C5     CB     0.19910\n");
	fprintf(fout,"C6     C      0.49180\n");
	fprintf(fout,"O6     O      -0.56990\n");
	fprintf(fout,"N1     NA     -0.50530\n");
	fprintf(fout,"H1     H      0.35200\n");
	fprintf(fout,"C2     CA     0.74320\n");
	fprintf(fout,"N2     N2     -0.92300\n");
	fprintf(fout,"H21    H      0.42350\n");
	fprintf(fout,"H22    H      0.42350\n");
	fprintf(fout,"N3     NC     -0.66360\n");
	fprintf(fout,"C4     CB     0.18140\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DG3 Residue\n");
	fprintf(fout,"P      P      1.16590\n");
	fprintf(fout,"O1P    O2     -0.77610\n");
	fprintf(fout,"O2P    O2     -0.77610\n");
	fprintf(fout,"O5'    OS     -0.49540\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.03580\n");
	fprintf(fout,"H1'    H2     0.17460\n");
	fprintf(fout,"N9     N*     0.05770\n");
	fprintf(fout,"C8     CK     0.07360\n");
	fprintf(fout,"H8     H5     0.19970\n");
	fprintf(fout,"N7     NB     -0.57250\n");
	fprintf(fout,"C5     CB     0.19910\n");
	fprintf(fout,"C6     C      0.49180\n");
	fprintf(fout,"O6     O      -0.56990\n");
	fprintf(fout,"N1     NA     -0.50530\n");
	fprintf(fout,"H1     H      0.35200\n");
	fprintf(fout,"C2     CA     0.74320\n");
	fprintf(fout,"N2     N2     -0.92300\n");
	fprintf(fout,"H21    H      0.42350\n");
	fprintf(fout,"H22    H      0.42350\n");
	fprintf(fout,"N3     NC     -0.66360\n");
	fprintf(fout,"C4     CB     0.18140\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DGN Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     0.03580\n");
	fprintf(fout,"H1'    H2     0.17460\n");
	fprintf(fout,"N9     N*     0.05770\n");
	fprintf(fout,"C8     CK     0.07360\n");
	fprintf(fout,"H8     H5     0.19970\n");
	fprintf(fout,"N7     NB     -0.57250\n");
	fprintf(fout,"C5     CB     0.19910\n");
	fprintf(fout,"C6     C      0.49180\n");
	fprintf(fout,"O6     O      -0.56990\n");
	fprintf(fout,"N1     NA     -0.50530\n");
	fprintf(fout,"H1     H      0.35200\n");
	fprintf(fout,"C2     CA     0.74320\n");
	fprintf(fout,"N2     N2     -0.92300\n");
	fprintf(fout,"H21    H      0.42350\n");
	fprintf(fout,"H22    H      0.42350\n");
	fprintf(fout,"N3     NC     -0.66360\n");
	fprintf(fout,"C4     CB     0.18140\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RG5 Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.01910\n");
	fprintf(fout,"H1'    H2     0.20060\n");
	fprintf(fout,"N9     N*     0.04920\n");
	fprintf(fout,"C8     CK     0.13740\n");
	fprintf(fout,"H8     H5     0.16400\n");
	fprintf(fout,"N7     NB     -0.57090\n");
	fprintf(fout,"C5     CB     0.17440\n");
	fprintf(fout,"C6     C      0.47700\n");
	fprintf(fout,"O6     O      -0.55970\n");
	fprintf(fout,"N1     NA     -0.47870\n");
	fprintf(fout,"H1     H      0.34240\n");
	fprintf(fout,"C2     CA     0.76570\n");
	fprintf(fout,"N2     N2     -0.96720\n");
	fprintf(fout,"H21    H      0.43640\n");
	fprintf(fout,"H22    H      0.43640\n");
	fprintf(fout,"N3     NC     -0.63230\n");
	fprintf(fout,"C4     CB     0.12220\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RG Residue\n");
	fprintf(fout,"N      N      -0.34790\n");
	fprintf(fout,"H      H      0.27470\n");
	fprintf(fout,"CA     CT     -0.26370\n");
	fprintf(fout,"HA     H1     0.15600\n");
	fprintf(fout,"CB     CT     -0.00070\n");
	fprintf(fout,"HB1    HC     0.03270\n");
	fprintf(fout,"HB2    HC     0.03270\n");
	fprintf(fout,"CG     CT     0.03900\n");
	fprintf(fout,"HG1    HC     0.02850\n");
	fprintf(fout,"HG2    HC     0.02850\n");
	fprintf(fout,"CD     CT     0.04860\n");
	fprintf(fout,"HD1    H1     0.06870\n");
	fprintf(fout,"HD2    H1     0.06870\n");
	fprintf(fout,"NE     N2     -0.52950\n");
	fprintf(fout,"HE     H      0.34560\n");
	fprintf(fout,"CZ     CA     0.80760\n");
	fprintf(fout,"NH1    N2     -0.86270\n");
	fprintf(fout,"HH11   H      0.44780\n");
	fprintf(fout,"HH12   H      0.44780\n");
	fprintf(fout,"NH2    N2     -0.86270\n");
	fprintf(fout,"HH21   H      0.44780\n");
	fprintf(fout,"HH22   H      0.44780\n");
	fprintf(fout,"C      C      0.73410\n");
	fprintf(fout,"O      O      -0.58940\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RG3 Residue\n");
	fprintf(fout,"P      P      1.16620\n");
	fprintf(fout,"O1P    O2     -0.77600\n");
	fprintf(fout,"O2P    O2     -0.77600\n");
	fprintf(fout,"O5'    OS     -0.49890\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.01910\n");
	fprintf(fout,"H1'    H2     0.20060\n");
	fprintf(fout,"N9     N*     0.04920\n");
	fprintf(fout,"C8     CK     0.13740\n");
	fprintf(fout,"H8     H5     0.16400\n");
	fprintf(fout,"N7     NB     -0.57090\n");
	fprintf(fout,"C5     CB     0.17440\n");
	fprintf(fout,"C6     C      0.47700\n");
	fprintf(fout,"O6     O      -0.55970\n");
	fprintf(fout,"N1     NA     -0.47870\n");
	fprintf(fout,"H1     H      0.34240\n");
	fprintf(fout,"C2     CA     0.76570\n");
	fprintf(fout,"N2     N2     -0.96720\n");
	fprintf(fout,"H21    H      0.43640\n");
	fprintf(fout,"H22    H      0.43640\n");
	fprintf(fout,"N3     NC     -0.63230\n");
	fprintf(fout,"C4     CB     0.12220\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RGN Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.01910\n");
	fprintf(fout,"H1'    H2     0.20060\n");
	fprintf(fout,"N9     N*     0.04920\n");
	fprintf(fout,"C8     CK     0.13740\n");
	fprintf(fout,"H8     H5     0.16400\n");
	fprintf(fout,"N7     NB     -0.57090\n");
	fprintf(fout,"C5     CB     0.17440\n");
	fprintf(fout,"C6     C      0.47700\n");
	fprintf(fout,"O6     O      -0.55970\n");
	fprintf(fout,"N1     NA     -0.47870\n");
	fprintf(fout,"H1     H      0.34240\n");
	fprintf(fout,"C2     CA     0.76570\n");
	fprintf(fout,"N2     N2     -0.96720\n");
	fprintf(fout,"H21    H      0.43640\n");
	fprintf(fout,"H22    H      0.43640\n");
	fprintf(fout,"N3     NC     -0.63230\n");
	fprintf(fout,"C4     CB     0.12220\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DC5 Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     -0.01160\n");
	fprintf(fout,"H1'    H2     0.19630\n");
	fprintf(fout,"N1     N*     -0.03390\n");
	fprintf(fout,"C6     CM     -0.01830\n");
	fprintf(fout,"H6     H4     0.22930\n");
	fprintf(fout,"C5     CM     -0.52220\n");
	fprintf(fout,"H5     HA     0.18630\n");
	fprintf(fout,"C4     CA     0.84390\n");
	fprintf(fout,"N4     N2     -0.97730\n");
	fprintf(fout,"H41    H      0.43140\n");
	fprintf(fout,"H42    H      0.43140\n");
	fprintf(fout,"N3     NC     -0.77480\n");
	fprintf(fout,"C2     C      0.79590\n");
	fprintf(fout,"O      O      -0.65480\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DC Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     -0.01160\n");
	fprintf(fout,"H1'    H2     0.19630\n");
	fprintf(fout,"N1     N*     -0.03390\n");
	fprintf(fout,"C6     CM     -0.01830\n");
	fprintf(fout,"H6     H4     0.22930\n");
	fprintf(fout,"C5     CM     -0.52220\n");
	fprintf(fout,"H5     HA     0.18630\n");
	fprintf(fout,"C4     CA     0.84390\n");
	fprintf(fout,"N4     N2     -0.97730\n");
	fprintf(fout,"H41    H      0.43140\n");
	fprintf(fout,"H42    H      0.43140\n");
	fprintf(fout,"N3     NC     -0.77480\n");
	fprintf(fout,"C2     C      0.79590\n");
	fprintf(fout,"O      O      -0.65480\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OS     -0.52320\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DC3 Residue\n");
	fprintf(fout,"P      P      1.16590\n");
	fprintf(fout,"O1P    O2     -0.77610\n");
	fprintf(fout,"O2P    O2     -0.77610\n");
	fprintf(fout,"O5'    OS     -0.49540\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     -0.01160\n");
	fprintf(fout,"H1'    H2     0.19630\n");
	fprintf(fout,"N1     N*     -0.03390\n");
	fprintf(fout,"C6     CM     -0.01830\n");
	fprintf(fout,"H6     H4     0.22930\n");
	fprintf(fout,"C5     CM     -0.52220\n");
	fprintf(fout,"H5     HA     0.18630\n");
	fprintf(fout,"C4     CA     0.84390\n");
	fprintf(fout,"N4     N2     -0.97730\n");
	fprintf(fout,"H41    H      0.43140\n");
	fprintf(fout,"H42    H      0.43140\n");
	fprintf(fout,"N3     NC     -0.77480\n");
	fprintf(fout,"C2     C      0.79590\n");
	fprintf(fout,"O      O      -0.65480\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin DCN Residue\n");
	fprintf(fout,"H5T    HO     0.44220\n");
	fprintf(fout,"O5'    OH     -0.63180\n");
	fprintf(fout,"C5'    CT     -0.00690\n");
	fprintf(fout,"H5'1   H1     0.07540\n");
	fprintf(fout,"H5'2   H1     0.07540\n");
	fprintf(fout,"C4'    CT     0.16290\n");
	fprintf(fout,"H4'    H1     0.11760\n");
	fprintf(fout,"O4'    OS     -0.36910\n");
	fprintf(fout,"C1'    CT     -0.01160\n");
	fprintf(fout,"H1'    H2     0.19630\n");
	fprintf(fout,"N1     N*     -0.03390\n");
	fprintf(fout,"C6     CM     -0.01830\n");
	fprintf(fout,"H6     H4     0.22930\n");
	fprintf(fout,"C5     CM     -0.52220\n");
	fprintf(fout,"H5     HA     0.18630\n");
	fprintf(fout,"C4     CA     0.84390\n");
	fprintf(fout,"N4     N2     -0.97730\n");
	fprintf(fout,"H41    H      0.43140\n");
	fprintf(fout,"H42    H      0.43140\n");
	fprintf(fout,"N3     NC     -0.77480\n");
	fprintf(fout,"C2     C      0.79590\n");
	fprintf(fout,"O      O      -0.65480\n");
	fprintf(fout,"C3'    CT     0.07130\n");
	fprintf(fout,"H3'    H1     0.09850\n");
	fprintf(fout,"C2'    CT     -0.08540\n");
	fprintf(fout,"H2'1   HC     0.07180\n");
	fprintf(fout,"H2'2   HC     0.07180\n");
	fprintf(fout,"O3'    OH     -0.65490\n");
	fprintf(fout,"H3T    HO     0.43960\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RC5 Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.00660\n");
	fprintf(fout,"H1'    H2     0.20290\n");
	fprintf(fout,"N1     N*     -0.04840\n");
	fprintf(fout,"C6     CM     0.00530\n");
	fprintf(fout,"H6     H4     0.19580\n");
	fprintf(fout,"C5     CM     -0.52150\n");
	fprintf(fout,"H5     HA     0.19280\n");
	fprintf(fout,"C4     CA     0.81850\n");
	fprintf(fout,"N4     N2     -0.95300\n");
	fprintf(fout,"H41    H      0.42340\n");
	fprintf(fout,"H42    H      0.42340\n");
	fprintf(fout,"N3     NC     -0.75840\n");
	fprintf(fout,"C2     C      0.75380\n");
	fprintf(fout,"O      O      -0.62520\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RC Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.00660\n");
	fprintf(fout,"H1'    H2     0.20290\n");
	fprintf(fout,"N1     N*     -0.04840\n");
	fprintf(fout,"C6     CM     0.00530\n");
	fprintf(fout,"H6     H4     0.19580\n");
	fprintf(fout,"C5     CM     -0.52150\n");
	fprintf(fout,"H5     HA     0.19280\n");
	fprintf(fout,"C4     CA     0.81850\n");
	fprintf(fout,"N4     N2     -0.95300\n");
	fprintf(fout,"H41    H      0.42340\n");
	fprintf(fout,"H42    H      0.42340\n");
	fprintf(fout,"N3     NC     -0.75840\n");
	fprintf(fout,"C2     C      0.75380\n");
	fprintf(fout,"O      O      -0.62520\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OS     -0.52460\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RC3 Residue\n");
	fprintf(fout,"P      P      1.16620\n");
	fprintf(fout,"O1P    O2     -0.77600\n");
	fprintf(fout,"O2P    O2     -0.77600\n");
	fprintf(fout,"O5'    OS     -0.49890\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.00660\n");
	fprintf(fout,"H1'    H2     0.20290\n");
	fprintf(fout,"N1     N*     -0.04840\n");
	fprintf(fout,"C6     CM     0.00530\n");
	fprintf(fout,"H6     H4     0.19580\n");
	fprintf(fout,"C5     CM     -0.52150\n");
	fprintf(fout,"H5     HA     0.19280\n");
	fprintf(fout,"C4     CA     0.81850\n");
	fprintf(fout,"N4     N2     -0.95300\n");
	fprintf(fout,"H41    H      0.42340\n");
	fprintf(fout,"H42    H      0.42340\n");
	fprintf(fout,"N3     NC     -0.75840\n");
	fprintf(fout,"C2     C      0.75380\n");
	fprintf(fout,"O      O      -0.62520\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin RCN Residue\n");
	fprintf(fout,"H5T    HO     0.42950\n");
	fprintf(fout,"O5'    OH     -0.62230\n");
	fprintf(fout,"C5'    CT     0.05580\n");
	fprintf(fout,"H5'1   H1     0.06790\n");
	fprintf(fout,"H5'2   H1     0.06790\n");
	fprintf(fout,"C4'    CT     0.10650\n");
	fprintf(fout,"H4'    H1     0.11740\n");
	fprintf(fout,"O4'    OS     -0.35480\n");
	fprintf(fout,"C1'    CT     0.00660\n");
	fprintf(fout,"H1'    H2     0.20290\n");
	fprintf(fout,"N1     N*     -0.04840\n");
	fprintf(fout,"C6     CM     0.00530\n");
	fprintf(fout,"H6     H4     0.19580\n");
	fprintf(fout,"C5     CM     -0.52150\n");
	fprintf(fout,"H5     HA     0.19280\n");
	fprintf(fout,"C4     CA     0.81850\n");
	fprintf(fout,"N4     N2     -0.95300\n");
	fprintf(fout,"H41    H      0.42340\n");
	fprintf(fout,"H42    H      0.42340\n");
	fprintf(fout,"N3     NC     -0.75840\n");
	fprintf(fout,"C2     C      0.75380\n");
	fprintf(fout,"O      O      -0.62520\n");
	fprintf(fout,"C3'    CT     0.20220\n");
	fprintf(fout,"H3'    H1     0.06150\n");
	fprintf(fout,"C2'    CT     0.06700\n");
	fprintf(fout,"H2'1   H1     0.09720\n");
	fprintf(fout,"O2'    OH     -0.61390\n");
	fprintf(fout,"HO'2   HO     0.41860\n");
	fprintf(fout,"O3'    OH     -0.65410\n");
	fprintf(fout,"H3T    HO     0.43760\n");

	fprintf(fout,"Begin 1MA Residue\n");
	fprintf(fout,"P      P      1.072000\n");
	fprintf(fout,"O1P    O2     -0.755200\n");
	fprintf(fout,"O2P    O2     -0.755200\n");
	fprintf(fout,"O5'    OS     -0.408500\n");
	fprintf(fout,"C5'    CT     0.055600\n");
	fprintf(fout,"H5'1   H1     0.060200\n");
	fprintf(fout,"H5'2   H1     0.060200\n");
	fprintf(fout,"C4'    CT     0.021900\n");
	fprintf(fout,"H4'    H1     0.105500\n");
	fprintf(fout,"O4'    OS     -0.259900\n");
	fprintf(fout,"C1'    CT     0.083400\n");
	fprintf(fout,"H1'    H2     0.115000\n");
	fprintf(fout,"N9     N*     -0.169200\n");
	fprintf(fout,"C8     CK     0.215300\n");
	fprintf(fout,"H8     H5     0.145100\n");
	fprintf(fout,"N7     NB     -0.543600\n");
	fprintf(fout,"C5     CB     -0.047500\n");
	fprintf(fout,"C6     CA     0.603800\n");
	fprintf(fout,"N6     N2     -0.713600\n");
	fprintf(fout,"H61    H      0.355800\n");
	fprintf(fout,"H62    H      0.355800\n");
	fprintf(fout,"N1     NC     -0.731300\n");
	fprintf(fout,"C1     C      0.560800\n");
	fprintf(fout,"H11    H      0.420500\n");
	fprintf(fout,"H12    H      0.420500\n");
	fprintf(fout,"H13    H      0.420500\n");
	fprintf(fout,"1H1    H      0.420500\n");
	fprintf(fout,"2H1    H      0.420500\n");
	fprintf(fout,"3H1    H      0.420500\n");
	fprintf(fout,"C2     CQ     0.572600\n");
	fprintf(fout,"H2     H5     0.011900\n");
	fprintf(fout,"N3     NC     -0.764900\n");
	fprintf(fout,"C4     CB     0.549900\n");
	fprintf(fout,"C3'    CT     0.164500\n");
	fprintf(fout,"H3'    H1     0.062300\n");
	fprintf(fout,"C2'    CT     -0.056100\n");
	fprintf(fout,"H2'1   HC     0.048600\n");
	fprintf(fout,"H2'2   HC     0.048600\n");
	fprintf(fout,"O3'    OS     -0.499800\n");
	fprintf(fout,"H2'    H1     0.103300\n");
	fprintf(fout,"O2'    OH     -0.496300\n");
	fprintf(fout,"HO'2   HO     0.372000\n");
	fprintf(fout,"HO2   HO     0.372000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin 1MG Residue\n");
	fprintf(fout,"P      P      1.072000\n");
	fprintf(fout,"O1P    O2     -0.755200\n");
	fprintf(fout,"O2P    O2     -0.755200\n");
	fprintf(fout,"O5'    OS     -0.408500\n");
	fprintf(fout,"C5'    CT     0.055600\n");
	fprintf(fout,"H5'1   H1     0.060200\n");
	fprintf(fout,"H5'2   H1     0.060200\n");
	fprintf(fout,"C4'    CT     0.021900\n");
	fprintf(fout,"H4'    H1     0.105500\n");
	fprintf(fout,"O4'    OS     -0.259900\n");
	fprintf(fout,"C1'    CT     0.083400\n");
	fprintf(fout,"H1'    H2     0.115000\n");
	fprintf(fout,"N9     N*     -0.169200\n");
	fprintf(fout,"C8     CK     0.215300\n");
	fprintf(fout,"H8     H5     0.145100\n");
	fprintf(fout,"N7     NB     -0.543600\n");
	fprintf(fout,"C5     CB     -0.047500\n");
	fprintf(fout,"C6     CA     0.603800\n");
	fprintf(fout,"N6     N2     -0.713600\n");
	fprintf(fout,"H61    H      0.355800\n");
	fprintf(fout,"H62    H      0.355800\n");
	fprintf(fout,"O6     O      -0.530100\n");
	fprintf(fout,"N1     NC     -0.731300\n");
	fprintf(fout,"C1A    CC      0.0300000\n");
	fprintf(fout,"H11    H      0.420500\n");
	fprintf(fout,"H12    H      0.420500\n");
	fprintf(fout,"H13    H      0.420500\n");
	fprintf(fout,"1H1    H      0.420500\n");
	fprintf(fout,"2H1    H      0.420500\n");
	fprintf(fout,"3H1    H      0.420500\n");
	fprintf(fout,"C2     CQ     0.572600\n");
	fprintf(fout,"N2     N2     -0.750800\n");
	fprintf(fout,"H21    H      0.344300\n");
	fprintf(fout,"H22    H      0.344300\n");
	fprintf(fout,"N3     NC     -0.650200\n");
	fprintf(fout,"C4     CB     0.290900\n");
	fprintf(fout,"C3'    CT     0.164500\n");
	fprintf(fout,"H3'    H1     0.062300\n");
	fprintf(fout,"C2'    CT     -0.056100\n");
	fprintf(fout,"H2'1   HC     0.048600\n");
	fprintf(fout,"H2'2   HC     0.048600\n");
	fprintf(fout,"H2'    H1     0.103300\n");
	fprintf(fout,"O2'    OH     -0.496300\n");
	fprintf(fout,"HO'2   HO     0.372000\n");
	fprintf(fout,"HO2   HO     0.372000\n");
	fprintf(fout,"O3'    OS     -0.499800\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin 2MG Residue\n");
	fprintf(fout,"P      P      1.072000\n");
	fprintf(fout,"O1P    O2     -0.755200\n");
	fprintf(fout,"O2P    O2     -0.755200\n");
	fprintf(fout,"O5'    OS     -0.408500\n");
	fprintf(fout,"C5'    CT     0.055600\n");
	fprintf(fout,"H5'1   H1     0.060200\n");
	fprintf(fout,"H5'2   H1     0.060200\n");
	fprintf(fout,"C4'    CT     0.021900\n");
	fprintf(fout,"H4'    H1     0.105500\n");
	fprintf(fout,"O4'    OS     -0.259900\n");
	fprintf(fout,"C1'    CT     0.083400\n");
	fprintf(fout,"H1'    H2     0.115000\n");
	fprintf(fout,"N9     N*     -0.169200\n");
	fprintf(fout,"C8     CK     0.215300\n");
	fprintf(fout,"H8     H5     0.145100\n");
	fprintf(fout,"N7     NB     -0.543600\n");
	fprintf(fout,"C5     CB     -0.047500\n");
	fprintf(fout,"C6     CA     0.603800\n");
	fprintf(fout,"O6     O      -0.530100\n");
	fprintf(fout,"N1     NC     -0.731300\n");
	fprintf(fout,"H1     H      0.420500\n");
	fprintf(fout,"C2     CQ     0.572600\n");
	fprintf(fout,"N2     N2     -0.750800\n");
	fprintf(fout,"H2     H      0.344300\n");
	fprintf(fout,"C2A    CB    -0.020000\n");
	fprintf(fout,"H2A1   HC     0.080300\n");
	fprintf(fout,"H2A2   HC     0.080300\n");
	fprintf(fout,"H2A3   HC     0.080300\n");
	fprintf(fout,"N3     NC     -0.650200\n");
	fprintf(fout,"C4     CB     0.290900\n");
	fprintf(fout,"C3'    CT     0.164500\n");
	fprintf(fout,"H3'    H1     0.062300\n");
	fprintf(fout,"C2'    CT     -0.056100\n");
	fprintf(fout,"H2'    H1     0.103300\n");
	fprintf(fout,"O2'    OH     -0.496300\n");
	fprintf(fout,"HO'2   HO     0.372000\n");
	fprintf(fout,"HO2   HO     0.372000\n");
	fprintf(fout,"O3'    OS     -0.499800\n");
	fprintf(fout,"H2'1   HC     0.048600\n");
	fprintf(fout,"H2'2   HC     0.048600\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin 5MC Residue\n");
	fprintf(fout,"P      P      1.072000\n");
	fprintf(fout,"O1P    O2     -0.755200\n");
	fprintf(fout,"O2P    O2     -0.755200\n");
	fprintf(fout,"O5'    OS     -0.408500\n");
	fprintf(fout,"C5'    CT     0.055600\n");
	fprintf(fout,"H5'1   H1     0.060200\n");
	fprintf(fout,"H5'2   H1     0.060200\n");
	fprintf(fout,"C4'    CT     0.021900\n");
	fprintf(fout,"H4'    H1     0.105500\n");
	fprintf(fout,"O4'    OS     -0.259900\n");
	fprintf(fout,"C1'    CT     0.083400\n");
	fprintf(fout,"H1'    H2     0.115000\n");
	fprintf(fout,"N1     NC     -0.731300\n");
	fprintf(fout,"C6     CM     -0.011500\n");
	fprintf(fout,"H6     H4     0.209900\n");
	fprintf(fout,"C5     CM     -0.469600\n");
	fprintf(fout,"C5A    CM     -0.469600\n");
	fprintf(fout,"H5A1   HA     0.183300\n");
	fprintf(fout,"H5A2   HA     0.183300\n");
	fprintf(fout,"H5A3   HA     0.183300\n");
	fprintf(fout,"C4     CA     0.701000\n");
	fprintf(fout,"N4     N2     -0.741700\n");
	fprintf(fout,"H41    H      0.352600\n");
	fprintf(fout,"H42    H      0.352600\n");
	fprintf(fout,"N3     NC     -0.755500\n");
	fprintf(fout,"C2     C      0.846400\n");
	fprintf(fout,"O2     O      -0.652400\n");
	fprintf(fout,"C3'    CT     0.164500\n");
	fprintf(fout,"H3'    H1     0.062300\n");
	fprintf(fout,"C2'    CT     -0.056100\n");
	fprintf(fout,"H2'    H1     0.103300\n");
	fprintf(fout,"O2'    OH     -0.496300\n");
	fprintf(fout,"HO'2   HO     0.372000\n");
	fprintf(fout,"HO2    HO     0.372000\n");
	fprintf(fout,"H2'1   HC     0.048600\n");
	fprintf(fout,"H2'2   HC     0.048600\n");
	fprintf(fout,"O3'    OS     -0.499800\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin 5MU Residue\n");
	fprintf(fout,"P      P      1.072000\n");
	fprintf(fout,"O1P    O2     -0.755200\n");
	fprintf(fout,"O2P    O2     -0.755200\n");
	fprintf(fout,"O5'    OS     -0.408500\n");
	fprintf(fout,"C5'    CT     0.055600\n");
	fprintf(fout,"H5'1   H1     0.060200\n");
	fprintf(fout,"H5'2   H1     0.060200\n");
	fprintf(fout,"C4'    CT     0.021900\n");
	fprintf(fout,"H4'    H1     0.105500\n");
	fprintf(fout,"O4'    OS     -0.259900\n");
	fprintf(fout,"C1'    CT     0.083400\n");
	fprintf(fout,"H1'    H2     0.115000\n");
	fprintf(fout,"N1     NC     -0.731300\n");
	fprintf(fout,"C6     CM     -0.011500\n");
	fprintf(fout,"H6     H4     0.209900\n");
	fprintf(fout,"C5     CM     -0.469600\n");
	fprintf(fout,"C5A    CM     -0.469600\n");
	fprintf(fout,"H5A1   HA     0.183300\n");
	fprintf(fout,"H5A2   HA     0.183300\n");
	fprintf(fout,"H5A3   HA     0.183300\n");
	fprintf(fout,"C4     CA     0.701000\n");
	fprintf(fout,"O4     O      -0.545500\n");
	fprintf(fout,"N3     NA     -0.482400\n");
	fprintf(fout,"H3     H      0.354200\n");
	fprintf(fout,"C2     C      0.589200\n");
	fprintf(fout,"O2     O      -0.588000\n");
	fprintf(fout,"C3'    CT     0.164500\n");
	fprintf(fout,"H3'    H1     0.062300\n");
	fprintf(fout,"C2'    CT     -0.056100\n");
	fprintf(fout,"H2'    H1     0.103300\n");
	fprintf(fout,"O2'    OH     -0.496300\n");
	fprintf(fout,"HO'2   HO     0.372000\n");
	fprintf(fout,"HO2    HO     0.372000\n");
	fprintf(fout,"H2'1   HC     0.048600\n");
	fprintf(fout,"H2'2   HC     0.048600\n");
	fprintf(fout,"O3'    OS     -0.499800\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin 7MG Residue\n");
	fprintf(fout,"P      P      1.072000\n");
	fprintf(fout,"O1P    O2     -0.755200\n");
	fprintf(fout,"O2P    O2     -0.755200\n");
	fprintf(fout,"O5'    OS     -0.408500\n");
	fprintf(fout,"C5'    CT     0.055600\n");
	fprintf(fout,"H5'1   H1     0.060200\n");
	fprintf(fout,"H5'2   H1     0.060200\n");
	fprintf(fout,"C4'    CT     0.021900\n");
	fprintf(fout,"H4'    H1     0.105500\n");
	fprintf(fout,"O4'    OS     -0.259900\n");
	fprintf(fout,"C1'    CT     0.083400\n");
	fprintf(fout,"H1'    H2     0.115000\n");
	fprintf(fout,"N9     N*     -0.169200\n");
	fprintf(fout,"C8     CK     0.215300\n");
	fprintf(fout,"H8     H5     0.145100\n");
	fprintf(fout,"N7     NB     -0.543600\n");
	fprintf(fout,"C7     CT     -0.132600\n");
	fprintf(fout,"H71    HC     0.060600\n");
	fprintf(fout,"H72    HC     0.060600\n");
	fprintf(fout,"H73    HC     0.060600\n");
	fprintf(fout,"C5     CB     -0.047500\n");
	fprintf(fout,"C6     CA     0.603800\n");
	fprintf(fout,"O6     O      -0.530100\n");
	fprintf(fout,"N1     NA     -0.540500\n");
	fprintf(fout,"H1     H      0.375000\n");
	fprintf(fout,"C2     CA     0.683400\n");
	fprintf(fout,"N2     N2     -0.750800\n");
	fprintf(fout,"H21    H      0.344300\n");
	fprintf(fout,"H22    H      0.344300\n");
	fprintf(fout,"N3     NC     -0.650200\n");
	fprintf(fout,"C4     CB     0.290900\n");
	fprintf(fout,"C3'    CT     0.164500\n");
	fprintf(fout,"H3'    H1     0.062300\n");
	fprintf(fout,"C2'    CT     -0.056100\n");
	fprintf(fout,"H2'1   HC     0.048600\n");
	fprintf(fout,"H2'2   HC     0.048600\n");
	fprintf(fout,"O3'    OS     -0.499800\n");
	fprintf(fout,"H2'    H1     0.103300\n");
	fprintf(fout,"O2'    OH     -0.496300\n");
	fprintf(fout,"HO'2   HO     0.372000\n");
	fprintf(fout,"HO2    HO     0.372000\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin H2U Residue\n");
	fprintf(fout,"P      P      1.072000\n");
	fprintf(fout,"O1P    O2     -0.755200\n");
	fprintf(fout,"O2P    O2     -0.755200\n");
	fprintf(fout,"O5'    OS     -0.408500\n");
	fprintf(fout,"C5'    CT     0.055600\n");
	fprintf(fout,"H5'1   H1     0.060200\n");
	fprintf(fout,"H5'2   H1     0.060200\n");
	fprintf(fout,"C4'    CT     0.021900\n");
	fprintf(fout,"H4'    H1     0.105500\n");
	fprintf(fout,"O4'    OS     -0.259900\n");
	fprintf(fout,"C1'    CT     0.083400\n");
	fprintf(fout,"H1'    H2     0.115000\n");
	fprintf(fout,"C3'    CT     0.164500\n");
	fprintf(fout,"H3'    H1     0.062300\n");
	fprintf(fout,"C2'    CT     -0.056100\n");
	fprintf(fout,"H2'    H1     0.103300\n");
	fprintf(fout,"O2'    OH     -0.496300\n");
	fprintf(fout,"HO'2   HO     0.372000\n");
	fprintf(fout,"HO2    HO     0.372000\n");
	fprintf(fout,"O3'    OS     -0.499800\n");
	fprintf(fout,"N1     NC     -0.731300\n");
	fprintf(fout,"C6     CM     -0.011500\n");
	fprintf(fout,"H61    H      0.355800\n");
	fprintf(fout,"H62    H      0.355800\n");
	fprintf(fout,"C5     CB     -0.047500\n");
	fprintf(fout,"H51    H      0.355800\n");
	fprintf(fout,"H52    H      0.355800\n");
	fprintf(fout,"C4     C      0.572800\n");
	fprintf(fout,"O4     O      -0.552800\n");
	fprintf(fout,"N3     NA     -0.340900\n");
	fprintf(fout,"H3     H      0.307700\n");
	fprintf(fout,"C2     C      0.462500\n");
	fprintf(fout,"O2     O      -0.559700\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin I Residue\n");
	fprintf(fout,"P      P      1.072000\n");
	fprintf(fout,"O1P    O2     -0.755200\n");
	fprintf(fout,"O2P    O2     -0.755200\n");
	fprintf(fout,"O5'    OS     -0.408500\n");
	fprintf(fout,"C5'    CT     0.055600\n");
	fprintf(fout,"H5'1   H1     0.060200\n");
	fprintf(fout,"H5'2   H1     0.060200\n");
	fprintf(fout,"C4'    CT     0.021900\n");
	fprintf(fout,"H4'    H1     0.105500\n");
	fprintf(fout,"O4'    OS     -0.259900\n");
	fprintf(fout,"C1'    CT     0.083400\n");
	fprintf(fout,"H1'    H2     0.115000\n");
	fprintf(fout,"N9     N*     -0.169200\n");
	fprintf(fout,"C8     CK     0.215300\n");
	fprintf(fout,"H8     H5     0.145100\n");
	fprintf(fout,"N7     NB     -0.543600\n");
	fprintf(fout,"C5     CB     -0.047500\n");
	fprintf(fout,"C6     CA     0.603800\n");
	fprintf(fout,"O6     O      -0.530100\n");
	fprintf(fout,"N1     NA     -0.540500\n");
	fprintf(fout,"H1     H      0.375000\n");
	fprintf(fout,"C2     CA     0.683400\n");
	fprintf(fout,"N3     NC     -0.764900\n");
	fprintf(fout,"C4     CB     0.549900\n");
	fprintf(fout,"C3'    CT     0.164500\n");
	fprintf(fout,"H3'    H1     0.062300\n");
	fprintf(fout,"C2'    CT     -0.056100\n");
	fprintf(fout,"H2'    H1     0.103300\n");
	fprintf(fout,"O2'    OH     -0.496300\n");
	fprintf(fout,"HO'2   HO     0.372000\n");
	fprintf(fout,"HO2    HO     0.372000\n");
	fprintf(fout,"H2'1   HC     0.048600\n");
	fprintf(fout,"H2'2   HC     0.048600\n");
	fprintf(fout,"O3'    OS     -0.499800\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin M2G Residue\n");
	fprintf(fout,"P      P      1.072000\n");
	fprintf(fout,"O1P    O2     -0.755200\n");
	fprintf(fout,"O2P    O2     -0.755200\n");
	fprintf(fout,"O5'    OS     -0.408500\n");
	fprintf(fout,"C5'    CT     0.055600\n");
	fprintf(fout,"H5'1   H1     0.060200\n");
	fprintf(fout,"H5'2   H1     0.060200\n");
	fprintf(fout,"C4'    CT     0.021900\n");
	fprintf(fout,"H4'    H1     0.105500\n");
	fprintf(fout,"O4'    OS     -0.259900\n");
	fprintf(fout,"C1'    CT     0.083400\n");
	fprintf(fout,"H1'    H2     0.115000\n");
	fprintf(fout,"N9     N*     -0.169200\n");
	fprintf(fout,"C8     CK     0.215300\n");
	fprintf(fout,"H8     H5     0.145100\n");
	fprintf(fout,"N7     NB     -0.543600\n");
	fprintf(fout,"C5     CB     -0.047500\n");
	fprintf(fout,"C6     CA     0.603800\n");
	fprintf(fout,"O6     O      -0.530100\n");
	fprintf(fout,"N1     NA     -0.540500\n");
	fprintf(fout,"H1     H      0.375000\n");
	fprintf(fout,"C2     CA     0.683400\n");
	fprintf(fout,"N2     N2     -0.750800\n");
	fprintf(fout,"C2A    CB    -0.020000\n");
	fprintf(fout,"H2A1   HC     0.080300\n");
	fprintf(fout,"H2A2   HC     0.080300\n");
	fprintf(fout,"H2A3   HC     0.080300\n");
	fprintf(fout,"C2B    CB    -0.020000\n");
	fprintf(fout,"H2B1   HC     0.080300\n");
	fprintf(fout,"H2B2   HC     0.080300\n");
	fprintf(fout,"H2B3   HC     0.080300\n");
	fprintf(fout,"N3     NC     -0.650200\n");
	fprintf(fout,"C4     CB     0.290900\n");
	fprintf(fout,"C3'    CT     0.164500\n");
	fprintf(fout,"H3'    H1     0.062300\n");
	fprintf(fout,"C2'    CT     -0.056100\n");
	fprintf(fout,"H2'    H1     0.103300\n");
	fprintf(fout,"O2'    OH     -0.496300\n");
	fprintf(fout,"HO'2   HO     0.372000\n");
	fprintf(fout,"HO2   HO     0.372000\n");
	fprintf(fout,"O3'    OS     -0.499800\n");
	fprintf(fout,"H2'1   HC     0.048600\n");
	fprintf(fout,"H2'2   HC     0.048600\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin OMC Residue\n");
	fprintf(fout,"P      P      1.072000\n");
	fprintf(fout,"O1P    O2     -0.755200\n");
	fprintf(fout,"O2P    O2     -0.755200\n");
	fprintf(fout,"O5'    OS     -0.408500\n");
	fprintf(fout,"C5'    CT     0.055600\n");
	fprintf(fout,"H5'1   H1     0.060200\n");
	fprintf(fout,"H5'2   H1     0.060200\n");
	fprintf(fout,"C4'    CT     0.021900\n");
	fprintf(fout,"H4'    H1     0.105500\n");
	fprintf(fout,"O4'    OS     -0.259900\n");
	fprintf(fout,"C1'    CT     0.083400\n");
	fprintf(fout,"H1'    H2     0.115000\n");
	fprintf(fout,"N1     N*     -0.131800\n");
	fprintf(fout,"C6     CM     -0.011500\n");
	fprintf(fout,"H6     H4     0.209900\n");
	fprintf(fout,"C5     CM     -0.469600\n");
	fprintf(fout,"H5     HA     0.183300\n");
	fprintf(fout,"C4     CA     0.701000\n");
	fprintf(fout,"N4     N2     -0.741700\n");
	fprintf(fout,"H41    H      0.352600\n");
	fprintf(fout,"H42    H      0.352600\n");
	fprintf(fout,"N3     NC     -0.755500\n");
	fprintf(fout,"C2     CQ     0.572600\n");
	fprintf(fout,"O2     O      -0.652400\n");
	fprintf(fout,"H3'    H1     0.062300\n");
	fprintf(fout,"C2'    CT     -0.056100\n");
	fprintf(fout,"H2'    H1     0.103300\n");
	fprintf(fout,"O2'    OH     -0.496300\n");
	fprintf(fout,"C2A    CB    -0.020000\n");
	fprintf(fout,"H2A1   HC     0.080300\n");
	fprintf(fout,"H2A2   HC     0.080300\n");
	fprintf(fout,"H2A3   HC     0.080300\n");
	fprintf(fout,"C3'    CT     0.164500\n");
	fprintf(fout,"O3'    OS     -0.499800\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin OMG Residue\n");
	fprintf(fout,"P      P      1.072000\n");
	fprintf(fout,"O1P    O2     -0.755200\n");
	fprintf(fout,"O2P    O2     -0.755200\n");
	fprintf(fout,"O5'    OS     -0.408500\n");
	fprintf(fout,"C5'    CT     0.055600\n");
	fprintf(fout,"H5'1   H1     0.060200\n");
	fprintf(fout,"H5'2   H1     0.060200\n");
	fprintf(fout,"C4'    CT     0.021900\n");
	fprintf(fout,"H4'    H1     0.105500\n");
	fprintf(fout,"O4'    OS     -0.259900\n");
	fprintf(fout,"C1'    CT     0.083400\n");
	fprintf(fout,"H1'    H2     0.115000\n");
	fprintf(fout,"N9     N*     -0.169200\n");
	fprintf(fout,"C8     CK     0.215300\n");
	fprintf(fout,"H8     H5     0.145100\n");
	fprintf(fout,"N7     NB     -0.543600\n");
	fprintf(fout,"C5     CB     -0.047500\n");
	fprintf(fout,"C6     CA     0.603800\n");
	fprintf(fout,"O6     O      -0.530100\n");
	fprintf(fout,"N1     NA     -0.540500\n");
	fprintf(fout,"H1     H      0.375000\n");
	fprintf(fout,"C2     CA     0.683400\n");
	fprintf(fout,"N2     N2     -0.750800\n");
	fprintf(fout,"H21    H      0.344300\n");
	fprintf(fout,"H22    H      0.344300\n");
	fprintf(fout,"N3     NC     -0.650200\n");
	fprintf(fout,"C4     CB     0.290900\n");
	fprintf(fout,"C3'    CT     0.164500\n");
	fprintf(fout,"H3'    H1     0.062300\n");
	fprintf(fout,"C2'    CT     -0.056100\n");
	fprintf(fout,"H2'    H1     0.103300\n");
	fprintf(fout,"O2'    OH     -0.496300\n");
	fprintf(fout,"C2A    CB    -0.020000\n");
	fprintf(fout,"H2A1   HC     0.080300\n");
	fprintf(fout,"H2A2   HC     0.080300\n");
	fprintf(fout,"H2A3   HC     0.080300\n");
	fprintf(fout,"O3'    OS     -0.499800\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin PSU Residue\n");
	fprintf(fout,"P      P      1.072000\n");
	fprintf(fout,"O1P    O2     -0.755200\n");
	fprintf(fout,"O2P    O2     -0.755200\n");
	fprintf(fout,"O5'    OS     -0.408500\n");
	fprintf(fout,"C5'    CT     0.055600\n");
	fprintf(fout,"H5'1   H1     0.060200\n");
	fprintf(fout,"H5'2   H1     0.060200\n");
	fprintf(fout,"C4'    CT     0.021900\n");
	fprintf(fout,"H4'    H1     0.105500\n");
	fprintf(fout,"O4'    OS     -0.259900\n");
	fprintf(fout,"C1'    CT     0.083400\n");
	fprintf(fout,"H1'    H2     0.115000\n");
	fprintf(fout,"N1     NA     -0.540500\n");
	fprintf(fout,"H1     H      0.375000\n");
	fprintf(fout,"C6     CM     -0.011500\n");
	fprintf(fout,"H6     H4     0.209900\n");
	fprintf(fout,"C5     CM     -0.469600\n");
	fprintf(fout,"C4     CA     0.701000\n");
	fprintf(fout,"O4     O      -0.545500\n");
	fprintf(fout,"N3     NA     -0.482400\n");
	fprintf(fout,"H3     H      0.354200\n");
	fprintf(fout,"C2     C      0.589200\n");
	fprintf(fout,"O2     O      -0.588000\n");
	fprintf(fout,"C3'    CT     0.164500\n");
	fprintf(fout,"H3'    H1     0.062300\n");
	fprintf(fout,"C2'    CT     -0.056100\n");
	fprintf(fout,"H2'    H1     0.103300\n");
	fprintf(fout,"O2'    OH     -0.496300\n");
	fprintf(fout,"HO'2   HO     0.372000\n");
	fprintf(fout,"HO2   HO     0.372000\n");
	fprintf(fout,"H2'1   HC     0.048600\n");
	fprintf(fout,"H2'2   HC     0.048600\n");
	fprintf(fout,"O3'    OS     -0.499800\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin Y Residue\n");
	fprintf(fout,"P      P      1.072000\n");
	fprintf(fout,"O1P    O2     -0.755200\n");
	fprintf(fout,"O2P    O2     -0.755200\n");
	fprintf(fout,"O5'    OS     -0.408500\n");
	fprintf(fout,"C5'    CT     0.055600\n");
	fprintf(fout,"H5'1   H1     0.060200\n");
	fprintf(fout,"H5'2   H1     0.060200\n");
	fprintf(fout,"C4'    CT     0.021900\n");
	fprintf(fout,"H4'    H1     0.105500\n");
	fprintf(fout,"O4'    OS     -0.259900\n");
	fprintf(fout,"C1'    CT     0.083400\n");
	fprintf(fout,"H1'    H2     0.115000\n");
	fprintf(fout,"C3'    CT     0.164500\n");
	fprintf(fout,"H3'    H1     0.062300\n");
	fprintf(fout,"C2'    CT     -0.056100\n");
	fprintf(fout,"H2'    H1     0.103300\n");
	fprintf(fout,"O2'    OH     -0.496300\n");
	fprintf(fout,"HO'2   HO     0.372000\n");
	fprintf(fout,"HO2   HO     0.372000\n");
	fprintf(fout,"O3'    OS     -0.499800\n");
	fprintf(fout,"H2'1   HC     0.048600\n");
	fprintf(fout,"H2'2   HC     0.048600\n");
	fprintf(fout,"N9     N*     -0.169200\n");
	fprintf(fout,"C8     CK     0.215300\n");
	fprintf(fout,"H8     H5     0.145100\n");
	fprintf(fout,"N7     NB     -0.543600\n");
	fprintf(fout,"H7    HC     0.060600\n");
	fprintf(fout,"C5     CB     -0.047500\n");
	fprintf(fout,"C6     CA     0.603800\n");
	fprintf(fout,"O6     O      -0.530100\n");
	fprintf(fout,"N1     NA     -0.540500\n");
	fprintf(fout,"C2     CA     0.683400\n");
	fprintf(fout,"N2     N2     -0.750800\n");
	fprintf(fout,"N3     NC     -0.764900\n");
	fprintf(fout,"C3     C      0.846400\n");
	fprintf(fout,"H31    H      0.354200\n");
	fprintf(fout,"H32    H      0.354200\n");
	fprintf(fout,"H33    H      0.354200\n");
	fprintf(fout,"C4     CB     0.549900\n");
	fprintf(fout,"C10    C      0.846400\n");
	fprintf(fout,"H101   H      0.375000\n");
	fprintf(fout,"H102   H      0.375000\n");
	fprintf(fout,"H103   H      0.375000\n");
	fprintf(fout,"C11    C      0.846400\n");
	fprintf(fout,"C12    C      0.846400\n");
	fprintf(fout,"C13    C      0.846400\n");
	fprintf(fout,"1C1    C      0.846400\n");
	fprintf(fout,"2C1    C      0.846400\n");
	fprintf(fout,"3C1    C      0.846400\n");
	fprintf(fout,"H131   H      0.375000\n");
	fprintf(fout,"H132   H      0.375000\n");
	fprintf(fout,"1H13   H      0.375000\n");
	fprintf(fout,"2H13   H      0.375000\n");
	fprintf(fout,"C14    C      0.846400\n");
	fprintf(fout,"H141   H      0.375000\n");
	fprintf(fout,"H142   H      0.375000\n");
	fprintf(fout,"1H14   H      0.375000\n");
	fprintf(fout,"2H14   H      0.375000\n");
	fprintf(fout,"C15    C      0.846400\n");
	fprintf(fout,"H15   H      0.375000\n");
	fprintf(fout,"C16    C      0.846400\n");
	fprintf(fout,"O17    O      -0.504000\n");
	fprintf(fout,"O18    O      -0.504000\n");
	fprintf(fout,"C19    C      0.846400\n");
	fprintf(fout,"H191   H      0.375000\n");
	fprintf(fout,"H192   H      0.375000\n");
	fprintf(fout,"H193   H      0.375000\n");
	fprintf(fout,"1H19   H      0.375000\n");
	fprintf(fout,"2H19   H      0.375000\n");
	fprintf(fout,"3H19   H      0.375000\n");
	fprintf(fout,"N20    N2     -0.750800\n");
	fprintf(fout,"C21    CQ     0.572600\n");
	fprintf(fout,"H20    H      0.344300\n");
	fprintf(fout,"O22    O      -0.652400\n");
	fprintf(fout,"O23    O      -0.652400\n");
	fprintf(fout,"C24    CQ     0.572600\n");
	fprintf(fout,"H241   H      0.344300\n");
	fprintf(fout,"H242   H      0.344300\n");
	fprintf(fout,"H243   H      0.344300\n");
	fprintf(fout,"1H24   H      0.344300\n");
	fprintf(fout,"2H24   H      0.344300\n");
	fprintf(fout,"3H24   H      0.344300\n");
	fprintf(fout,"End\n");

}
/************************************************************/
void createAllResidueTpl(FILE* fout)
{
	fprintf(fout,"Begin ALLRESIDUE Residue\n");
	fprintf(fout,"OXT    O2    -0.542500\n");
	fprintf(fout,"1H     H	    0.301800\n");
	fprintf(fout,"2H     H      0.301800\n");
	fprintf(fout,"3H     H      0.301800\n");
	fprintf(fout,"O3T    OH     -0.63180\n");
	fprintf(fout,"H3T    HO     0.325000\n");
	fprintf(fout,"HT1    H     0.325000\n");
	fprintf(fout,"HT2    H     0.325000\n");
	fprintf(fout,"HT3    H     0.325000\n");
	fprintf(fout,"Li     Li     1.000000\n");
	fprintf(fout,"Na     Na     1.000000\n");
	fprintf(fout,"K      K      1.000000\n");
	fprintf(fout,"Rb     Rb     1.000000\n");
	fprintf(fout,"Cs     Cs     1.000000\n");
	fprintf(fout,"End\n");
}
/************************************************************/
void createFragResidueTpl(FILE* fout)
{
	fprintf(fout,"Begin GBZN Residue\n");
	fprintf(fout,"C1    CA    -0.542500\n");
	fprintf(fout,"C2    CA    -0.542500\n");
	fprintf(fout,"C3    CA    -0.542500\n");
	fprintf(fout,"C4    CA    -0.542500\n");
	fprintf(fout,"C5    CA    -0.542500\n");
	fprintf(fout,"C6    CA    -0.542500\n");
	fprintf(fout,"H11   HA      0.301800\n");
	fprintf(fout,"H21   HA      0.301800\n");
	fprintf(fout,"H31   HA      0.301800\n");
	fprintf(fout,"H41   HA      0.301800\n");
	fprintf(fout,"H51   HA      0.301800\n");
	fprintf(fout,"H61   HA      0.301800\n");
	fprintf(fout,"End\n");

	fprintf(fout,"Begin GAPT Residue\n");
	fprintf(fout,"C1    CT    -0.542500\n");
	fprintf(fout,"C2    CT    -0.542500\n");
	fprintf(fout,"C3    CA    -0.542500\n");
	fprintf(fout,"C4    CA    -0.542500\n");
	fprintf(fout,"C5    CA    -0.542500\n");
	fprintf(fout,"C6    CA    -0.542500\n");
	fprintf(fout,"C7    CA    -0.542500\n");
	fprintf(fout,"C8    CA    -0.542500\n");
	fprintf(fout,"C9    CA    -0.542500\n");
	fprintf(fout,"C10    CA    -0.542500\n");
	fprintf(fout,"C11    CA    -0.542500\n");
	fprintf(fout,"C12    CA    -0.542500\n");
	fprintf(fout,"H1   HC      0.301800\n");
	fprintf(fout,"H2   HC      0.301800\n");
	fprintf(fout,"H3   HC      0.301800\n");
	fprintf(fout,"H4   HC      0.301800\n");
	fprintf(fout,"H5   HA      0.301800\n");
	fprintf(fout,"H6   HA      0.301800\n");
	fprintf(fout,"H7   HA      0.301800\n");
	fprintf(fout,"H8   HA      0.301800\n");
	fprintf(fout,"H9   HA      0.301800\n");
	fprintf(fout,"H10   HA      0.301800\n");
	fprintf(fout,"End\n");
}
/************************************************************/
gboolean CreateDefaultPDBTpl()
{
	gchar* filename = g_strdup_printf("%s%sDefaultPDBTemplate.tpl",gabedit_directory(), G_DIR_SEPARATOR_S);
	FILE* fout = FOpen(filename,"w");
	if(!fout)
		return FALSE;
	createTitleResidueTpl(fout);
	createListResidueTpl(fout);
	createAminoResidueTpl(fout);
	createNucleicResidueTpl(fout);
	createAllResidueTpl(fout);
	createFragResidueTpl(fout);
	fclose(fout);
	return TRUE;
}
